@@ -30,6 +30,7 @@ import (
 	"syscall"
 	"time"
 
+	"code.superseriousbusiness.org/gopkg/log"
 	"code.superseriousbusiness.org/gotosocial/cmd/gotosocial/action"
 	"code.superseriousbusiness.org/gotosocial/internal/admin"
 	"code.superseriousbusiness.org/gotosocial/internal/api"
@@ -47,7 +48,6 @@ import (
 	"code.superseriousbusiness.org/gotosocial/internal/filter/visibility"
 	"code.superseriousbusiness.org/gotosocial/internal/gtserror"
 	"code.superseriousbusiness.org/gotosocial/internal/httpclient"
-	"code.superseriousbusiness.org/gotosocial/internal/log"
 	"code.superseriousbusiness.org/gotosocial/internal/media"
 	"code.superseriousbusiness.org/gotosocial/internal/media/ffmpeg"
 	"code.superseriousbusiness.org/gotosocial/internal/messages"
@@ -172,8 +172,9 @@ func Start(ctx context.Context) error {
 		log.Info(ctx, "done! exiting...")
 	}()
 
-	// Create maintenance router.
 	var err error
+
+	// Create maintenance router.
 	route, err = router.New(ctx)
 	if err != nil {
 		return fmt.Errorf("error creating maintenance router: %w", err)
@@ -441,6 +442,7 @@ func Start(ctx context.Context) error {
 		middleware.UserAgent(),
 		middleware.CORS(),
 		middleware.ExtraHeaders(),
+		middleware.Timeout(10 * time.Minute),
 	}...)
 
 	// Instantiate Content-Security-Policy
@@ -461,12 +463,14 @@ func Start(ctx context.Context) error {
 	}
 
 	// Add any extra CSP URIs from config.
-	cspExtraURIs = append(cspExtraURIs, config.GetAdvancedCSPExtraURIs()...)
+	cspExtraURIs = append(cspExtraURIs,
+		config.GetAdvancedCSPExtraURIs()...)
 
 	// Add CSP to middlewares.
-	middlewares = append(middlewares, middleware.ContentSecurityPolicy(cspExtraURIs...))
+	middlewares = append(middlewares,
+		middleware.ContentSecurityPolicy(cspExtraURIs...))
 
-	// attach global middlewares which are used for every request
+	// Attach global middlewares which are used for every request
 	route.AttachGlobalMiddleware(middlewares...)
 
 	// attach global no route / 404 handler to the router
@@ -475,7 +479,7 @@ func Start(ctx context.Context) error {
 	})
 
 	// build router modules
-	var idp oidc.IDP
+	var idp *oidc.IDP
 	if config.GetOIDCEnabled() {
 		idp, err = oidc.NewIDP(ctx)
 		if err != nil {
