@@ -23,7 +23,7 @@ import (
 
 	"code.superseriousbusiness.org/gotosocial/cmd/gotosocial/action"
 	"code.superseriousbusiness.org/gotosocial/internal/config"
-	"code.superseriousbusiness.org/gotosocial/internal/log"
+	"code.superseriousbusiness.org/gotosocial/internal/gtslog"
 	"github.com/spf13/cobra"
 )
 
@@ -63,21 +63,21 @@ func preRun(a preRunArgs) error {
 // The idea here is to take a GTSAction and run it with the given
 // context, after initializing any last-minute things like loggers etc.
 func run(ctx context.Context, action action.GTSAction) error {
-	log.SetTimeFormat(config.GetLogTimestampFormat())
+	gtslog.SetTimeFormat(config.GetLogTimestampFormat())
 
 	// Set the global log level from configuration.
-	if err := log.ParseLevel(config.GetLogLevel()); err != nil {
+	if err := gtslog.ParseLevel(config.GetLogLevel()); err != nil {
 		return fmt.Errorf("error parsing log level: %w", err)
 	}
 
 	// Set global log output format from configuration.
-	if err := log.ParseFormat(config.GetLogFormat()); err != nil {
+	if err := gtslog.ParseFormat(config.GetLogFormat()); err != nil {
 		return fmt.Errorf("error parsing log format: %w", err)
 	}
 
 	if config.GetSyslogEnabled() {
 		// Enable logging to syslog
-		if err := log.EnableSyslog(
+		if err := gtslog.EnableSyslog(
 			config.GetSyslogProtocol(),
 			config.GetSyslogAddress(),
 		); err != nil {
