@@ -232,6 +232,7 @@ type Activityable interface {
 	WithActor
 	WithObject
 	WithPublished
+	WithInstrument
 }
 
 // Accountable represents the minimum activitypub interface for representing an 'account'.
@@ -247,6 +248,7 @@ type Accountable interface {
 	WithSummary
 	WithAttachment
 	WithDiscoverable
+	WithIndexable
 	WithURL
 	WithPublicKey
 	WithInbox
@@ -423,6 +425,7 @@ type InteractionRequestable interface {
 	vocab.Type
 
 	WithActor
+	WithTo
 	WithObject
 	WithInstrument
 }
@@ -550,6 +553,12 @@ type WithDiscoverable interface {
 	SetTootDiscoverable(vocab.TootDiscoverableProperty)
 }
 
+// WithIndexable represents an activity with TootIndexableProperty
+type WithIndexable interface {
+	GetTootIndexable() vocab.TootIndexableProperty
+	SetTootIndexable(vocab.TootIndexableProperty)
+}
+
 // WithURL represents an activity with ActivityStreamsUrlProperty
 type WithURL interface {
 	GetActivityStreamsUrl() vocab.ActivityStreamsUrlProperty
@@ -808,12 +817,12 @@ type WithInteractionPolicy interface {
 	SetGoToSocialInteractionPolicy(vocab.GoToSocialInteractionPolicyProperty)
 }
 
-// WithPolicyRules represents an activity with always and approvalRequired properties.
+// WithPolicyRules represents interaction policy properties.
 type WithPolicyRules interface {
 	GetGoToSocialAutomaticApproval() vocab.GoToSocialAutomaticApprovalProperty
 	GetGoToSocialManualApproval() vocab.GoToSocialManualApprovalProperty
-	GetGoToSocialAlways() vocab.GoToSocialAlwaysProperty                     // Deprecated
-	GetGoToSocialApprovalRequired() vocab.GoToSocialApprovalRequiredProperty // Deprecated
+	GetGoToSocialAlways() vocab.GoToSocialAlwaysProperty                     // Deprecated - remove in v0.22.0
+	GetGoToSocialApprovalRequired() vocab.GoToSocialApprovalRequiredProperty // Deprecated - remove in v0.22.0
 }
 
 // WithApprovedBy represents an object with the approvedBy property.
