@@ -33,15 +33,19 @@ import (
 	another instance to dereference something.
 */
 
-// NormalizeIncomingActivityObject normalizes the 'object'.'content' field of the given Activity.
+// NormalizeIncomingActivity normalizes any
+// Statusables and Accountables in the 'object' and
+// 'instrument' fields of the given Activity.
 //
-// The rawActivity map should the freshly deserialized json representation of the Activity.
-//
-// This function is a noop if the type passed in is anything except a Create or Update with a Statusable or Accountable as its Object.
-func NormalizeIncomingActivity(activity pub.Activity, rawJSON map[string]interface{}) {
-	// From the activity extract the data vocab.Type + its "raw" JSON.
-	dataIfaces, rawData, ok := ExtractActivityData(activity, rawJSON)
-	if !ok || len(dataIfaces) != len(rawData) {
+// The rawJSON map should be the freshly
+// deserialized json representation of the Activity.
+func NormalizeIncomingActivity(
+	activity pub.Activity,
+	rawJSON map[string]any,
+) {
+	// From the activity extract the data vocab.Types + "rawData" JSON.
+	dataIfaces, rawData := ExtractActivityObjectsAndInstruments(activity, rawJSON)
+	if len(dataIfaces) != len(rawData) {
 		// non-equal lengths *shouldn't* happen,
 		// but this is just an integrity check.
 		return
@@ -114,7 +118,6 @@ func normalizeContent(rawContent interface{}) string {
 	// TODO: sanitize differently based on mediaType.
 	// https://www.w3.org/TR/activitystreams-vocabulary/#dfn-mediatype
 	content = text.SanitizeHTML(content)
-	content = text.MinifyHTML(content)
 	return content
 }
 
@@ -249,7 +252,6 @@ func NormalizeIncomingSummary(item WithSummary, rawJSON map[string]interface{})
 	// Summary should be HTML encoded:
 	// https://www.w3.org/TR/activitystreams-vocabulary/#dfn-summary
 	summary = text.SanitizeHTML(summary)
-	summary = text.MinifyHTML(summary)
 
 	// Set normalized summary property from the raw string; this
 	// will replace any existing summary property on the item.
@@ -378,13 +380,20 @@ func NormalizeIncomingValue(item WithValue, rawJSON map[string]interface{}) {
 	item.SetSchemaValue(valueProp)
 }
 
-// NormalizeIncomingOneOf normalizes all oneOf (if any) of the given
-// item, replacing the 'name' field of each oneOf with the raw 'name'
-// value from the raw json object map, and doing sanitization
-// on the result.
+// NormalizeIncomingOneOf normalizes all oneOf|anyOf (if any) of the given
+// item, replacing the 'name' field of each oneOf|anyOf with the raw 'name'
+// value from the raw json object map, and doing sanitization on the result.
 //
 // noop if there are no oneOf; noop if oneOf is not expected format.
-func NormalizeIncomingPollOptions(item WithOneOf, rawJSON map[string]interface{}) {
+func NormalizeIncomingPollOptions(item interface {
+	WithOneOf
+	WithAnyOf
+}, rawJSON map[string]interface{}) {
+	normalizeIncomingWithOneOf(item, rawJSON)
+	normalizeIncomingWithAnyOf(item, rawJSON)
+}
+
+func normalizeIncomingWithOneOf(item WithOneOf, rawJSON map[string]interface{}) {
 	var oneOf []interface{}
 
 	// Get the raw one-of JSON data.
@@ -404,7 +413,7 @@ func NormalizeIncomingPollOptions(item WithOneOf, rawJSON map[string]interface{}
 		return
 	}
 
-	// Check we have useable one-of JSON-vs-unmarshaled data.
+	// Check we have useable one-of JSON vs. unmarshaled data.
 	if l := oneOfProp.Len(); l == 0 || l != len(oneOf) {
 		return
 	}
@@ -435,6 +444,57 @@ func NormalizeIncomingPollOptions(item WithOneOf, rawJSON map[string]interface{}
 	}
 }
 
+func normalizeIncomingWithAnyOf(item WithAnyOf, rawJSON map[string]interface{}) {
+	var anyOf []interface{}
+
+	// Get the raw any-of JSON data.
+	rawAnyOf, ok := rawJSON["anyOf"]
+	if !ok {
+		return
+	}
+
+	// Convert to slice if not already, so we can iterate.
+	if anyOf, ok = rawAnyOf.([]interface{}); !ok {
+		anyOf = []interface{}{rawAnyOf}
+	}
+
+	// Extract the any-of property from interface.
+	anyOfProp := item.GetActivityStreamsAnyOf()
+	if anyOfProp == nil {
+		return
+	}
+
+	// Check we have useable any-of JSON vs. unmarshaled data.
+	if l := anyOfProp.Len(); l == 0 || l != len(anyOf) {
+		return
+	}
+
+	// Get start and end of iter.
+	start := anyOfProp.Begin()
+	end := anyOfProp.End()
+
+	// Iterate a counter, from start through to end iter item.
+	for i, iter := 0, start; iter != end; i, iter = i+1, iter.Next() {
+		// Get item type.
+		t := iter.GetType()
+
+		// Check fulfills Choiceable type
+		// (this accounts for nil input type).
+		choiceable, ok := t.(PollOptionable)
+		if !ok {
+			continue
+		}
+
+		// Get the corresponding raw one-of data.
+		rawChoice, ok := anyOf[i].(map[string]interface{})
+		if !ok {
+			continue
+		}
+
+		NormalizeIncomingName(choiceable, rawChoice)
+	}
+}
+
 /*
 	OUTGOING NORMALIZATION
 	The below functions should be called to normalize the content
@@ -463,21 +523,7 @@ func NormalizeIncomingPollOptions(item WithOneOf, rawJSON map[string]interface{}
 //
 // Noop for items with no attachments, or with attachments that are already a slice.
 func NormalizeOutgoingAttachmentProp(item WithAttachment, rawJSON map[string]interface{}) {
-	attachment, ok := rawJSON["attachment"]
-	if !ok {
-		// No 'attachment',
-		// nothing to change.
-		return
-	}
-
-	if _, ok := attachment.([]interface{}); ok {
-		// Already slice,
-		// nothing to change.
-		return
-	}
-
-	// Coerce single-object to slice.
-	rawJSON["attachment"] = []interface{}{attachment}
+	coercePropertyToArray(rawJSON, "attachment")
 }
 
 // NormalizeOutgoingAlsoKnownAsProp replaces single-entry alsoKnownAs values with
@@ -493,21 +539,7 @@ func NormalizeOutgoingAttachmentProp(item WithAttachment, rawJSON map[string]int
 //
 // Noop for items with no attachments, or with attachments that are already a slice.
 func NormalizeOutgoingAlsoKnownAsProp(item WithAlsoKnownAs, rawJSON map[string]interface{}) {
-	alsoKnownAs, ok := rawJSON["alsoKnownAs"]
-	if !ok {
-		// No 'alsoKnownAs',
-		// nothing to change.
-		return
-	}
-
-	if _, ok := alsoKnownAs.([]interface{}); ok {
-		// Already slice,
-		// nothing to change.
-		return
-	}
-
-	// Coerce single-object to slice.
-	rawJSON["alsoKnownAs"] = []interface{}{alsoKnownAs}
+	coercePropertyToArray(rawJSON, "alsoKnownAs")
 }
 
 // NormalizeOutgoingContentProp normalizes go-fed's funky formatting of content and
@@ -582,16 +614,13 @@ func NormalizeOutgoingContentProp(item WithContent, rawJSON map[string]interface
 //
 //	"interactionPolicy": {
 //		"canAnnounce": {
-//			"automaticApproval": "https://www.w3.org/ns/activitystreams#Public",
-//			"manualApproval": []
+//			"automaticApproval": "https://www.w3.org/ns/activitystreams#Public"
 //		},
 //		"canLike": {
-//			"automaticApproval": "https://www.w3.org/ns/activitystreams#Public",
-//			"manualApproval": []
+//			"automaticApproval": "https://www.w3.org/ns/activitystreams#Public"
 //		},
 //		"canReply": {
-//			"automaticApproval": "https://www.w3.org/ns/activitystreams#Public",
-//			"manualApproval": []
+//			"automaticApproval": "https://www.w3.org/ns/activitystreams#Public"
 //		}
 //	}
 //
@@ -601,24 +630,21 @@ func NormalizeOutgoingContentProp(item WithContent, rawJSON map[string]interface
 //		"canAnnounce": {
 //			"automaticApproval": [
 //				"https://www.w3.org/ns/activitystreams#Public"
-//			],
-//			"manualApproval": []
+//			]
 //		},
 //		"canLike": {
 //			"automaticApproval": [
 //				"https://www.w3.org/ns/activitystreams#Public"
-//			],
-//			"manualApproval": []
+//			]
 //		},
 //		"canReply": {
 //			"automaticApproval": [
 //				"https://www.w3.org/ns/activitystreams#Public"
-//			],
-//			"manualApproval": []
+//			]
 //		}
 //	}
 //
-// Noop for items with no attachments, or with attachments that are already a slice.
+// Noop for items with no interaction policies, or with policies that are already a slice.
 func NormalizeOutgoingInteractionPolicyProp(item WithInteractionPolicy, rawJSON map[string]interface{}) {
 	policy, ok := rawJSON["interactionPolicy"]
 	if !ok {
@@ -638,43 +664,18 @@ func NormalizeOutgoingInteractionPolicyProp(item WithInteractionPolicy, rawJSON
 		"canLike",
 		"canReply",
 		"canAnnounce",
+		"canQuote",
 	} {
-		// Either "canAnnounce",
-		// "canLike", or "canApprove"
-		rulesVal, ok := policyMap[rulesKey]
-		if !ok {
-			// Not set.
-			return
-		}
-
-		rulesValMap, ok := rulesVal.(map[string]interface{})
+		rulesValMap, ok := policyMap[rulesKey].(map[string]interface{})
 		if !ok {
 			// Malformed or not
-			// present skip.
+			// present, skip it.
 			return
 		}
 
-		for _, PolicyValuesKey := range []string{
-			"automaticApproval",
-			"manualApproval",
-			"always",           // deprecated
-			"approvalRequired", // deprecated
-		} {
-			PolicyValuesVal, ok := rulesValMap[PolicyValuesKey]
-			if !ok {
-				// Not set.
-				continue
-			}
-
-			if _, ok := PolicyValuesVal.([]interface{}); ok {
-				// Already slice,
-				// nothing to change.
-				continue
-			}
-
-			// Coerce single-object to slice.
-			rulesValMap[PolicyValuesKey] = []interface{}{PolicyValuesVal}
-		}
+		// Coerce single objects to arrays.
+		coercePropertyToArray(rulesValMap, "automaticApproval")
+		coercePropertyToArray(rulesValMap, "manualApproval")
 	}
 }
 
@@ -768,3 +769,140 @@ func NormalizeOutgoingObjectProp(item WithObject, rawJSON map[string]interface{}
 
 	return nil
 }
+
+// NormalizeOutgoingInstrumentProp normalizes each Instrument entry in the rawJSON of the given
+// item by calling custom serialization / normalization functions on them in turn.
+//
+// This function also unnests single-entry arrays, so that:
+//
+//	"instrument": [
+//	  {
+//	    ...
+//	  }
+//	]
+//
+// Becomes:
+//
+//	"instrument": {
+//	  ...
+//	}
+//
+// Noop for each Instrument entry that isn't an Accountable or Statusable.
+func NormalizeOutgoingInstrumentProp(item WithInstrument, rawJSON map[string]interface{}) error {
+	instrumentProp := item.GetActivityStreamsInstrument()
+	if instrumentProp == nil {
+		// Nothing to do,
+		// bail early.
+		return nil
+	}
+
+	instrumentPropLen := instrumentProp.Len()
+	if instrumentPropLen == 0 {
+		// Nothing to do,
+		// bail early.
+		return nil
+	}
+
+	// The thing we already serialized has instruments
+	// on it, so we should see if we need to custom
+	// serialize any of those instruments, and replace
+	// them on the data map as necessary.
+	instruments := make([]interface{}, 0, instrumentPropLen)
+	for iter := instrumentProp.Begin(); iter != instrumentProp.End(); iter = iter.Next() {
+		if iter.IsIRI() {
+			// Plain IRIs don't need custom serialization.
+			instruments = append(instruments, iter.GetIRI().String())
+			continue
+		}
+
+		var (
+			instrumentType = iter.GetType()
+			instrumentSer  map[string]interface{}
+		)
+
+		if instrumentType == nil {
+			// This is awkward.
+			return gtserror.Newf("could not resolve instrument iter %T to vocab.Type", iter)
+		}
+
+		var err error
+
+		// In the below statusable serialization,
+		// `@context` will be included in the wrapping
+		// type already, so we shouldn't also include
+		// it in the instrument itself.
+		switch tn := instrumentType.GetTypeName(); {
+		case IsStatusable(tn):
+			// IsStatusable includes Pollable as well.
+			instrumentSer, err = serializeStatusable(instrumentType, false)
+
+		default:
+			// No custom serializer for this type; serialize as normal.
+			instrumentSer, err = instrumentType.Serialize()
+		}
+
+		if err != nil {
+			return err
+		}
+
+		instruments = append(instruments, instrumentSer)
+	}
+
+	if instrumentPropLen == 1 {
+		// Unnest single instrument.
+		rawJSON["instrument"] = instruments[0]
+	} else {
+		// Array of instruments.
+		rawJSON["instrument"] = instruments
+	}
+
+	return nil
+}
+
+// NormalizeOutgoingOneOrAnyOfProp replaces single-entry oneOf or anyOf values
+// with single-entry arrays, for better compatibility with other AP implementations.
+//
+// Ie:
+//
+//	"oneOf": {}
+//
+// or
+//
+//	"anyOf": {}
+//
+// becomes:
+//
+//	"oneOf": [{}]
+//
+// or
+//
+//	"anyOf": [{}]
+//
+// Noop for items with no interaction policies, or with policies that are already a slice.
+func NormalizeOutgoingOneOrAnyOfProp(item interface {
+	WithOneOf
+	WithAnyOf
+}, rawJSON map[string]interface{}) {
+	coercePropertyToArray(rawJSON, "oneOf")
+	coercePropertyToArray(rawJSON, "anyOf")
+}
+
+// coercePropertyToArray coerces the property contained at key in map
+// to an array if it isn't already, i.e. if not an []interface{} type.
+func coercePropertyToArray(data map[string]interface{}, key string) {
+	property, ok := data[key]
+	if !ok {
+		// No key found,
+		// nothing to change.
+		return
+	}
+
+	if _, ok := property.([]interface{}); ok {
+		// Already
+		// a slice.
+		return
+	}
+
+	// Coerce single-object to slice.
+	data[key] = []interface{}{property}
+}
