@@ -18,12 +18,9 @@
 package users
 
 import (
-	"errors"
 	"net/http"
-	"strings"
 
 	apiutil "code.superseriousbusiness.org/gotosocial/internal/api/util"
-	"code.superseriousbusiness.org/gotosocial/internal/gtserror"
 	"code.superseriousbusiness.org/gotosocial/internal/paging"
 	"github.com/gin-gonic/gin"
 )
@@ -91,24 +88,15 @@ import (
 //				"$ref": "#/definitions/error"
 //			description: not found
 func (m *Module) OutboxGETHandler(c *gin.Context) {
-	// usernames on our instance are always lowercase
-	requestedUser := strings.ToLower(c.Param(apiutil.UsernameKey))
-	if requestedUser == "" {
-		err := errors.New("no username specified in request")
-		apiutil.ErrorHandler(c, gtserror.NewErrorBadRequest(err, err.Error()), m.processor.InstanceGetV1)
+	username, contentType, errWithCode := m.parseCommon(c)
+	if errWithCode != nil {
+		apiutil.ErrorHandler(c, errWithCode, m.processor.InstanceGetV1)
 		return
 	}
 
-	contentType, err := apiutil.NegotiateAccept(c, apiutil.ActivityPubOrHTMLHeaders...)
-	if err != nil {
-		apiutil.ErrorHandler(c, gtserror.NewErrorNotAcceptable(err, err.Error()), m.processor.InstanceGetV1)
-		return
-	}
-
-	if contentType == string(apiutil.TextHTML) {
-		// This isn't an ActivityPub request;
-		// redirect to the user's profile.
-		c.Redirect(http.StatusSeeOther, "/@"+requestedUser)
+	if contentType == apiutil.TextHTML {
+		// Redirect to account web view.
+		c.Redirect(http.StatusSeeOther, "/@"+username)
 		return
 	}
 
@@ -122,7 +110,7 @@ func (m *Module) OutboxGETHandler(c *gin.Context) {
 		return
 	}
 
-	resp, errWithCode := m.processor.Fedi().OutboxGet(c.Request.Context(), requestedUser, page)
+	resp, errWithCode := m.processor.Fedi().OutboxGet(c.Request.Context(), username, page)
 	if errWithCode != nil {
 		apiutil.ErrorHandler(c, errWithCode, m.processor.InstanceGetV1)
 		return
