@@ -28,6 +28,7 @@ import (
 	"code.superseriousbusiness.org/gotosocial/internal/api/client/bookmarks"
 	"code.superseriousbusiness.org/gotosocial/internal/api/client/conversations"
 	"code.superseriousbusiness.org/gotosocial/internal/api/client/customemojis"
+	"code.superseriousbusiness.org/gotosocial/internal/api/client/debug"
 	"code.superseriousbusiness.org/gotosocial/internal/api/client/exports"
 	"code.superseriousbusiness.org/gotosocial/internal/api/client/favourites"
 	"code.superseriousbusiness.org/gotosocial/internal/api/client/featuredtags"
@@ -78,6 +79,7 @@ type Client struct {
 	bookmarks           *bookmarks.Module           // api/v1/bookmarks
 	conversations       *conversations.Module       // api/v1/conversations
 	customEmojis        *customemojis.Module        // api/v1/custom_emojis
+	debug               *debug.Module               // api/v1/debug
 	exports             *exports.Module             // api/v1/exports
 	favourites          *favourites.Module          // api/v1/favourites
 	featuredTags        *featuredtags.Module        // api/v1/featured_tags
@@ -135,6 +137,7 @@ func (c *Client) Route(r *router.Router, m ...gin.HandlerFunc) {
 	c.bookmarks.Route(h)
 	c.conversations.Route(h)
 	c.customEmojis.Route(h)
+	c.debug.Route(h)
 	c.exports.Route(h)
 	c.favourites.Route(h)
 	c.featuredTags.Route(h)
@@ -180,6 +183,7 @@ func NewClient(state *state.State, p *processing.Processor) *Client {
 		bookmarks:           bookmarks.New(p),
 		conversations:       conversations.New(p),
 		customEmojis:        customemojis.New(p),
+		debug:               debug.New(state, p),
 		exports:             exports.New(p),
 		favourites:          favourites.New(p),
 		featuredTags:        featuredtags.New(p),
