@@ -23,7 +23,6 @@ import (
 	apiutil "code.superseriousbusiness.org/gotosocial/internal/api/util"
 	"code.superseriousbusiness.org/gotosocial/internal/processing"
 	"code.superseriousbusiness.org/gotosocial/internal/state"
-	"codeberg.org/gruf/go-debug"
 	"github.com/gin-gonic/gin"
 )
 
@@ -36,6 +35,8 @@ const (
 	DomainBlocksPathWithID                   = DomainBlocksPath + "/:" + apiutil.IDKey
 	DomainAllowsPath                         = BasePath + "/domain_allows"
 	DomainAllowsPathWithID                   = DomainAllowsPath + "/:" + apiutil.IDKey
+	DomainLimitsPath                         = BasePath + "/domain_limits"
+	DomainLimitsPathWithID                   = DomainLimitsPath + "/:" + apiutil.IDKey
 	DomainPermissionDraftsPath               = BasePath + "/domain_permission_drafts"
 	DomainPermissionDraftsPathWithID         = DomainPermissionDraftsPath + "/:" + apiutil.IDKey
 	DomainPermissionDraftAcceptPath          = DomainPermissionDraftsPathWithID + "/accept"
@@ -59,6 +60,7 @@ const (
 	AccountsApprovePath                      = AccountsPathWithID + "/approve"
 	AccountsRejectPath                       = AccountsPathWithID + "/reject"
 	MediaCleanupPath                         = BasePath + "/media_cleanup"
+	MediaPurgePath                           = BasePath + "/media_purge"
 	MediaRefetchPath                         = BasePath + "/media_refetch"
 	ReportsPath                              = BasePath + "/reports"
 	ReportsPathWithID                        = ReportsPath + "/:" + apiutil.IDKey
@@ -67,9 +69,6 @@ const (
 	EmailTestPath                            = EmailPath + "/test"
 	InstanceRulesPath                        = BasePath + "/instance/rules"
 	InstanceRulesPathWithID                  = InstanceRulesPath + "/:" + apiutil.IDKey
-	DebugPath                                = BasePath + "/debug"
-	DebugAPUrlPath                           = DebugPath + "/apurl"
-	DebugClearCachesPath                     = DebugPath + "/caches/clear"
 
 	FilterQueryKey        = "filter"
 	MaxShortcodeDomainKey = "max_shortcode_domain"
@@ -112,6 +111,12 @@ func (m *Module) Route(attachHandler func(method string, path string, f ...gin.H
 	attachHandler(http.MethodPut, DomainAllowsPathWithID, m.DomainAllowUpdatePUTHandler)
 	attachHandler(http.MethodDelete, DomainAllowsPathWithID, m.DomainAllowDELETEHandler)
 
+	// domain limits stuff
+	attachHandler(http.MethodGet, DomainLimitsPath, m.DomainLimitsGETHandler)
+	attachHandler(http.MethodPost, DomainLimitsPath, m.DomainLimitsPOSTHandler)
+	attachHandler(http.MethodPut, DomainLimitsPathWithID, m.DomainLimitPUTHandler)
+	attachHandler(http.MethodDelete, DomainLimitsPathWithID, m.DomainLimitDELETEHandler)
+
 	// domain permission draft stuff
 	attachHandler(http.MethodPost, DomainPermissionDraftsPath, m.DomainPermissionDraftsPOSTHandler)
 	attachHandler(http.MethodGet, DomainPermissionDraftsPath, m.DomainPermissionDraftsGETHandler)
@@ -157,6 +162,7 @@ func (m *Module) Route(attachHandler func(method string, path string, f ...gin.H
 
 	// media stuff
 	attachHandler(http.MethodPost, MediaCleanupPath, m.MediaCleanupPOSTHandler)
+	attachHandler(http.MethodPost, MediaPurgePath, m.MediaPurgePOSTHandler)
 	attachHandler(http.MethodPost, MediaRefetchPath, m.MediaRefetchPOSTHandler)
 
 	// reports stuff
@@ -173,10 +179,4 @@ func (m *Module) Route(attachHandler func(method string, path string, f ...gin.H
 	attachHandler(http.MethodPost, InstanceRulesPath, m.RulePOSTHandler)
 	attachHandler(http.MethodPatch, InstanceRulesPathWithID, m.RulePATCHHandler)
 	attachHandler(http.MethodDelete, InstanceRulesPathWithID, m.RuleDELETEHandler)
-
-	// debug stuff
-	if debug.DEBUG {
-		attachHandler(http.MethodGet, DebugAPUrlPath, m.DebugAPUrlHandler)
-		attachHandler(http.MethodPost, DebugClearCachesPath, m.DebugClearCachesHandler)
-	}
 }
