@@ -18,6 +18,7 @@
 package admin
 
 import (
+	"errors"
 	"fmt"
 	"net/http"
 
@@ -100,23 +101,26 @@ func (m *Module) MediaCleanupPOSTHandler(c *gin.Context) {
 		return
 	}
 
-	form := &apimodel.MediaCleanupRequest{}
+	form := new(apimodel.MediaCleanupRequest)
 	if err := c.ShouldBind(form); err != nil {
 		apiutil.ErrorHandler(c, gtserror.NewErrorBadRequest(err, err.Error()), m.processor.InstanceGetV1)
 		return
 	}
 
+	// Normalize remoteCacheDays.
 	var remoteCacheDays int
 	if form.RemoteCacheDays == nil {
 		remoteCacheDays = config.GetMediaRemoteCacheDays()
-	} else {
-		remoteCacheDays = *form.RemoteCacheDays
-	}
-	if remoteCacheDays < 0 {
-		remoteCacheDays = 0
+	} else if remoteCacheDays = *form.RemoteCacheDays; remoteCacheDays < 0 {
+		text := fmt.Sprintf("invalid value for remote_cache_days; value was %d, cannot be less than 0", remoteCacheDays)
+		apiutil.ErrorHandler(c, gtserror.NewErrorBadRequest(errors.New(text), text), m.processor.InstanceGetV1)
+		return
 	}
 
-	if errWithCode := m.processor.Admin().MediaPrune(c.Request.Context(), remoteCacheDays); errWithCode != nil {
+	if errWithCode := m.processor.Admin().MediaPrune(
+		c.Request.Context(),
+		remoteCacheDays,
+	); errWithCode != nil {
 		apiutil.ErrorHandler(c, errWithCode, m.processor.InstanceGetV1)
 		return
 	}
