@@ -48,6 +48,11 @@ type Account struct {
 	Locked bool `json:"locked"`
 	// Account has opted into discovery features.
 	Discoverable bool `json:"discoverable"`
+	// Account has opted its posts into full-text search features.
+	Indexable bool `json:"indexable"`
+	// Account has *not* opted its posts into full-text search features.
+	// Opposite sense of Indexable for compatibility with `masto-fe-standalone`.
+	NoIndex bool `json:"noindex"`
 	// Account identifies as a bot.
 	Bot bool `json:"bot"`
 	// When the account was created (ISO 8601 Datetime).
@@ -191,11 +196,10 @@ type AccountCreateRequest struct {
 	// swagger:parameters
 	// required: true
 	Agreement bool `form:"agreement"  json:"agreement" xml:"agreement" binding:"required"`
-	// The language of the confirmation email that will be sent.
+	// The preferred language of the account user (optional).
 	// swagger:parameters
 	// example: en
-	// Required: true
-	Locale string `form:"locale" json:"locale" xml:"locale" binding:"required"`
+	Locale string `form:"locale" json:"locale" xml:"locale"`
 	// The IP of the sign up request, will not be parsed from the form.
 	// swagger:parameters
 	// swagger:ignore
@@ -208,6 +212,8 @@ type AccountCreateRequest struct {
 type UpdateCredentialsRequest struct {
 	// Account should be made discoverable and shown in the profile directory (if enabled).
 	Discoverable *bool `form:"discoverable" json:"discoverable"`
+	// Account should be made indexable and opted into full-text search (if enabled).
+	Indexable *bool `form:"indexable" json:"indexable"`
 	// Account is flagged as a bot.
 	Bot *bool `form:"bot" json:"bot"`
 	// The display name to use for the account.
@@ -247,6 +253,8 @@ type UpdateCredentialsRequest struct {
 	// "microblog": default, classic microblog layout.
 	// "gallery": gallery layout with media only.
 	WebLayout *string `form:"web_layout" json:"web_layout"`
+	// Include boosts created by the account on the web view of the account.
+	WebIncludeBoosts *bool `form:"web_include_boosts" json:"web_include_boosts"`
 }
 
 // UpdateSource is to be used specifically in an UpdateCredentialsRequest.
