@@ -78,9 +78,11 @@ type AttachmentAttributesRequest struct {
 //
 // swagger:model attachment
 type Attachment struct {
+
 	// The ID of the attachment.
 	// example: 01FC31DZT1AYWDZ8XTCRWRBYRK
 	ID string `json:"id"`
+
 	// The type of the attachment.
 	// enum:
 	//   - unknown
@@ -90,31 +92,43 @@ type Attachment struct {
 	//   - audio
 	// example: image
 	Type string `json:"type"`
+
 	// The location of the original full-size attachment.
 	// example: https://example.org/fileserver/some_id/attachments/some_id/original/attachment.jpeg
 	URL *string `json:"url"`
+
 	// A shorter URL for the attachment.
 	// In our case, we just give the URL again since we don't create smaller URLs.
 	TextURL *string `json:"text_url"`
+
 	// The location of a scaled-down preview of the attachment.
 	// example: https://example.org/fileserver/some_id/attachments/some_id/small/attachment.jpeg
 	PreviewURL *string `json:"preview_url"`
+
 	// The location of the full-size original attachment on the remote server.
 	// Only defined for instances other than our own.
 	// example: https://some-other-server.org/attachments/original/ahhhhh.jpeg
 	RemoteURL *string `json:"remote_url"`
+
 	// The location of a scaled-down preview of the attachment on the remote server.
 	// Only defined for instances other than our own.
 	// example: https://some-other-server.org/attachments/small/ahhhhh.jpeg
 	PreviewRemoteURL *string `json:"preview_remote_url"`
+
 	// Metadata for this attachment.
 	Meta *MediaMeta `json:"meta"`
+
 	// Alt text that describes what is in the media attachment.
 	// example: This is a picture of a kitten.
 	Description *string `json:"description"`
+
 	// A hash computed by the BlurHash algorithm, for generating colorful preview thumbnails when media has not been downloaded yet.
 	// See https://github.com/woltapp/blurhash
 	Blurhash *string `json:"blurhash"`
+
+	// Error encountered while fetching remote media, if any.
+	// example: network timeout
+	Error *string `json:"error,omitempty"`
 }
 
 // WebAttachment is like Attachment, but with
