@@ -35,6 +35,8 @@ type Source struct {
 	//    "microblog": default, classic microblog layout.
 	//    "gallery": gallery layout with media only.
 	WebLayout string `json:"web_layout"`
+	// Include boosts created by the account on the web view of the account.
+	WebIncludeBoosts bool `json:"web_include_boosts"`
 	// Whether new statuses should be marked sensitive by default.
 	Sensitive bool `json:"sensitive"`
 	// The default posting language for new statuses.
