@@ -63,10 +63,6 @@ const (
 
 	TagNameKey = "tag_name"
 
-	/* Web endpoint keys */
-
-	WebStatusIDKey = "status"
-
 	/* Domain permission keys */
 
 	DomainPermissionExportKey         = "export"
@@ -101,6 +97,10 @@ const (
 	InteractionFavouritesKey = "favourites"
 	InteractionRepliesKey    = "replies"
 	InteractionReblogsKey    = "reblogs"
+
+	/* Web view keys */
+
+	WebIncludeBoostsKey = "include_boosts"
 )
 
 /*
@@ -216,6 +216,10 @@ func ParseInteractionReblogs(value string, defaultValue bool) (bool, gtserror.Wi
 	return parseBool(value, defaultValue, InteractionReblogsKey)
 }
 
+func ParseWebIncludeBoosts(value string, defaultValue *bool) (*bool, gtserror.WithCode) {
+	return parseBoolPtr(value, defaultValue, WebIncludeBoostsKey)
+}
+
 /*
 	Parse functions for *REQUIRED* parameters.
 */
@@ -247,6 +251,9 @@ func ParseID(value string) (string, gtserror.WithCode) {
 		return "", requiredError(key)
 	}
 
+	// ULIDs are always uppercase.
+	value = strings.ToUpper(value)
+
 	return value, nil
 }
 
@@ -287,15 +294,10 @@ func ParseUsername(value string) (string, gtserror.WithCode) {
 		return "", requiredError(key)
 	}
 
-	return value, nil
-}
-
-func ParseWebStatusID(value string) (string, gtserror.WithCode) {
-	key := WebStatusIDKey
-
-	if value == "" {
-		return "", requiredError(key)
-	}
+	// Usernames on our instance are always lowercase.
+	// TODO: Update this when we allow different cases etc.
+	// See: https://codeberg.org/superseriousbusiness/gotosocial/issues/1813
+	value = strings.ToLower(value)
 
 	return value, nil
 }
