@@ -18,8 +18,8 @@
 package cache
 
 import (
+	"code.superseriousbusiness.org/gotosocial/internal/cache/timeline"
 	"code.superseriousbusiness.org/gotosocial/internal/gtsmodel"
-	"code.superseriousbusiness.org/gotosocial/internal/util"
 )
 
 // Below are cache invalidation hooks between other caches,
@@ -216,6 +216,16 @@ func (c *Caches) OnInvalidateFollow(follow *gtsmodel.Follow) {
 		// list entries for follow.
 		"f"+follow.ID,
 	)
+
+	// Invalidate the status filter cache, as it
+	// checks follow relationships when applying
+	// limit Statuses policy filter results.
+	c.StatusFilter.Invalidate("RequesterID", follow.AccountID)
+
+	// Invalidate the mutes cache, as it checks
+	// follow relationships when applying limit
+	// Accounts policy mute results.
+	c.Mutes.Invalidate("RequesterID", follow.AccountID)
 }
 
 func (c *Caches) OnInvalidateFollowRequest(followReq *gtsmodel.FollowRequest) {
@@ -350,7 +360,7 @@ func (c *Caches) OnInvalidateStatus(status *gtsmodel.Status) {
 		c.DB.Poll.Invalidate("ID", status.PollID)
 	}
 
-	if util.PtrOrZero(status.Local) {
+	if status.Local != nil && *status.Local {
 		// Invalidate the local statuses count.
 		c.DB.LocalInstance.Statuses.Store(nil)
 	}
@@ -403,3 +413,31 @@ func (c *Caches) OnInvalidateWebPushSubscription(subscription *gtsmodel.WebPushS
 	// Invalidate source account's Web Push subscription list.
 	c.DB.WebPushSubscriptionIDs.Invalidate(subscription.AccountID)
 }
+
+func (c *Caches) OnInvalidateDomainLimit(domainLimit *gtsmodel.DomainLimit) {
+	// Clear the StatusFilter cache, as
+	// the invalidated limit may affect
+	// filtering via a StatusesPolicy.
+	c.StatusFilter.Clear()
+
+	// Clear the Mutes cache, as the
+	// invalidated limit may affect
+	// mutes via an AccountsPolicy.
+	c.Mutes.Clear()
+
+	// Clear all timelines, as filtering
+	// of prepared statuses for the limited
+	// domain may have changed and we don't
+	// want to include "hide" result statuses.
+	for _, timeline := range []*timeline.StatusTimelines{
+		&c.Timelines.Home,
+		&c.Timelines.List,
+		&c.Timelines.Tag,
+	} {
+		timeline.ClearAll()
+	}
+
+	// Clear public timeline
+	// for the same reason.
+	c.Timelines.Public.Clear()
+}
