@@ -189,6 +189,7 @@ func sizeofAccount() uintptr {
 		FetchedAt:               exampleTime,
 		Locked:                  util.Ptr(true),
 		Discoverable:            util.Ptr(false),
+		Indexable:               util.Ptr(false),
 		URI:                     exampleURI,
 		URL:                     exampleURI,
 		InboxURI:                exampleURI,
@@ -295,6 +296,19 @@ func sizeofDomainPermissionDraft() uintptr {
 	}))
 }
 
+func sizeofDomainLimit() uintptr {
+	return uintptr(size.Of(&gtsmodel.DomainLimit{
+		ID:                 exampleID,
+		Domain:             "example.org",
+		CreatedByAccountID: exampleID,
+		PrivateComment:     exampleTextSmall,
+		PublicComment:      exampleTextSmall,
+		MediaPolicy:        gtsmodel.MediaPolicyNoAction,
+		FollowsPolicy:      gtsmodel.FollowsPolicyNoAction,
+		ContentWarning:     exampleTextSmall,
+	}))
+}
+
 func sizeofDomainPermissionSubscription() uintptr {
 	return uintptr(size.Of(&gtsmodel.DomainPermissionSubscription{
 		ID:                    exampleID,
@@ -334,7 +348,6 @@ func sizeofEmoji() uintptr {
 		URI:                    "http://localhost:8080/emoji/01F8MH9H8E4VG3KDYJR9EGPXCQ",
 		VisibleInPicker:        func() *bool { ok := true; return &ok }(),
 		CategoryID:             "01GGQ8V4993XK67B2JB396YFB7",
-		Cached:                 func() *bool { ok := true; return &ok }(),
 	}))
 }
 
@@ -476,7 +489,6 @@ func sizeofMedia() uintptr {
 		},
 		Avatar: func() *bool { ok := false; return &ok }(),
 		Header: func() *bool { ok := false; return &ok }(),
-		Cached: func() *bool { ok := true; return &ok }(),
 	}))
 }
 
