@@ -20,13 +20,15 @@ package cleaner
 import (
 	"context"
 	"errors"
+	"net/netip"
 	"time"
 
+	"code.superseriousbusiness.org/gopkg/log"
 	"code.superseriousbusiness.org/gotosocial/internal/db"
 	"code.superseriousbusiness.org/gotosocial/internal/gtscontext"
 	"code.superseriousbusiness.org/gotosocial/internal/gtserror"
 	"code.superseriousbusiness.org/gotosocial/internal/gtsmodel"
-	"code.superseriousbusiness.org/gotosocial/internal/log"
+	"code.superseriousbusiness.org/gotosocial/internal/id"
 	"code.superseriousbusiness.org/gotosocial/internal/media"
 	"code.superseriousbusiness.org/gotosocial/internal/paging"
 	"code.superseriousbusiness.org/gotosocial/internal/regexes"
@@ -35,7 +37,7 @@ import (
 
 // Media encompasses a set of
 // media cleanup / admin utils.
-type Media struct{ *Cleaner }
+type Media struct{ Cleaner }
 
 // All will execute all cleaner.Media utilities synchronously, including output logging.
 // Context will be checked for `gtscontext.DryRun()` in order to actually perform the action.
@@ -64,6 +66,16 @@ func (m *Media) LogUncacheRemote(ctx context.Context, olderThan time.Time) {
 	}
 }
 
+// LogPurgeRemote performs Media.PurgeRemote(...), logging the start and outcome.
+func (m *Media) LogPurgeRemote(ctx context.Context, domain string) {
+	log.Infof(ctx, "start purge domain: %s", domain)
+	if n, err := m.PurgeRemote(ctx, domain); err != nil {
+		log.Error(ctx, err)
+	} else {
+		log.Infof(ctx, "purged: %d", n)
+	}
+}
+
 // LogPruneOrphaned performs Media.PruneOrphaned(...), logging the start and outcome.
 func (m *Media) LogPruneOrphaned(ctx context.Context) {
 	log.Info(ctx, "start")
@@ -132,12 +144,11 @@ func (m *Media) PruneOrphaned(ctx context.Context) (int, error) {
 // Media is marked as unused if not attached to any status, account or account is suspended.
 // Context will be checked for `gtscontext.DryRun()` in order to actually perform the action.
 func (m *Media) PruneUnused(ctx context.Context) (int, error) {
-	var (
-		total int
-		page  paging.Page
-	)
+	var total int
+	var page paging.Page
 
-	// Set page select limit.
+	// Setup page w/ select limit.
+	page.Max = paging.MaxID("")
 	page.Limit = selectLimit
 
 	for {
@@ -157,7 +168,7 @@ func (m *Media) PruneUnused(ctx context.Context) (int, error) {
 
 		// Use last ID as the next 'maxID' value.
 		maxID = attachments[len(attachments)-1].ID
-		page.Max = paging.MaxID(maxID)
+		page.Max.Value = maxID
 
 		for _, media := range attachments {
 			// Check / prune unused media attachment.
@@ -181,33 +192,42 @@ func (m *Media) PruneUnused(ctx context.Context) (int, error) {
 // Context will be checked for `gtscontext.DryRun()` in order to actually perform the action.
 func (m *Media) UncacheRemote(ctx context.Context, olderThan time.Time) (int, error) {
 	var total int
+	var page paging.Page
+
+	// Setup page w/ select limit.
+	page.Max = paging.MaxID("")
+	page.Limit = selectLimit
 
 	// Drop time by a minute to improve search,
 	// (i.e. make it olderThan inclusive search).
 	olderThan = olderThan.Add(-time.Minute)
 
-	// Store recent time.
-	mostRecent := olderThan
+	// Get ULID for 'olderThan' to use as maxID.
+	olderThanID := id.ZeroULIDForTime(olderThan)
+	page.Max.Value = olderThanID
 
 	for {
-		// Fetch the next batch of cached attachments older than last-set time.
-		attachments, err := m.state.DB.GetCachedAttachmentsOlderThan(ctx, olderThan, selectLimit)
+		// Fetch the next batch of cached attachments older than maxID.
+		attachments, err := m.state.DB.GetCachedAttachments(ctx, &page)
 		if err != nil && !errors.Is(err, db.ErrNoEntries) {
 			return total, gtserror.Newf("error getting remote attachments: %w", err)
 		}
 
-		// If no attachments / same group is returned, we reached the end.
-		if len(attachments) == 0 ||
-			olderThan.Equal(attachments[len(attachments)-1].CreatedAt) {
+		// Get current max ID.
+		maxID := page.Max.Value
+
+		// If no attachments or the same group is returned, we reached the end.
+		if len(attachments) == 0 || maxID == attachments[len(attachments)-1].ID {
 			break
 		}
 
-		// Use last created-at as the next 'olderThan' value.
-		olderThan = attachments[len(attachments)-1].CreatedAt
+		// Use last ID as the next 'maxID' value.
+		maxID = attachments[len(attachments)-1].ID
+		page.Max.Value = maxID
 
 		for _, media := range attachments {
-			// Check / uncache each remote media attachment.
-			uncached, err := m.uncacheRemote(ctx, mostRecent, media)
+			// Check and try uncache each remote media attachment.
+			uncached, err := m.uncacheRemote(ctx, olderThan, media)
 			if err != nil {
 				return total, err
 			}
@@ -223,16 +243,150 @@ func (m *Media) UncacheRemote(ctx context.Context, olderThan time.Time) (int, er
 	return total, nil
 }
 
+// PurgeRemote stubs + uncaches all remote media from the given domain.
+// Context will be checked for `gtscontext.DryRun()` in order to actually perform the action.
+func (m *Media) PurgeRemote(ctx context.Context, domain string) (int, error) {
+	var total int
+	var page paging.Page
+
+	// Setup page w/ select limit.
+	page.Max = paging.MaxID("")
+	page.Limit = selectLimit
+
+	for {
+		// Get (next) page of accounts for domain.
+		accounts, err := m.state.DB.GetAccounts(
+			gtscontext.SetBarebones(ctx),
+			"",           // origin
+			"",           // status
+			false,        // mods
+			"",           // invitedBy
+			"",           // username
+			"",           // displayName
+			domain,       // domain
+			"",           // email
+			netip.Addr{}, // ip
+			&page,
+		)
+		if err != nil && !errors.Is(err, db.ErrNoEntries) {
+			return total, gtserror.Newf("db error getting accounts: %w", err)
+		}
+
+		count := len(accounts)
+		if count == 0 {
+			// We're done.
+			break
+		}
+
+		// Set params for next page.
+		loAcct := accounts[count-1]
+		lo := loAcct.Domain + "/@" + loAcct.Username
+		page.Max.Value = lo
+
+		// For each account, stub all
+		// that account's attachments.
+		for _, account := range accounts {
+			t, err := m.stubAccountAttachments(ctx, account.ID)
+			if err != nil {
+				return total, err
+			}
+			total += t
+		}
+	}
+
+	return total, nil
+}
+
+// stubAccountAttachments stubs all attachments belonging to the given accountID.
+func (m *Media) stubAccountAttachments(ctx context.Context, accountID string) (int, error) {
+	var total int
+	var page paging.Page
+
+	// Setup page w/ select limit.
+	page.Max = paging.MaxID("")
+	page.Limit = selectLimit
+
+	for {
+		// Get (next) page of attachments from db for the account.
+		attachments, err := m.state.DB.GetAttachmentsByAccountID(
+			ctx,
+			accountID,
+			&page,
+		)
+		if err != nil && !errors.Is(err, db.ErrNoEntries) {
+			return total, gtserror.Newf("db error getting attachments: %w", err)
+		}
+
+		// Get current max ID.
+		maxID := page.Max.Value
+
+		// If no attachments or the same group is returned, we reached the end.
+		if len(attachments) == 0 || maxID == attachments[len(attachments)-1].ID {
+			break
+		}
+
+		// Use last ID as the next 'maxID' value.
+		maxID = attachments[len(attachments)-1].ID
+		page.Max.Value = maxID
+
+		total += len(attachments)
+		if gtscontext.DryRun(ctx) {
+			// If this is a dry run, just increment
+			// the total by the attachment count
+			// without actually doing anything.
+			continue
+		}
+
+		// Stub each attachment by removing it
+		// from storage, and stubbing it fields,
+		// leaving description, blurhash, and
+		// remoteURL metadata in place.
+		for _, a := range attachments {
+			if err := m.stubAttachment(ctx, a); err != nil {
+				return total, err
+			}
+		}
+	}
+
+	return total, nil
+}
+
+// stubAttachment removes stored media and stubs all available fields for given attachment.
+func (m *Media) stubAttachment(ctx context.Context, a *gtsmodel.MediaAttachment) error {
+
+	// Remove any attachment files.
+	if _, err := m.removeFiles(ctx,
+		a.Thumbnail.Path,
+		a.File.Path,
+	); err != nil {
+		log.Error(ctx, err)
+	}
+
+	// Unset
+	// fields.
+	a.Stub()
+
+	// Also ensure marked as unknown so
+	// gets inserted as placeholder URL.
+	a.Type = gtsmodel.FileTypeUnknown
+
+	// Update the stubbed attachment in the database.
+	if err := m.state.DB.UpdateAttachment(ctx, a); err != nil {
+		return gtserror.Newf("db error updating attachment: %w", err)
+	}
+
+	return nil
+}
+
 // FixCacheStatus will check all media for up-to-date cache status (i.e. in storage driver).
 // Media marked as cached, with any required files missing, will be automatically uncached.
 // Context will be checked for `gtscontext.DryRun()` in order to actually perform the action.
 func (m *Media) FixCacheStates(ctx context.Context) (int, error) {
-	var (
-		total int
-		page  paging.Page
-	)
+	var total int
+	var page paging.Page
 
-	// Set page select limit.
+	// Setup page w/ select limit.
+	page.Max = paging.MaxID("")
 	page.Limit = selectLimit
 
 	for {
@@ -251,7 +405,7 @@ func (m *Media) FixCacheStates(ctx context.Context) (int, error) {
 
 		// Use last ID as the next 'maxID' value.
 		maxID = attachments[len(attachments)-1].ID
-		page.Max = paging.MaxID(maxID)
+		page.Max.Value = maxID
 
 		for _, media := range attachments {
 			// Check / fix required media cache states.
@@ -437,13 +591,13 @@ func (m *Media) fixCacheState(ctx context.Context, media *gtsmodel.MediaAttachme
 		return false, err
 	}
 
-	switch {
-	case *media.Cached && !exist:
+	switch cached := media.Cached(); {
+	case cached && !exist:
 		// Mark as uncached if expected files don't exist.
 		l.Debug("cached=true exists=false => uncaching")
 		return true, m.uncache(ctx, media)
 
-	case !*media.Cached && exist:
+	case !cached && exist:
 		// Remove files if we don't expect them to exist.
 		l.Debug("cached=false exists=true => deleting")
 		_, err := m.removeFiles(ctx,
@@ -458,7 +612,7 @@ func (m *Media) fixCacheState(ctx context.Context, media *gtsmodel.MediaAttachme
 }
 
 func (m *Media) uncacheRemote(ctx context.Context, after time.Time, media *gtsmodel.MediaAttachment) (bool, error) {
-	if !*media.Cached {
+	if !media.Cached() {
 		// Already uncached.
 		return false, nil
 	}
@@ -608,8 +762,11 @@ func (m *Media) uncache(ctx context.Context, media *gtsmodel.MediaAttachment) er
 
 	// Update attachment to reflect that we no longer have it cached.
 	log.Debugf(ctx, "marking media attachment as uncached: %s", media.ID)
-	media.Cached = func() *bool { i := false; return &i }()
-	if err := m.state.DB.UpdateAttachment(ctx, media, "cached"); err != nil {
+	media.File.Path, media.Thumbnail.Path = "", ""
+	if err := m.state.DB.UpdateAttachment(ctx, media,
+		"thumbnail_path",
+		"file_path",
+	); err != nil {
 		return gtserror.Newf("error updating media: %w", err)
 	}
 
