@@ -215,69 +215,73 @@ type MediaConfiguration struct {
 }
 
 type CacheConfiguration struct {
-	S3ObjectInfo                          int           `name:"s3-object-info" usage:"Enables caching of S3 object information in the storage driver to reduce S3 calls, value is cache capacity."`
-	MemoryTarget                          bytesize.Size `name:"memory-target" usage:"Sets a target limit that the application will *try* to keep *most* of its caches within."`
-	AccountMemRatio                       float64       `name:"account-mem-ratio"`
-	AccountNoteMemRatio                   float64       `name:"account-note-mem-ratio"`
-	AccountSettingsMemRatio               float64       `name:"account-settings-mem-ratio"`
-	AccountStatsMemRatio                  float64       `name:"account-stats-mem-ratio"`
-	ApplicationMemRatio                   float64       `name:"application-mem-ratio"`
-	BlockMemRatio                         float64       `name:"block-mem-ratio"`
-	BlockIDsMemRatio                      float64       `name:"block-ids-mem-ratio"`
-	BoostOfIDsMemRatio                    float64       `name:"boost-of-ids-mem-ratio"`
-	ClientMemRatio                        float64       `name:"client-mem-ratio"`
-	ConversationMemRatio                  float64       `name:"conversation-mem-ratio"`
-	ConversationLastStatusIDsMemRatio     float64       `name:"conversation-last-status-ids-mem-ratio"`
-	DomainPermissionDraftMemRation        float64       `name:"domain-permission-draft-mem-ratio"`
-	DomainPermissionSubscriptionMemRation float64       `name:"domain-permission-subscription-mem-ratio"`
-	EmojiMemRatio                         float64       `name:"emoji-mem-ratio"`
-	EmojiCategoryMemRatio                 float64       `name:"emoji-category-mem-ratio"`
-	FilterMemRatio                        float64       `name:"filter-mem-ratio"`
-	FilterIDsMemRatio                     float64       `name:"filter-ids-mem-ratio"`
-	FilterKeywordMemRatio                 float64       `name:"filter-keyword-mem-ratio"`
-	FilterStatusMemRatio                  float64       `name:"filter-status-mem-ratio"`
-	FollowMemRatio                        float64       `name:"follow-mem-ratio"`
-	FollowIDsMemRatio                     float64       `name:"follow-ids-mem-ratio"`
-	FollowRequestMemRatio                 float64       `name:"follow-request-mem-ratio"`
-	FollowRequestIDsMemRatio              float64       `name:"follow-request-ids-mem-ratio"`
-	FollowingTagIDsMemRatio               float64       `name:"following-tag-ids-mem-ratio"`
-	HomeAccountIDsMemRatio                float64       `name:"home-account-ids-mem-ratio"`
-	InReplyToIDsMemRatio                  float64       `name:"in-reply-to-ids-mem-ratio"`
-	InstanceMemRatio                      float64       `name:"instance-mem-ratio"`
-	InteractionRequestMemRatio            float64       `name:"interaction-request-mem-ratio"`
-	ListMemRatio                          float64       `name:"list-mem-ratio"`
-	ListIDsMemRatio                       float64       `name:"list-ids-mem-ratio"`
-	ListedIDsMemRatio                     float64       `name:"listed-ids-mem-ratio"`
-	MarkerMemRatio                        float64       `name:"marker-mem-ratio"`
-	MediaMemRatio                         float64       `name:"media-mem-ratio"`
-	MentionMemRatio                       float64       `name:"mention-mem-ratio"`
-	MoveMemRatio                          float64       `name:"move-mem-ratio"`
-	NotificationMemRatio                  float64       `name:"notification-mem-ratio"`
-	PollMemRatio                          float64       `name:"poll-mem-ratio"`
-	PollVoteMemRatio                      float64       `name:"poll-vote-mem-ratio"`
-	PollVoteIDsMemRatio                   float64       `name:"poll-vote-ids-mem-ratio"`
-	ReportMemRatio                        float64       `name:"report-mem-ratio"`
-	ScheduledStatusMemRatio               float64       `name:"scheduled-status-mem-ratio"`
-	SinBinStatusMemRatio                  float64       `name:"sin-bin-status-mem-ratio"`
-	StatusMemRatio                        float64       `name:"status-mem-ratio"`
-	StatusBookmarkMemRatio                float64       `name:"status-bookmark-mem-ratio"`
-	StatusBookmarkIDsMemRatio             float64       `name:"status-bookmark-ids-mem-ratio"`
-	StatusEditMemRatio                    float64       `name:"status-edit-mem-ratio"`
-	StatusFaveMemRatio                    float64       `name:"status-fave-mem-ratio"`
-	StatusFaveIDsMemRatio                 float64       `name:"status-fave-ids-mem-ratio"`
-	TagMemRatio                           float64       `name:"tag-mem-ratio"`
-	ThreadMuteMemRatio                    float64       `name:"thread-mute-mem-ratio"`
-	TokenMemRatio                         float64       `name:"token-mem-ratio"`
-	TombstoneMemRatio                     float64       `name:"tombstone-mem-ratio"`
-	UserMemRatio                          float64       `name:"user-mem-ratio"`
-	UserMuteMemRatio                      float64       `name:"user-mute-mem-ratio"`
-	UserMuteIDsMemRatio                   float64       `name:"user-mute-ids-mem-ratio"`
-	WebfingerMemRatio                     float64       `name:"webfinger-mem-ratio"`
-	WebPushSubscriptionMemRatio           float64       `name:"web-push-subscription-mem-ratio"`
-	WebPushSubscriptionIDsMemRatio        float64       `name:"web-push-subscription-ids-mem-ratio"`
-	MutesMemRatio                         float64       `name:"mutes-mem-ratio"`
-	StatusFilterMemRatio                  float64       `name:"status-filter-mem-ratio"`
-	VisibilityMemRatio                    float64       `name:"visibility-mem-ratio"`
+	S3ObjectInfo                         int           `name:"s3-object-info" usage:"Enables caching of S3 object information in the storage driver to reduce S3 calls, value is cache capacity."`
+	HomeTimelineTimeout                  time.Duration `name:"home-timeline-timeout" usage:"Duration before any one home timeline cache is unloaded from memory. Values <= 0 disable unloading."`
+	ListTimelineTimeout                  time.Duration `name:"list-timeline-timeout" usage:"Duration before any one list timeline cache is unloaded from memory. Values <= 0 disable unloading."`
+	TagTimelineTimeout                   time.Duration `name:"tag-timeline-timeout" usage:"Duration before any one tag timeline cache is unloaded from memory. Values <= 0 disable unloading."`
+	MemoryTarget                         bytesize.Size `name:"memory-target"`
+	AccountMemRatio                      float64       `name:"account-mem-ratio"`
+	AccountNoteMemRatio                  float64       `name:"account-note-mem-ratio"`
+	AccountSettingsMemRatio              float64       `name:"account-settings-mem-ratio"`
+	AccountStatsMemRatio                 float64       `name:"account-stats-mem-ratio"`
+	ApplicationMemRatio                  float64       `name:"application-mem-ratio"`
+	BlockMemRatio                        float64       `name:"block-mem-ratio"`
+	BlockIDsMemRatio                     float64       `name:"block-ids-mem-ratio"`
+	BoostOfIDsMemRatio                   float64       `name:"boost-of-ids-mem-ratio"`
+	ClientMemRatio                       float64       `name:"client-mem-ratio"`
+	ConversationMemRatio                 float64       `name:"conversation-mem-ratio"`
+	ConversationLastStatusIDsMemRatio    float64       `name:"conversation-last-status-ids-mem-ratio"`
+	DomainPermissionDraftMemRatio        float64       `name:"domain-permission-draft-mem-ratio"`
+	DomainLimitMemRatio                  float64       `name:"domain-permission-limit-mem-ratio"`
+	DomainPermissionSubscriptionMemRatio float64       `name:"domain-permission-subscription-mem-ratio"`
+	EmojiMemRatio                        float64       `name:"emoji-mem-ratio"`
+	EmojiCategoryMemRatio                float64       `name:"emoji-category-mem-ratio"`
+	FilterMemRatio                       float64       `name:"filter-mem-ratio"`
+	FilterIDsMemRatio                    float64       `name:"filter-ids-mem-ratio"`
+	FilterKeywordMemRatio                float64       `name:"filter-keyword-mem-ratio"`
+	FilterStatusMemRatio                 float64       `name:"filter-status-mem-ratio"`
+	FollowMemRatio                       float64       `name:"follow-mem-ratio"`
+	FollowIDsMemRatio                    float64       `name:"follow-ids-mem-ratio"`
+	FollowRequestMemRatio                float64       `name:"follow-request-mem-ratio"`
+	FollowRequestIDsMemRatio             float64       `name:"follow-request-ids-mem-ratio"`
+	FollowingTagIDsMemRatio              float64       `name:"following-tag-ids-mem-ratio"`
+	HomeAccountIDsMemRatio               float64       `name:"home-account-ids-mem-ratio"`
+	InReplyToIDsMemRatio                 float64       `name:"in-reply-to-ids-mem-ratio"`
+	InstanceMemRatio                     float64       `name:"instance-mem-ratio"`
+	InteractionRequestMemRatio           float64       `name:"interaction-request-mem-ratio"`
+	ListMemRatio                         float64       `name:"list-mem-ratio"`
+	ListIDsMemRatio                      float64       `name:"list-ids-mem-ratio"`
+	ListedIDsMemRatio                    float64       `name:"listed-ids-mem-ratio"`
+	MarkerMemRatio                       float64       `name:"marker-mem-ratio"`
+	MediaMemRatio                        float64       `name:"media-mem-ratio"`
+	MentionMemRatio                      float64       `name:"mention-mem-ratio"`
+	MoveMemRatio                         float64       `name:"move-mem-ratio"`
+	NotificationMemRatio                 float64       `name:"notification-mem-ratio"`
+	PollMemRatio                         float64       `name:"poll-mem-ratio"`
+	PollVoteMemRatio                     float64       `name:"poll-vote-mem-ratio"`
+	PollVoteIDsMemRatio                  float64       `name:"poll-vote-ids-mem-ratio"`
+	ReportMemRatio                       float64       `name:"report-mem-ratio"`
+	ScheduledStatusMemRatio              float64       `name:"scheduled-status-mem-ratio"`
+	SinBinStatusMemRatio                 float64       `name:"sin-bin-status-mem-ratio"`
+	StatusMemRatio                       float64       `name:"status-mem-ratio"`
+	StatusBookmarkMemRatio               float64       `name:"status-bookmark-mem-ratio"`
+	StatusBookmarkIDsMemRatio            float64       `name:"status-bookmark-ids-mem-ratio"`
+	StatusEditMemRatio                   float64       `name:"status-edit-mem-ratio"`
+	StatusFaveMemRatio                   float64       `name:"status-fave-mem-ratio"`
+	StatusFaveIDsMemRatio                float64       `name:"status-fave-ids-mem-ratio"`
+	TagMemRatio                          float64       `name:"tag-mem-ratio"`
+	ThreadMuteMemRatio                   float64       `name:"thread-mute-mem-ratio"`
+	TokenMemRatio                        float64       `name:"token-mem-ratio"`
+	TombstoneMemRatio                    float64       `name:"tombstone-mem-ratio"`
+	UserMemRatio                         float64       `name:"user-mem-ratio"`
+	UserMuteMemRatio                     float64       `name:"user-mute-mem-ratio"`
+	UserMuteIDsMemRatio                  float64       `name:"user-mute-ids-mem-ratio"`
+	WebfingerMemRatio                    float64       `name:"webfinger-mem-ratio"`
+	WebPushSubscriptionMemRatio          float64       `name:"web-push-subscription-mem-ratio"`
+	WebPushSubscriptionIDsMemRatio       float64       `name:"web-push-subscription-ids-mem-ratio"`
+	MutesMemRatio                        float64       `name:"mutes-mem-ratio"`
+	StatusFilterMemRatio                 float64       `name:"status-filter-mem-ratio"`
+	VisibilityMemRatio                   float64       `name:"visibility-mem-ratio"`
 }
 
 type AdvancedConfig struct {
