@@ -22,7 +22,6 @@ import (
 
 	"code.superseriousbusiness.org/gotosocial/internal/language"
 	"codeberg.org/gruf/go-bytesize"
-	"github.com/coreos/go-oidc/v3/oidc"
 )
 
 // Defaults contains a populated Configuration with reasonable defaults. Note that
@@ -122,7 +121,7 @@ var Defaults = Configuration{
 	OIDCIssuer:           "",
 	OIDCClientID:         "",
 	OIDCClientSecret:     "",
-	OIDCScopes:           []string{oidc.ScopeOpenID, "profile", "email", "groups"},
+	OIDCScopes:           []string{"openid", "profile", "email", "groups"},
 	OIDCLinkExisting:     false,
 
 	SMTPHost:               "",
@@ -169,6 +168,11 @@ var Defaults = Configuration{
 		// to those on metered S3 to tweak.
 		S3ObjectInfo: 0,
 
+		// Timeline trim eviction timeouts.
+		HomeTimelineTimeout: 6 * time.Hour,
+		ListTimelineTimeout: 2 * time.Hour,
+		TagTimelineTimeout:  10 * time.Minute,
+
 		// Rough memory target that the total
 		// size of all State.Caches will attempt
 		// to remain with. Emphasis on *rough*.
@@ -188,67 +192,68 @@ var Defaults = Configuration{
 		// when TODO items in the size.go source
 		// file have been addressed, these should
 		// be able to make some more sense :D
-		AccountMemRatio:                       5,
-		AccountNoteMemRatio:                   1,
-		AccountSettingsMemRatio:               0.1,
-		AccountStatsMemRatio:                  2,
-		ApplicationMemRatio:                   0.1,
-		BlockMemRatio:                         2,
-		BlockIDsMemRatio:                      3,
-		BoostOfIDsMemRatio:                    3,
-		ClientMemRatio:                        0.1,
-		ConversationMemRatio:                  1,
-		ConversationLastStatusIDsMemRatio:     2,
-		DomainPermissionDraftMemRation:        0.5,
-		DomainPermissionSubscriptionMemRation: 0.5,
-		EmojiMemRatio:                         3,
-		EmojiCategoryMemRatio:                 0.1,
-		FilterMemRatio:                        0.5,
-		FilterIDsMemRatio:                     2,
-		FilterKeywordMemRatio:                 0.5,
-		FilterStatusMemRatio:                  0.5,
-		FollowMemRatio:                        2,
-		FollowIDsMemRatio:                     4,
-		FollowRequestMemRatio:                 2,
-		FollowRequestIDsMemRatio:              2,
-		FollowingTagIDsMemRatio:               2,
-		HomeAccountIDsMemRatio:                2,
-		InReplyToIDsMemRatio:                  3,
-		InstanceMemRatio:                      1,
-		InteractionRequestMemRatio:            1,
-		ListMemRatio:                          1,
-		ListIDsMemRatio:                       2,
-		ListedIDsMemRatio:                     2,
-		MarkerMemRatio:                        0.5,
-		MediaMemRatio:                         4,
-		MentionMemRatio:                       2,
-		MoveMemRatio:                          0.1,
-		NotificationMemRatio:                  2,
-		PollMemRatio:                          1,
-		PollVoteMemRatio:                      2,
-		PollVoteIDsMemRatio:                   2,
-		ReportMemRatio:                        1,
-		ScheduledStatusMemRatio:               4,
-		SinBinStatusMemRatio:                  0.5,
-		StatusMemRatio:                        5,
-		StatusBookmarkMemRatio:                0.5,
-		StatusBookmarkIDsMemRatio:             2,
-		StatusEditMemRatio:                    2,
-		StatusFaveMemRatio:                    2,
-		StatusFaveIDsMemRatio:                 3,
-		TagMemRatio:                           2,
-		ThreadMuteMemRatio:                    0.2,
-		TokenMemRatio:                         0.75,
-		TombstoneMemRatio:                     0.5,
-		UserMemRatio:                          0.25,
-		UserMuteMemRatio:                      2,
-		UserMuteIDsMemRatio:                   3,
-		WebfingerMemRatio:                     0.1,
-		WebPushSubscriptionMemRatio:           1,
-		WebPushSubscriptionIDsMemRatio:        1,
-		MutesMemRatio:                         2,
-		StatusFilterMemRatio:                  7,
-		VisibilityMemRatio:                    2,
+		AccountMemRatio:                      5,
+		AccountNoteMemRatio:                  1,
+		AccountSettingsMemRatio:              0.1,
+		AccountStatsMemRatio:                 2,
+		ApplicationMemRatio:                  0.1,
+		BlockMemRatio:                        2,
+		BlockIDsMemRatio:                     3,
+		BoostOfIDsMemRatio:                   3,
+		ClientMemRatio:                       0.1,
+		ConversationMemRatio:                 1,
+		ConversationLastStatusIDsMemRatio:    2,
+		DomainPermissionDraftMemRatio:        0.5,
+		DomainLimitMemRatio:                  0.5,
+		DomainPermissionSubscriptionMemRatio: 0.5,
+		EmojiMemRatio:                        3,
+		EmojiCategoryMemRatio:                0.1,
+		FilterMemRatio:                       0.5,
+		FilterIDsMemRatio:                    2,
+		FilterKeywordMemRatio:                0.5,
+		FilterStatusMemRatio:                 0.5,
+		FollowMemRatio:                       2,
+		FollowIDsMemRatio:                    4,
+		FollowRequestMemRatio:                2,
+		FollowRequestIDsMemRatio:             2,
+		FollowingTagIDsMemRatio:              2,
+		HomeAccountIDsMemRatio:               2,
+		InReplyToIDsMemRatio:                 3,
+		InstanceMemRatio:                     1,
+		InteractionRequestMemRatio:           1,
+		ListMemRatio:                         1,
+		ListIDsMemRatio:                      2,
+		ListedIDsMemRatio:                    2,
+		MarkerMemRatio:                       0.5,
+		MediaMemRatio:                        4,
+		MentionMemRatio:                      2,
+		MoveMemRatio:                         0.1,
+		NotificationMemRatio:                 2,
+		PollMemRatio:                         1,
+		PollVoteMemRatio:                     2,
+		PollVoteIDsMemRatio:                  2,
+		ReportMemRatio:                       1,
+		ScheduledStatusMemRatio:              4,
+		SinBinStatusMemRatio:                 0.5,
+		StatusMemRatio:                       5,
+		StatusBookmarkMemRatio:               0.5,
+		StatusBookmarkIDsMemRatio:            2,
+		StatusEditMemRatio:                   2,
+		StatusFaveMemRatio:                   2,
+		StatusFaveIDsMemRatio:                3,
+		TagMemRatio:                          2,
+		ThreadMuteMemRatio:                   0.2,
+		TokenMemRatio:                        0.75,
+		TombstoneMemRatio:                    0.5,
+		UserMemRatio:                         0.25,
+		UserMuteMemRatio:                     2,
+		UserMuteIDsMemRatio:                  3,
+		WebfingerMemRatio:                    0.1,
+		WebPushSubscriptionMemRatio:          1,
+		WebPushSubscriptionIDsMemRatio:       1,
+		MutesMemRatio:                        2,
+		StatusFilterMemRatio:                 7,
+		VisibilityMemRatio:                   2,
 	},
 
 	HTTPClient: HTTPClientConfiguration{
