@@ -26,17 +26,17 @@ import (
 	"strings"
 	"time"
 
+	"code.superseriousbusiness.org/gopkg/log"
+	"code.superseriousbusiness.org/gopkg/xslices"
 	"code.superseriousbusiness.org/gotosocial/internal/config"
 	"code.superseriousbusiness.org/gotosocial/internal/db"
 	"code.superseriousbusiness.org/gotosocial/internal/gtscontext"
 	"code.superseriousbusiness.org/gotosocial/internal/gtserror"
 	"code.superseriousbusiness.org/gotosocial/internal/gtsmodel"
 	"code.superseriousbusiness.org/gotosocial/internal/id"
-	"code.superseriousbusiness.org/gotosocial/internal/log"
 	"code.superseriousbusiness.org/gotosocial/internal/paging"
 	"code.superseriousbusiness.org/gotosocial/internal/state"
 	"code.superseriousbusiness.org/gotosocial/internal/util"
-	"code.superseriousbusiness.org/gotosocial/internal/util/xslices"
 	"github.com/uptrace/bun"
 	"github.com/uptrace/bun/dialect"
 )
@@ -900,27 +900,81 @@ func (a *accountDB) GetAccountFaves(ctx context.Context, accountID string) ([]*g
 	return *faves, nil
 }
 
-func selectOnlyWithMedia(q *bun.SelectQuery) *bun.SelectQuery {
+func selectOnlyWithMedia(q *bun.SelectQuery, includeBoosts bool) *bun.SelectQuery {
 	// Attachments are stored as a json object; this
 	// implementation differs between SQLite and Postgres,
-	// so we have to be thorough to cover all eventualities
-	return q.WhereGroup(" AND ", func(q *bun.SelectQuery) *bun.SelectQuery {
-		switch d := q.Dialect().Name(); d {
-		case dialect.PG:
-			return q.
-				Where("? IS NOT NULL", bun.Ident("attachments")).
-				Where("? != '{}'", bun.Ident("attachments"))
+	// so we have to be thorough to cover all eventualities.
+	//
+	// If including boosts, consider status as having media
+	// *either* if the status itself has attachments, OR if
+	// the boosted status has attachments. For example:
+	//
+	//	[... rest of the query ...]
+	//	AND (
+	//	  (
+	//	    "status"."attachments" IS NOT NULL
+	//	    AND "status"."attachments" != 'null'
+	//	    AND "status"."attachments" != '[]'
+	//	  )
+	//	  OR (
+	//	    "boost_of"."attachments" IS NOT NULL
+	//	    AND "boost_of"."attachments" != 'null'
+	//	    AND "boost_of"."attachments" != '[]'
+	//	  )
+	//	)
+	//	[... rest of the query ...]
+	switch d := q.Dialect().Name(); {
 
-		case dialect.SQLite:
-			return q.
-				Where("? IS NOT NULL", bun.Ident("attachments")).
-				Where("? != 'null'", bun.Ident("attachments")).
-				Where("? != '[]'", bun.Ident("attachments"))
+	// Postgres with boosts.
+	// Use joined "boost_of".
+	case d == dialect.PG && includeBoosts:
+		return q.
+			Where(
+				"(? IS NOT NULL AND ? != '{}') "+
+					"OR (? IS NOT NULL AND ? != '{}')",
+				bun.Ident("status.attachments"),
+				bun.Ident("status.attachments"),
+				bun.Ident("boost_of.attachments"),
+				bun.Ident("boost_of.attachments"),
+			)
 
-		default:
-			panic("dialect " + d.String() + " was neither pg nor sqlite")
-		}
-	})
+	// Postgres without boosts.
+	case d == dialect.PG:
+		return q.
+			Where(
+				"? IS NOT NULL AND ? != '{}'",
+				bun.Ident("status.attachments"),
+				bun.Ident("status.attachments"),
+			)
+
+	// SQLite with boosts.
+	// Use joined "boost_of".
+	case d == dialect.SQLite && includeBoosts:
+		return q.
+			Where(
+				"(? IS NOT NULL AND ? != 'null' AND ? != '[]') "+
+					"OR (? IS NOT NULL AND ? != 'null' AND ? != '[]')",
+				bun.Ident("status.attachments"),
+				bun.Ident("status.attachments"),
+				bun.Ident("status.attachments"),
+				bun.Ident("boost_of.attachments"),
+				bun.Ident("boost_of.attachments"),
+				bun.Ident("boost_of.attachments"),
+			)
+
+	// SQLite without boosts.
+	case d == dialect.SQLite:
+		return q.
+			Where(
+				"? IS NOT NULL AND ? != 'null' AND ? != '[]'",
+				bun.Ident("status.attachments"),
+				bun.Ident("status.attachments"),
+				bun.Ident("status.attachments"),
+			)
+
+	default:
+		panic("dialect " + d.String() + " was neither pg nor sqlite")
+	}
 }
 
 func (a *accountDB) GetAccountStatuses(ctx context.Context, accountID string, limit int, excludeReplies bool, excludeReblogs bool, maxID string, minID string, mediaOnly bool, publicOnly bool) ([]*gtsmodel.Status, error) {
@@ -965,7 +1019,10 @@ func (a *accountDB) GetAccountStatuses(ctx context.Context, accountID string, li
 
 	if mediaOnly {
 		// Respect mediaOnly pref.
-		q = selectOnlyWithMedia(q)
+		// For this particular endpoint mediaOnly
+		// also implies excludeReblogs so just pass
+		// includeBoosts=false instead of !excludeReblogs.
+		q = selectOnlyWithMedia(q, false)
 	}
 
 	if publicOnly {
@@ -1041,16 +1098,101 @@ func (a *accountDB) GetAccountPinnedStatuses(ctx context.Context, accountID stri
 	return a.state.DB.GetStatusesByIDs(ctx, statusIDs)
 }
 
-var webStatusVisibilities = bun.In([]gtsmodel.Visibility{
-	gtsmodel.VisibilityPublic,
-	gtsmodel.VisibilityUnlocked,
-})
+func (a *accountDB) accountWebStatusesCommonSelect(
+	accountID string,
+	mediaOnly bool,
+	includeBoosts bool,
+	visibility gtsmodel.Visibility,
+) *bun.SelectQuery {
+	// Start building
+	// this common query.
+	q := a.db.NewSelect()
+
+	// Select ID from statuses.
+	q = q.
+		TableExpr("? AS ?", bun.Ident("statuses"), bun.Ident("status")).
+		Column("status.id")
+
+	if includeBoosts {
+		// Join on boosted account.
+		q = q.Join(
+			"LEFT JOIN ? AS ? ON ? = ?",
+			bun.Ident("accounts"), bun.Ident("boost_of_account"),
+			bun.Ident("status.boost_of_account_id"), bun.Ident("boost_of_account.id"),
+		)
+
+		// Join on boosted status.
+		q = q.Join(
+			"LEFT JOIN ? AS ? ON ? = ?",
+			bun.Ident("statuses"), bun.Ident("boost_of"),
+			bun.Ident("status.boost_of_id"), bun.Ident("boost_of.id"),
+		)
+	}
+
+	// Local posts only, we don't show
+	// remote account's posts on the web view.
+	q = q.Where("? = ?", bun.Ident("status.local"), true)
+
+	// Select statuses created by the target account.
+	q = q.Where("? = ?", bun.Ident("status.account_id"), accountID)
+
+	// Select statuses of target visibility.
+	q = q.Where("? = ?", bun.Ident("status.visibility"), visibility)
+
+	// Don't show replies.
+	q = q.Where("? IS NULL", bun.Ident("status.in_reply_to_uri"))
+
+	if !includeBoosts {
+		// Don't include boosts.
+		q = q.Where("? IS NULL", bun.Ident("status.boost_of_id"))
+	} else {
+		// Allow statuses from boosted
+		// accounts where possible.
+		q = q.WhereGroup(" AND ", func(q *bun.SelectQuery) *bun.SelectQuery {
+			// Include non-boosts.
+			q = q.Where("? IS NULL", bun.Ident("status.boost_of_id"))
+
+			// Include boosts as well.
+			q = q.
+				WhereGroup(" OR ", func(q *bun.SelectQuery) *bun.SelectQuery {
+					// Boosted status must have target visibility.
+					q = q.Where("? = ?", bun.Ident("boost_of.visibility"), visibility)
+
+					// Boosted status must be federated.
+					q = q.Where("? = ?", bun.Ident("boost_of.federated"), true)
+
+					// Boosted account must not hide
+					// target visibility from unauthed web.
+					if visibility == gtsmodel.VisibilityPublic {
+						q = q.Where("? = ?", bun.Ident("boost_of_account.hides_to_public_from_unauthed_web"), false)
+					} else {
+						q = q.Where("? = ?", bun.Ident("boost_of_account.hides_cc_public_from_unauthed_web"), false)
+					}
+
+					return q
+				})
+
+			return q
+		})
+	}
+
+	// Don't show local only / unfederated.
+	q = q.Where("? = ?", bun.Ident("status.federated"), true)
+
+	if mediaOnly {
+		// Respect mediaOnly pref.
+		q = selectOnlyWithMedia(q, includeBoosts)
+	}
+
+	return q
+}
 
 func (a *accountDB) GetAccountWebStatuses(
 	ctx context.Context,
 	account *gtsmodel.Account,
 	page *paging.Page,
 	mediaOnly bool,
+	includeBoosts bool,
 ) ([]*gtsmodel.Status, error) {
 	if account.Username == config.GetHost() {
 		// Instance account
@@ -1075,35 +1217,120 @@ func (a *accountDB) GetAccountWebStatuses(
 		return nil, nil
 	}
 
-	return loadStatusTimelinePage(ctx, a.db, a.state,
+	if publicOnly {
+		// Simple case, we
+		// don't need a union.
+		return loadStatusTimelinePage(ctx, a.db, a.state,
+			// Paging
+			// params.
+			page,
 
-		// Paging
-		// params.
-		page,
+			// Use the common select query
+			// for just public web statuses.
+			func(q *bun.SelectQuery) (*bun.SelectQuery, error) {
+				return a.accountWebStatusesCommonSelect(
+					account.ID,
+					mediaOnly,
+					includeBoosts,
+					gtsmodel.VisibilityPublic,
+				), nil
+			},
+		)
+	}
 
-		// The actual meat of the account web statuses query.
-		func(q *bun.SelectQuery) (*bun.SelectQuery, error) {
-			q = q.Where("? = ?", bun.Ident("account_id"), account.ID)
+	// More complicated case with both
+	// public and unlisted visibilities:
+	// we need to build a union query to
+	// ensure the correct index gets used.
 
-			if publicOnly {
-				q = q.Where("? = ?", bun.Ident("visibility"), gtsmodel.VisibilityPublic)
-			} else {
-				q = q.Where("? IN (?)", bun.Ident("visibility"), webStatusVisibilities)
-			}
+	// Extract page params.
+	minID := page.Min.Value
+	maxID := page.Max.Value
+	limit := page.Limit
+	order := page.Order()
 
-			// Don't show replies, boosts, or local-only in web view.
-			q = q.Where("? IS NULL", bun.Ident("in_reply_to_uri")).
-				Where("? IS NULL", bun.Ident("boost_of_id")).
-				Where("? = ?", bun.Ident("federated"), true)
+	// Pre-allocate slice of IDs as dest.
+	statusIDs := make([]string, 0, limit)
 
-			if mediaOnly {
-				// Respect mediaOnly pref.
-				q = selectOnlyWithMedia(q)
-			}
-
-			return q, nil
-		},
+	// Left side of the union (public statuses).
+	// Able to use statuses_profile_web_view_including_boosts_idx.
+	q1 := a.accountWebStatusesCommonSelect(
+		account.ID,
+		mediaOnly,
+		includeBoosts,
+		gtsmodel.VisibilityPublic,
 	)
+
+	// Right side of the union (unlisted statuses).
+	// Able to use statuses_profile_web_view_including_boosts_idx.
+	q2 := a.accountWebStatusesCommonSelect(
+		account.ID,
+		mediaOnly,
+		includeBoosts,
+		gtsmodel.VisibilityUnlocked,
+	)
+
+	// Apply max/min ID boundaries
+	// to both sides of the union.
+	if maxID != "" {
+		// Set a maximum ID boundary if was given.
+		q1 = q1.Where("? < ?", bun.Ident("status.id"), maxID)
+		q2 = q2.Where("? < ?", bun.Ident("status.id"), maxID)
+	}
+	if minID != "" {
+		// Set a minimum ID boundary if was given.
+		q1 = q1.Where("? > ?", bun.Ident("status.id"), minID)
+		q2 = q2.Where("? > ?", bun.Ident("status.id"), minID)
+	}
+
+	// Build the union query.
+	queryStr := "? UNION ALL ?"
+	queryArgs := []any{q1, q2}
+
+	// Apply order and limit *only* to
+	// the union query overall, not the
+	// left + right sides individually.
+	if order.Ascending() {
+		queryStr += " ORDER BY ? ASC"
+	} else /* i.e. descending */ {
+		queryStr += " ORDER BY ? DESC"
+	}
+
+	// Order by column must differ according to driver.
+	//
+	// If you include "status"."id" in Postgres you get:
+	//	missing FROM-clause entry for table "status"
+	//
+	// If you don't include it in SQLite you get:
+	//	1st ORDER BY term does not match any column in the result set
+	switch d := a.db.Dialect().Name(); d {
+	case dialect.PG:
+		queryArgs = append(queryArgs, bun.Ident("id"))
+	case dialect.SQLite:
+		queryArgs = append(queryArgs, bun.Ident("status.id"))
+	default:
+		panic("dialect " + d.String() + " was neither pg nor sqlite")
+	}
+
+	// A limit should always
+	// be supplied for this.
+	queryStr += " LIMIT ?"
+	queryArgs = append(queryArgs, limit)
+
+	// Assemble the
+	// whole query.
+	q := a.db.NewRaw(
+		queryStr,
+		queryArgs...,
+	)
+
+	// Finally, perform query into status ID slice.
+	if err := q.Scan(ctx, &statusIDs); err != nil {
+		return nil, err
+	}
+
+	// Fetch statuses from DB / cache with given IDs.
+	return a.state.DB.GetStatusesByIDs(ctx, statusIDs)
 }
 
 func (a *accountDB) GetAccountSettings(
