@@ -27,12 +27,12 @@ import (
 	"strings"
 	"time"
 
+	"code.superseriousbusiness.org/gopkg/log"
 	"code.superseriousbusiness.org/gotosocial/internal/config"
 	"code.superseriousbusiness.org/gotosocial/internal/db"
 	"code.superseriousbusiness.org/gotosocial/internal/gtserror"
 	"code.superseriousbusiness.org/gotosocial/internal/gtsmodel"
 	"code.superseriousbusiness.org/gotosocial/internal/id"
-	"code.superseriousbusiness.org/gotosocial/internal/log"
 	"code.superseriousbusiness.org/gotosocial/internal/state"
 	"code.superseriousbusiness.org/gotosocial/internal/uris"
 	"code.superseriousbusiness.org/gotosocial/internal/util"
@@ -137,10 +137,27 @@ func (a *adminDB) NewSignup(ctx context.Context, newSignup gtsmodel.NewSignup) (
 			return nil, err
 		}
 
+		// Take user locale from form if set.
+		// If not, fall back to first instance
+		// language if that's set, and if it's
+		// not, fall back to db default "en".
+		locale := newSignup.Locale
+		if locale == "" {
+			instanceLanguages := config.GetInstanceLanguages()
+			if len(instanceLanguages) != 0 {
+				// Use first instance lang.
+				locale = instanceLanguages[0].TagStr
+			} else {
+				// Use db default "en".
+				locale = "en"
+			}
+		}
+
 		// Insert basic settings for new account.
 		account.Settings = &gtsmodel.AccountSettings{
 			AccountID: accountID,
 			Privacy:   gtsmodel.VisibilityDefault,
+			Language:  locale,
 		}
 		if err := a.state.DB.PutAccountSettings(ctx, account.Settings); err != nil {
 			return nil, err
@@ -208,7 +225,7 @@ func (a *adminDB) NewSignup(ctx context.Context, newSignup gtsmodel.NewSignup) (
 		EncryptedPassword:      string(encryptedPassword),
 		SignUpIP:               newSignup.SignUpIP.To4(),
 		Reason:                 newSignup.Reason,
-		Locale:                 newSignup.Locale,
+		Locale:                 account.Settings.Language,
 		UnconfirmedEmail:       newSignup.Email,
 		CreatedByApplicationID: newSignup.AppID,
 		ExternalID:             newSignup.ExternalID,
@@ -274,7 +291,7 @@ func (a *adminDB) CreateInstanceAccount(ctx context.Context) error {
 		PrivateKey:            key,
 		PublicKey:             &key.PublicKey,
 		PublicKeyURI:          newAccountURIs.PublicKeyURI,
-		ActorType:             gtsmodel.AccountActorTypeService,
+		ActorType:             gtsmodel.AccountActorTypeApplication,
 		URI:                   newAccountURIs.UserURI,
 		InboxURI:              newAccountURIs.InboxURI,
 		OutboxURI:             newAccountURIs.OutboxURI,
