@@ -25,6 +25,7 @@ import (
 	"time"
 
 	"code.superseriousbusiness.org/activity/pub"
+	"code.superseriousbusiness.org/gopkg/log"
 	"code.superseriousbusiness.org/gotosocial/internal/ap"
 	"code.superseriousbusiness.org/gotosocial/internal/config"
 	"code.superseriousbusiness.org/gotosocial/internal/db"
@@ -32,7 +33,6 @@ import (
 	"code.superseriousbusiness.org/gotosocial/internal/gtserror"
 	"code.superseriousbusiness.org/gotosocial/internal/gtsmodel"
 	"code.superseriousbusiness.org/gotosocial/internal/id"
-	"code.superseriousbusiness.org/gotosocial/internal/log"
 	"code.superseriousbusiness.org/gotosocial/internal/media"
 	"code.superseriousbusiness.org/gotosocial/internal/util"
 	errorsv2 "codeberg.org/gruf/go-errors/v2"
@@ -806,18 +806,60 @@ func (d *Dereferencer) enrichAccount(
 	latestAcc.FetchedAt = now
 	latestAcc.UpdatedAt = now
 
-	// Ensure the account's avatar media is populated, passing in existing to check for chages.
-	if err := d.fetchAccountAvatar(ctx, requestUser, account, latestAcc, apubAcc); err != nil {
+	// Check if there's any limits in place for (sub)domain.
+	limit, err := d.state.DB.MatchDomainLimit(ctx, uri.Host)
+	if err != nil {
+		return nil, nil, gtserror.Newf("error matching domain limit: %w", err)
+	}
+
+	// If domain media is limited, set reject reason,
+	// this gets passed to media fetching functions
+	// and prevents download of attached account media.
+	var rejectReason *gtsmodel.MediaErrorDetails
+	if limit.MediaReject() {
+		rejectReason = new(gtsmodel.MediaErrorDetails)
+		*rejectReason = gtsmodel.NewMediaErrorDetails(
+			gtsmodel.MediaErrorTypePolicy,
+			gtsmodel.MediaErrorTypePolicy_Domain,
+		)
+	}
+
+	// Ensure the account's avatar media
+	// is populated (if appropriate), passing
+	// in existing to check for chages.
+	if err := d.fetchAccountAvatar(
+		ctx,
+		requestUser,
+		account,
+		latestAcc,
+		apubAcc,
+		rejectReason,
+	); err != nil {
 		log.Errorf(ctx, "error fetching remote avatar for account %s: %v", uri, err)
 	}
 
-	// Ensure the account's avatar media is populated, passing in existing to check for chages.
-	if err := d.fetchAccountHeader(ctx, requestUser, account, latestAcc, apubAcc); err != nil {
+	// Ensure the account's header media
+	// is populated (if appropriate), passing
+	// in existing to check for chages.
+	if err := d.fetchAccountHeader(
+		ctx,
+		requestUser,
+		account,
+		latestAcc,
+		apubAcc,
+		rejectReason,
+	); err != nil {
 		log.Errorf(ctx, "error fetching remote header for account %s: %v", uri, err)
 	}
 
-	// Fetch the latest remote account emoji IDs used in account display name/bio.
-	if err = d.fetchAccountEmojis(ctx, account, latestAcc); err != nil {
+	// Fetch the latest remote emoji
+	// used in account display name/bio.
+	if err = d.fetchAccountEmojis(
+		ctx,
+		account,
+		latestAcc,
+		rejectReason,
+	); err != nil {
 		log.Errorf(ctx, "error fetching remote emojis for account %s: %v", uri, err)
 	}
 
@@ -855,21 +897,28 @@ func (d *Dereferencer) fetchAccountAvatar(
 	existingAcc *gtsmodel.Account,
 	latestAcc *gtsmodel.Account,
 	apubAcc ap.Accountable,
+	rejectReason *gtsmodel.MediaErrorDetails, // optional reason to reject media with
 ) error {
-	if latestAcc.AvatarRemoteURL == "" {
+	latestAvatarURL := latestAcc.AvatarRemoteURL
+	if latestAvatarURL == "" {
 		// No avatar set on newest model, leave
 		// latest avatar attachment ID empty.
 		return nil
 	}
 
+	// Check for image description of account header avatar.
 	avatarDescription := ap.ExtractIconDescription(apubAcc)
 
-	// Check for an existing stored media attachment
-	// specifically with unchanged remote URL we can use.
-	if existingAcc.AvatarMediaAttachmentID != "" &&
-		existingAcc.AvatarRemoteURL == latestAcc.AvatarRemoteURL {
+	// If account has a avatar set, and the avatar media
+	// has the same URL as the latest up-to-date URL,
+	// just ensure we have it cached (if appropriate).
+	if existingAcc.AvatarSet() &&
+		existingAcc.AvatarRemoteURL == latestAvatarURL {
 
-		// Fetch the existing avatar media attachment with ID.
+		// Avatar URL from existing account is up to date,
+		// so attachment ID will be up to date as well.
+		//
+		// Get this avatar media attachment from database.
 		existing, err := d.state.DB.GetAttachmentByID(ctx,
 			existingAcc.AvatarMediaAttachmentID,
 		)
@@ -878,66 +927,94 @@ func (d *Dereferencer) fetchAccountAvatar(
 		}
 
 		if existing != nil {
-			// Ensuring existing attachment is up-to-date
-			// and any recaching is performed if required.
-			existing, err := d.updateAttachment(ctx,
-				requestUser,
-				existing,
-				nil,
-			)
+			// Prepare to update info if necessary.
+			var info media.AdditionalMediaInfo
 
+			// Pass reject reason ptr, which
+			// will skip downloading if set.
+			info.RejectReason = rejectReason
+
+			// If description has changed,
+			// ensure this gets updated.
 			if existing.Description != avatarDescription {
-				existing.Description = avatarDescription
-				if err := d.state.DB.UpdateAttachment(
-					ctx,
-					existing,
-					"description",
-				); err != nil {
-					err := gtserror.Newf("db error updating existing avatar description: %w", err)
-					return gtserror.NewErrorInternalError(err)
-				}
+				info.Description = &avatarDescription
 			}
 
-			if err != nil {
-				log.Errorf(ctx, "error updating existing attachment: %v", err)
+			// Ensure attachment is up-to-date
+			// and do recaching if appropriate.
+			//
+			// We can do this async as we're
+			// likely only changing metadata.
+			existing, err := d.RefreshMedia(
+				ctx,
+				requestUser,
+				existing,
+				info,
+				false, // force
+				true,  // async
+			)
 
-				// specifically do NOT return nil here,
+			if err != nil {
+				// Specifically do NOT return nil here,
 				// we already have a model, we don't
 				// want to drop it from the account, just
 				// log that an update for it failed.
+				log.Errorf(ctx, "error updating existing attachment: %v", err)
 			}
 
-			// Set the avatar attachment on account model.
+			// Set the existing (maybe now updated)
+			// avatar attachment on latest account model.
 			latestAcc.AvatarMediaAttachment = existing
 			latestAcc.AvatarMediaAttachmentID = existing.ID
 
 			return nil
 		}
+
+		// If existing was nil, then the attachment got removed for some reason,
+		// fall to fetching from scratch with a new ID, but log as it is strange.
+		log.Warnf(ctx, "%s not found in db, refetching from scratch",
+			existingAcc.AvatarMediaAttachmentID,
+		)
+	}
+
+	// Prepare additional media info.
+	info := media.AdditionalMediaInfo{
+		Avatar:      util.Ptr(true),
+		RemoteURL:   &latestAvatarURL,
+		Description: &avatarDescription,
+
+		// Pass reject reason ptr, which
+		// will skip downloading if set.
+		RejectReason: rejectReason,
 	}
 
 	// Fetch newly changed avatar.
 	attachment, err := d.GetMedia(ctx,
 		requestUser,
 		latestAcc.ID,
-		latestAcc.AvatarRemoteURL,
-		media.AdditionalMediaInfo{
-			Avatar:      util.Ptr(true),
-			RemoteURL:   &latestAcc.AvatarRemoteURL,
-			Description: &avatarDescription,
-		},
+		latestAvatarURL,
+		info,
+		false, // async
 	)
-	if err != nil {
-		if attachment == nil {
-			return gtserror.Newf("error loading attachment %s: %w", latestAcc.AvatarRemoteURL, err)
-		}
+	switch {
+	case err == nil:
+		// No problem,
+		// loaded fine.
 
-		// non-fatal error occurred during loading, still use it.
+	case attachment == nil:
+		// Fatal error during loading, can't do anything further.
+		return gtserror.Newf("error loading attachment %s: %w",
+			latestAvatarURL, err)
+
+	default:
+		// Non-fatal error during loading, can still use it.
 		log.Warnf(ctx, "partially loaded attachment: %v", err)
 	}
 
-	// Set the avatar attachment on account model.
+	// Set updated avatar attachment info on account model.
 	latestAcc.AvatarMediaAttachment = attachment
 	latestAcc.AvatarMediaAttachmentID = attachment.ID
+	latestAcc.AvatarRemoteURL = latestAvatarURL
 
 	return nil
 }
@@ -948,21 +1025,28 @@ func (d *Dereferencer) fetchAccountHeader(
 	existingAcc *gtsmodel.Account,
 	latestAcc *gtsmodel.Account,
 	apubAcc ap.Accountable,
+	rejectReason *gtsmodel.MediaErrorDetails, // optional reason to reject media with
 ) error {
-	if latestAcc.HeaderRemoteURL == "" {
+	latestHeaderURL := latestAcc.HeaderRemoteURL
+	if latestHeaderURL == "" {
 		// No header set on newest model, leave
 		// latest header attachment ID empty.
 		return nil
 	}
 
+	// Check for image description of account header image.
 	headerDescription := ap.ExtractImageDescription(apubAcc)
 
-	// Check for an existing stored media attachment
-	// specifically with unchanged remote URL we can use.
-	if existingAcc.HeaderMediaAttachmentID != "" &&
-		existingAcc.HeaderRemoteURL == latestAcc.HeaderRemoteURL {
+	// If account has a header set, and the header media
+	// has the same URL as the latest up-to-date URL,
+	// just ensure we have it cached (if appropriate).
+	if existingAcc.HeaderSet() &&
+		existingAcc.HeaderRemoteURL == latestHeaderURL {
 
-		// Fetch the existing header media attachment with ID.
+		// Header URL from existing account is up to date,
+		// so attachment ID will be up to date as well.
+		//
+		// Get this header media attachment from database.
 		existing, err := d.state.DB.GetAttachmentByID(ctx,
 			existingAcc.HeaderMediaAttachmentID,
 		)
@@ -970,67 +1054,95 @@ func (d *Dereferencer) fetchAccountHeader(
 			return gtserror.Newf("error getting attachment %s: %w", existingAcc.HeaderMediaAttachmentID, err)
 		}
 
-		if existing.Description != headerDescription {
-			existing.Description = headerDescription
-			if err := d.state.DB.UpdateAttachment(
-				ctx,
-				existing,
-				"description",
-			); err != nil {
-				err := gtserror.Newf("db error updating existing header description: %w", err)
-				return gtserror.NewErrorInternalError(err)
-			}
-		}
-
 		if existing != nil {
-			// Ensuring existing attachment is up-to-date
-			// and any recaching is performed if required.
-			existing, err := d.updateAttachment(ctx,
+			// Prepare to update info if necessary.
+			var info media.AdditionalMediaInfo
+
+			// Pass reject reason ptr, which
+			// will skip downloading if set.
+			info.RejectReason = rejectReason
+
+			// If description has changed,
+			// ensure this gets updated.
+			if existing.Description != headerDescription {
+				info.Description = &headerDescription
+			}
+
+			// Ensure attachment is up-to-date
+			// and do recaching if appropriate.
+			//
+			// We can do this async as we're
+			// likely only changing metadata.
+			existing, err := d.RefreshMedia(
+				ctx,
 				requestUser,
 				existing,
-				nil,
+				info,
+				false, // force
+				true,  // async
 			)
 
 			if err != nil {
-				log.Errorf(ctx, "error updating existing attachment: %v", err)
-
-				// specifically do NOT return nil here,
+				// Specifically do NOT return nil here,
 				// we already have a model, we don't
 				// want to drop it from the account, just
 				// log that an update for it failed.
+				log.Errorf(ctx, "error updating existing attachment: %v", err)
 			}
 
-			// Set the header attachment on account model.
+			// Set the existing (maybe now updated)
+			// header attachment on latest account model.
 			latestAcc.HeaderMediaAttachment = existing
 			latestAcc.HeaderMediaAttachmentID = existing.ID
 
 			return nil
 		}
+
+		// If existing was nil, then the attachment got removed for some reason,
+		// fall to fetching from scratch with a new ID, but log as it is strange.
+		log.Warnf(ctx, "%s not found in db, refetching from scratch",
+			existingAcc.HeaderMediaAttachmentID,
+		)
+	}
+
+	// Prepare additional media info.
+	info := media.AdditionalMediaInfo{
+		Header:      util.Ptr(true),
+		RemoteURL:   &latestHeaderURL,
+		Description: &headerDescription,
+
+		// Pass reject reason ptr, which
+		// will skip downloading if set.
+		RejectReason: rejectReason,
 	}
 
 	// Fetch newly changed header.
 	attachment, err := d.GetMedia(ctx,
 		requestUser,
 		latestAcc.ID,
-		latestAcc.HeaderRemoteURL,
-		media.AdditionalMediaInfo{
-			Header:      util.Ptr(true),
-			RemoteURL:   &latestAcc.HeaderRemoteURL,
-			Description: &headerDescription,
-		},
+		latestHeaderURL,
+		info,
+		false, // async
 	)
-	if err != nil {
-		if attachment == nil {
-			return gtserror.Newf("error loading attachment %s: %w", latestAcc.HeaderRemoteURL, err)
-		}
+	switch {
+	case err == nil:
+		// No problem,
+		// loaded fine.
 
-		// non-fatal error occurred during loading, still use it.
+	case attachment == nil:
+		// Fatal error during loading, can't do anything further.
+		return gtserror.Newf("error loading attachment %s: %w",
+			latestHeaderURL, err)
+
+	default:
+		// Non-fatal error during loading, can still use it.
 		log.Warnf(ctx, "partially loaded attachment: %v", err)
 	}
 
-	// Set the header attachment on account model.
+	// Set updated header attachment info on account model.
 	latestAcc.HeaderMediaAttachment = attachment
 	latestAcc.HeaderMediaAttachmentID = attachment.ID
+	latestAcc.HeaderRemoteURL = latestHeaderURL
 
 	return nil
 }
@@ -1039,11 +1151,13 @@ func (d *Dereferencer) fetchAccountEmojis(
 	ctx context.Context,
 	existing *gtsmodel.Account,
 	account *gtsmodel.Account,
+	rejectReason *gtsmodel.MediaErrorDetails, // optional reason to reject media with
 ) error {
-	// Fetch the updated emojis for our account.
+	// Fetch the updated emojis for the account.
 	emojis, changed, err := d.fetchEmojis(ctx,
 		existing.Emojis,
 		account.Emojis,
+		rejectReason,
 	)
 	if err != nil {
 		return gtserror.Newf("error fetching emojis: %w", err)
@@ -1086,51 +1200,54 @@ func (d *Dereferencer) dereferenceAccountStats(
 	// it will just fall back to counting local.
 
 	// Followers first.
-	if count, err := d.countCollection(
+	followersCount, err := d.countCollection(
 		ctx,
 		account.FollowersURI,
 		requestUser,
-	); err != nil {
+	)
+	if err != nil {
 		// Log this but don't bail.
 		log.Warnf(ctx,
 			"couldn't count followers for @%s@%s: %v",
 			account.Username, account.Domain, err,
 		)
-	} else if count > 0 {
-		// Positive integer is useful!
-		account.Stats.FollowersCount = &count
+	} else if followersCount >= 0 {
+		// Zero or positive integer is useful!
+		account.Stats.FollowersCount = &followersCount
 	}
 
 	// Now following.
-	if count, err := d.countCollection(
+	followingCount, err := d.countCollection(
 		ctx,
 		account.FollowingURI,
 		requestUser,
-	); err != nil {
+	)
+	if err != nil {
 		// Log this but don't bail.
 		log.Warnf(ctx,
 			"couldn't count following for @%s@%s: %v",
 			account.Username, account.Domain, err,
 		)
-	} else if count > 0 {
-		// Positive integer is useful!
-		account.Stats.FollowingCount = &count
+	} else if followingCount >= 0 {
+		// Zero or positive integer is useful!
+		account.Stats.FollowingCount = &followingCount
 	}
 
 	// Now statuses count.
-	if count, err := d.countCollection(
+	statusesCount, err := d.countCollection(
 		ctx,
 		account.OutboxURI,
 		requestUser,
-	); err != nil {
+	)
+	if err != nil {
 		// Log this but don't bail.
 		log.Warnf(ctx,
 			"couldn't count statuses for @%s@%s: %v",
 			account.Username, account.Domain, err,
 		)
-	} else if count > 0 {
-		// Positive integer is useful!
-		account.Stats.StatusesCount = &count
+	} else if statusesCount >= 0 {
+		// Zero or positive integer is useful!
+		account.Stats.StatusesCount = &statusesCount
 	}
 
 	// Update stats now.
