@@ -36,21 +36,25 @@ import (
 // The wrapper is then returned to the caller.
 //
 // The provided boost wrapper status must have BoostOfURI set.
+//
+// The returned boolean indicates whether the target of the boost
+// is new (to us), ie., it has not been dereferenced or seen before.
 func (d *Dereferencer) EnrichAnnounce(
 	ctx context.Context,
 	boost *gtsmodel.Status,
 	requestUser string,
-) (*gtsmodel.Status, error) {
+	newThreadEntryCallback func(context.Context, *gtsmodel.Status) error,
+) (*gtsmodel.Status, bool, error) {
 	targetURI := boost.BoostOfURI
 	if targetURI == "" {
 		// We can't do anything.
-		return nil, gtserror.Newf("no URI to dereference")
+		return nil, false, gtserror.Newf("no URI to dereference")
 	}
 
 	// Parse the boost target status URI.
 	targetURIObj, err := url.Parse(targetURI)
 	if err != nil {
-		return nil, gtserror.Newf(
+		return nil, false, gtserror.Newf(
 			"couldn't parse boost target status URI %s: %w",
 			targetURI, err,
 		)
@@ -58,15 +62,20 @@ func (d *Dereferencer) EnrichAnnounce(
 
 	// Fetch and dereference status being boosted, noting that
 	// d.GetStatusByURI handles domain blocks and local statuses.
-	target, _, err := d.GetStatusByURI(ctx, requestUser, targetURIObj)
+	target, _, targetIsNew, err := d.GetStatusByURI(
+		ctx,
+		requestUser,
+		targetURIObj,
+		newThreadEntryCallback,
+	)
 	if err != nil {
-		return nil, gtserror.Newf("error fetching boost target %s: %w", targetURI, err)
+		return nil, false, gtserror.Newf("error fetching boost target %s: %w", targetURI, err)
 	}
 
 	if target.BoostOfID != "" {
 		// Ensure that the target is not a boost (should not be possible).
 		err := gtserror.Newf("target status %s is a boost", targetURI)
-		return nil, err
+		return nil, false, err
 	}
 
 	// Set boost_of_uri again in case the
@@ -89,13 +98,13 @@ func (d *Dereferencer) EnrichAnnounce(
 	// Ensure this Announce is permitted by the Announcee.
 	permit, err := d.isPermittedStatus(ctx, requestUser, nil, boost, true)
 	if err != nil {
-		return nil, gtserror.Newf("error checking permitted status %s: %w", boost.URI, err)
+		return nil, false, gtserror.Newf("error checking permitted status %s: %w", boost.URI, err)
 	}
 
 	if !permit {
 		// Return a checkable error type that can be ignored.
 		err := gtserror.Newf("dropping unpermitted status: %s", boost.URI)
-		return nil, gtserror.SetNotPermitted(err)
+		return nil, false, gtserror.SetNotPermitted(err)
 	}
 
 	// Generate an ID for the boost wrapper status.
@@ -113,15 +122,15 @@ func (d *Dereferencer) EnrichAnnounce(
 		// in a call to db.Put(Status). Look again in DB by URI.
 		boost, err = d.state.DB.GetStatusByURI(ctx, uri)
 		if err != nil {
-			return nil, gtserror.Newf(
+			return nil, false, gtserror.Newf(
 				"error getting boost wrapper status %s from database after race: %w",
 				uri, err,
 			)
 		}
 
 	default: // Proper database error.
-		return nil, gtserror.Newf("db error inserting status: %w", err)
+		return nil, false, gtserror.Newf("db error inserting status: %w", err)
 	}
 
-	return boost, err
+	return boost, targetIsNew, err
 }
