@@ -24,6 +24,8 @@ import (
 	"net/url"
 	"time"
 
+	"code.superseriousbusiness.org/gopkg/log"
+	"code.superseriousbusiness.org/gopkg/xslices"
 	"code.superseriousbusiness.org/gotosocial/internal/ap"
 	"code.superseriousbusiness.org/gotosocial/internal/config"
 	"code.superseriousbusiness.org/gotosocial/internal/db"
@@ -31,10 +33,8 @@ import (
 	"code.superseriousbusiness.org/gotosocial/internal/gtserror"
 	"code.superseriousbusiness.org/gotosocial/internal/gtsmodel"
 	"code.superseriousbusiness.org/gotosocial/internal/id"
-	"code.superseriousbusiness.org/gotosocial/internal/log"
 	"code.superseriousbusiness.org/gotosocial/internal/media"
 	"code.superseriousbusiness.org/gotosocial/internal/util"
-	"code.superseriousbusiness.org/gotosocial/internal/util/xslices"
 )
 
 // statusFresh returns true if the given status is still
@@ -74,13 +74,35 @@ func statusFresh(
 	return !time.Now().After(staleAt)
 }
 
-// GetStatusByURI will attempt to fetch a status by its URI, first checking the database. In the case of a newly-met remote model, or a remote model whose 'last_fetched' date
-// is beyond a certain interval, the status will be dereferenced. In the case of dereferencing, some low-priority status information may be enqueued for asynchronous fetching,
-// e.g. dereferencing the status thread. An ActivityPub object indicates the status was dereferenced.
-func (d *Dereferencer) GetStatusByURI(ctx context.Context, requestUser string, uri *url.URL) (*gtsmodel.Status, ap.Statusable, error) {
+// GetStatusByURI will attempt to fetch a status by its URI,
+// first checking the database. In the case of a newly-met
+// remote model, or a remote model whose 'last_fetched' date
+// is beyond a certain interval, the status will be dereferenced.
+//
+// A returned AP statusable indicates the status was dereferenced.
+// The returned bool indicates whether the status was new (to us).
+//
+// In the case of dereferencing, some low-priority status info
+// will be enqueued for asynchronous fetching, e.g. dereferencing
+// the status thread.
+//
+// If newThreadEntryCallback is set, it will be called for each
+// newly-discovered status in the thread other than the requested
+// status itself.
+func (d *Dereferencer) GetStatusByURI(
+	ctx context.Context,
+	requestUser string,
+	uri *url.URL,
+	newThreadEntryCallback func(context.Context, *gtsmodel.Status) error,
+) (
+	status *gtsmodel.Status,
+	statusable ap.Statusable,
+	isNew bool,
+	err error,
+) {
 
 	// Fetch and dereference / update status if necessary.
-	status, statusable, isNew, err := d.getStatusByURI(ctx,
+	status, statusable, isNew, err = d.getStatusByURI(ctx,
 		requestUser,
 		uri,
 	)
@@ -89,7 +111,7 @@ func (d *Dereferencer) GetStatusByURI(ctx context.Context, requestUser string, u
 		if status == nil {
 			// err with no existing
 			// status for fallback.
-			return nil, nil, err
+			return nil, nil, false, err
 		}
 
 		log.Errorf(ctx, "error updating status %s: %v", uri, err)
@@ -103,21 +125,29 @@ func (d *Dereferencer) GetStatusByURI(ctx context.Context, requestUser string, u
 			status,
 			statusable,
 			isNew,
+			newThreadEntryCallback,
 		)
 	}
 
-	return status, statusable, nil
+	return status, statusable, isNew, nil
 }
 
-// getStatusByURI is a package internal form of .GetStatusByURI() that doesn't dereference thread on update, and may return an existing status with error on failed re-fetch.
-func (d *Dereferencer) getStatusByURI(ctx context.Context, requestUser string, uri *url.URL) (*gtsmodel.Status, ap.Statusable, bool, error) {
-	var (
-		status *gtsmodel.Status
-		uriStr = uri.String()
-		err    error
-	)
-
-	// Search the database for existing by URI.
+// getStatusByURI is a package internal form of .GetStatusByURI()
+// that doesn't dereference thread on update, and may return
+// an existing status with error on failed re-fetch.
+func (d *Dereferencer) getStatusByURI(
+	ctx context.Context,
+	requestUser string,
+	uri *url.URL,
+) (
+	status *gtsmodel.Status,
+	statusable ap.Statusable,
+	isNew bool,
+	err error,
+) {
+	// Search the database
+	// for existing by URI.
+	uriStr := uri.String()
 	status, err = d.state.DB.GetStatusByURI(
 
 		// request a barebones object, it may be in the
@@ -165,7 +195,8 @@ func (d *Dereferencer) getStatusByURI(ctx context.Context, requestUser string, u
 		return status, nil, false, nil
 	}
 
-	// Try to deref and update existing.
+	// Status not found in db or not fresh.
+	// Try to deref new or update existing.
 	return d.enrichStatusSafely(ctx,
 		requestUser,
 		uri,
@@ -174,15 +205,28 @@ func (d *Dereferencer) getStatusByURI(ctx context.Context, requestUser string, u
 	)
 }
 
-// RefreshStatus is functionally equivalent to GetStatusByURI(), except that it requires a pre
-// populated status model (with AT LEAST uri set), and ALL thread dereferencing is asynchronous.
+// RefreshStatus is functionally equivalent to GetStatusByURI(),
+// except that it requires a pre populated status model (with AT
+// LEAST uri set), and ALL thread dereferencing is asynchronous.
+//
+// A returned AP statusable indicates the status was dereferenced.
+// The returned bool indicates whether the status was new (to us).
+//
+// If newThreadEntryCallback is set, it will be called for each
+// newly-discovered status in the thread other than the requested
+// status itself.
 func (d *Dereferencer) RefreshStatus(
 	ctx context.Context,
 	requestUser string,
 	status *gtsmodel.Status,
 	statusable ap.Statusable,
 	window *FreshnessWindow,
-) (*gtsmodel.Status, ap.Statusable, error) {
+	newThreadEntryCallback func(context.Context, *gtsmodel.Status) error,
+) (
+	latest *gtsmodel.Status,
+	latestStatusable ap.Statusable,
+	err error,
+) {
 	// If no incoming data is provided,
 	// check whether status needs update.
 	if statusable == nil &&
@@ -196,72 +240,29 @@ func (d *Dereferencer) RefreshStatus(
 		return nil, nil, gtserror.Newf("invalid status uri %q: %w", status.URI, err)
 	}
 
-	// Try to update + dereference the passed status model.
-	latest, statusable, isNew, err := d.enrichStatusSafely(ctx,
+	// Try to update + dereference
+	// the passed status model.
+	var isNew bool
+	latest, latestStatusable, isNew, err = d.enrichStatusSafely(ctx,
 		requestUser,
 		uri,
 		status,
 		statusable,
 	)
 
-	if statusable != nil {
+	if latestStatusable != nil {
 		// Deref parents + children.
 		d.dereferenceThread(ctx,
 			requestUser,
 			uri,
 			latest,
-			statusable,
+			latestStatusable,
 			isNew,
+			newThreadEntryCallback,
 		)
 	}
 
-	return latest, statusable, err
-}
-
-// RefreshStatusAsync is functionally equivalent to RefreshStatus(), except that ALL
-// dereferencing is queued for asynchronous processing, (both thread AND status).
-func (d *Dereferencer) RefreshStatusAsync(
-	ctx context.Context,
-	requestUser string,
-	status *gtsmodel.Status,
-	statusable ap.Statusable,
-	window *FreshnessWindow,
-) {
-	// If no incoming data is provided,
-	// check whether status needs update.
-	if statusable == nil &&
-		statusFresh(status, window) {
-		return
-	}
-
-	// Parse the URI from status.
-	uri, err := url.Parse(status.URI)
-	if err != nil {
-		log.Errorf(ctx, "invalid status uri %q: %v", status.URI, err)
-		return
-	}
-
-	// Enqueue a worker function to re-fetch this status entirely async.
-	d.state.Workers.Dereference.Queue.Push(func(ctx context.Context) {
-		latest, statusable, _, err := d.enrichStatusSafely(ctx,
-			requestUser,
-			uri,
-			status,
-			statusable,
-		)
-		if err != nil {
-			log.Errorf(ctx, "error enriching remote status: %v", err)
-			return
-		}
-		if statusable != nil {
-			if err := d.DereferenceStatusAncestors(ctx, requestUser, latest); err != nil {
-				log.Error(ctx, err)
-			}
-			if err := d.DereferenceStatusDescendants(ctx, requestUser, uri, statusable); err != nil {
-				log.Error(ctx, err)
-			}
-		}
-	})
+	return latest, latestStatusable, err
 }
 
 // enrichStatusSafely wraps enrichStatus() to perform it within
@@ -392,7 +393,7 @@ func (d *Dereferencer) enrichStatus(
 		return nil, nil, gtserror.Newf("couldn't create transport: %w", err)
 	}
 
-	// Check whether this account URI is a blocked domain / subdomain.
+	// Check whether this status URI is a blocked domain / subdomain.
 	if blocked, err := d.state.DB.IsDomainBlocked(ctx, uri.Host); err != nil {
 		return nil, nil, gtserror.Newf("error checking blocked domain: %w", err)
 	} else if blocked {
@@ -585,6 +586,24 @@ func (d *Dereferencer) enrichStatus(
 		return nil, nil, gtserror.Newf("error populating tags for status %s: %w", uri, err)
 	}
 
+	// Check if there's any limits in place for (sub)domain.
+	limit, err := d.state.DB.MatchDomainLimit(ctx, uri.Host)
+	if err != nil {
+		return nil, nil, gtserror.Newf("error matching domain limit: %w", err)
+	}
+
+	// If domain media is limited, set reject reason,
+	// this gets passed to media fetching functions
+	// and prevents download of attached status media.
+	var rejectReason *gtsmodel.MediaErrorDetails
+	if limit.MediaReject() {
+		rejectReason = new(gtsmodel.MediaErrorDetails)
+		*rejectReason = gtsmodel.NewMediaErrorDetails(
+			gtsmodel.MediaErrorTypePolicy,
+			gtsmodel.MediaErrorTypePolicy_Domain,
+		)
+	}
+
 	// Populate media attachments associated with status,
 	// passing in existing status to reuse old where possible
 	// (especially important here to reduce need to dereference).
@@ -592,6 +611,7 @@ func (d *Dereferencer) enrichStatus(
 		requestUser,
 		status,
 		latestStatus,
+		rejectReason,
 	)
 	if err != nil {
 		return nil, nil, gtserror.Newf("error populating attachments for status %s: %w", uri, err)
@@ -603,6 +623,7 @@ func (d *Dereferencer) enrichStatus(
 	emojiChanged, err := d.fetchStatusEmojis(ctx,
 		status,
 		latestStatus,
+		rejectReason,
 	)
 	if err != nil {
 		return nil, nil, gtserror.Newf("error populating emojis for status %s: %w", uri, err)
@@ -811,21 +832,25 @@ func (d *Dereferencer) fetchStatusAttachments(
 	requestUser string,
 	existing *gtsmodel.Status,
 	status *gtsmodel.Status,
+	rejectReason *gtsmodel.MediaErrorDetails, // optional reason to reject media with
 ) (
 	changed bool,
 	err error,
 ) {
-
 	// Allocate new slice to take the yet-to-be fetched attachment IDs.
 	status.AttachmentIDs = make([]string, len(status.Attachments))
-
 	for i := range status.Attachments {
 		placeholder := status.Attachments[i]
 
 		// Look for existing media attachment with remote URL first.
 		existing, ok := existing.GetAttachmentByRemoteURL(placeholder.RemoteURL)
 		if ok && existing.ID != "" {
-			var info media.AdditionalMediaInfo
+
+			info := media.AdditionalMediaInfo{
+				// Pass reject reason ptr, which
+				// will skip downloading if set.
+				RejectReason: rejectReason,
+			}
 
 			// Look for any difference in stored media description.
 			diff := (existing.Description != placeholder.Description)
@@ -837,13 +862,15 @@ func (d *Dereferencer) fetchStatusAttachments(
 			// we mark media as changed.
 			changed = changed || diff
 
-			// Store any attachment updates and
-			// ensure media is locally cached.
+			// Store any attachment updates
+			// and ensure media is locally
+			// cached (if appropriate).
 			existing, err := d.RefreshMedia(ctx,
 				requestUser,
 				existing,
 				info,
 				diff,
+				true, // async
 			)
 			if err != nil {
 				log.Errorf(ctx, "error updating existing attachment: %v", err)
@@ -876,7 +903,12 @@ func (d *Dereferencer) fetchStatusAttachments(
 				Blurhash:    &placeholder.Blurhash,
 				FocusX:      &placeholder.FileMeta.Focus.X,
 				FocusY:      &placeholder.FileMeta.Focus.Y,
+
+				// Pass reject reason ptr, which
+				// will skip downloading if set.
+				RejectReason: rejectReason,
 			},
+			false, // async
 		)
 		if err != nil {
 			if attachment == nil {
@@ -914,6 +946,7 @@ func (d *Dereferencer) fetchStatusEmojis(
 	ctx context.Context,
 	existing *gtsmodel.Status,
 	status *gtsmodel.Status,
+	rejectReason *gtsmodel.MediaErrorDetails, // optional reason to reject media with
 ) (
 	changed bool,
 	err error,
@@ -923,6 +956,7 @@ func (d *Dereferencer) fetchStatusEmojis(
 	emojis, changed, err := d.fetchEmojis(ctx,
 		existing.Emojis,
 		status.Emojis,
+		rejectReason,
 	)
 	if err != nil {
 		return changed, gtserror.Newf("error fetching emojis: %w", err)
