@@ -23,13 +23,13 @@ import (
 	"net/url"
 	"time"
 
+	"code.superseriousbusiness.org/gopkg/log"
 	"code.superseriousbusiness.org/gotosocial/internal/ap"
 	"code.superseriousbusiness.org/gotosocial/internal/db"
 	"code.superseriousbusiness.org/gotosocial/internal/gtscontext"
 	"code.superseriousbusiness.org/gotosocial/internal/gtserror"
 	"code.superseriousbusiness.org/gotosocial/internal/gtsmodel"
 	"code.superseriousbusiness.org/gotosocial/internal/id"
-	"code.superseriousbusiness.org/gotosocial/internal/log"
 	"code.superseriousbusiness.org/gotosocial/internal/uris"
 	"code.superseriousbusiness.org/gotosocial/internal/util"
 )
@@ -372,7 +372,7 @@ func (d *Dereferencer) unpermittedByParent(
 		TargetStatusID:        inReplyToID,
 		TargetAccountID:       targetAccountID,
 		InteractingAccountID:  reply.AccountID,
-		InteractionRequestURI: gtsmodel.ForwardCompatibleInteractionRequestURI(reply.URI, gtsmodel.ReplyRequestSuffix),
+		InteractionRequestURI: reply.URI + gtsmodel.ImpoliteReplyRequestSuffix,
 		InteractionURI:        reply.URI,
 		InteractionType:       gtsmodel.InteractionReply,
 		Polite:                util.Ptr(false),
@@ -506,7 +506,7 @@ func (d *Dereferencer) rejectedByPolicy(
 		TargetStatusID:        inReplyTo.ID,
 		TargetAccountID:       inReplyTo.AccountID,
 		InteractingAccountID:  reply.AccountID,
-		InteractionRequestURI: gtsmodel.ForwardCompatibleInteractionRequestURI(reply.URI, gtsmodel.ReplyRequestSuffix),
+		InteractionRequestURI: reply.URI + gtsmodel.ImpoliteReplyRequestSuffix,
 		InteractionURI:        reply.URI,
 		InteractionType:       gtsmodel.InteractionReply,
 		Polite:                util.Ptr(false),
