@@ -25,12 +25,12 @@ import (
 	"time"
 
 	"code.superseriousbusiness.org/activity/streams/vocab"
+	"code.superseriousbusiness.org/gopkg/log"
 	"code.superseriousbusiness.org/gotosocial/internal/ap"
 	"code.superseriousbusiness.org/gotosocial/internal/config"
 	"code.superseriousbusiness.org/gotosocial/internal/db"
 	"code.superseriousbusiness.org/gotosocial/internal/gtserror"
 	"code.superseriousbusiness.org/gotosocial/internal/gtsmodel"
-	"code.superseriousbusiness.org/gotosocial/internal/log"
 	"code.superseriousbusiness.org/gotosocial/internal/messages"
 	"code.superseriousbusiness.org/gotosocial/internal/uris"
 	"code.superseriousbusiness.org/gotosocial/internal/util"
@@ -48,7 +48,7 @@ func (f *DB) GetAccept(
 }
 
 func (f *DB) Accept(ctx context.Context, accept vocab.ActivityStreamsAccept) error {
-	log.DebugKV(ctx, "accept", serialize{accept})
+	log.DebugKV(ctx, "accept", Serialize{accept})
 
 	activityContext := getActivityContext(ctx)
 	if activityContext.internal {
@@ -726,9 +726,6 @@ func (f *DB) parseAcceptInteractionRequestable(
 	} else {
 
 		// Request stored for this interaction URI.
-		//
-		// Note: this path is not actually possible until v0.21.0,
-		// because we don't send out polite requests yet in v0.20.0.
 
 		// If the request is already accepted,
 		// we don't need to do anything at all.
