@@ -23,14 +23,14 @@ import (
 	"slices"
 
 	"code.superseriousbusiness.org/activity/streams/vocab"
+	"code.superseriousbusiness.org/gopkg/log"
 	"code.superseriousbusiness.org/gotosocial/internal/ap"
 	"code.superseriousbusiness.org/gotosocial/internal/gtserror"
-	"code.superseriousbusiness.org/gotosocial/internal/log"
 	"code.superseriousbusiness.org/gotosocial/internal/messages"
 )
 
 func (f *DB) Announce(ctx context.Context, announce vocab.ActivityStreamsAnnounce) error {
-	log.DebugKV(ctx, "announce", serialize{announce})
+	log.DebugKV(ctx, "announce", Serialize{announce})
 
 	activityContext := getActivityContext(ctx)
 	if activityContext.internal {
