@@ -23,16 +23,16 @@ import (
 	"net/http"
 
 	"code.superseriousbusiness.org/activity/streams/vocab"
+	"code.superseriousbusiness.org/gopkg/log"
 	"code.superseriousbusiness.org/gotosocial/internal/ap"
 	"code.superseriousbusiness.org/gotosocial/internal/db"
 	"code.superseriousbusiness.org/gotosocial/internal/gtserror"
 	"code.superseriousbusiness.org/gotosocial/internal/id"
-	"code.superseriousbusiness.org/gotosocial/internal/log"
 	"code.superseriousbusiness.org/gotosocial/internal/messages"
 )
 
 func (f *DB) Like(ctx context.Context, likeable vocab.ActivityStreamsLike) error {
-	log.DebugKV(ctx, "like", serialize{likeable})
+	log.DebugKV(ctx, "like", Serialize{likeable})
 
 	// Mark activity as handled.
 	f.storeActivityID(likeable)
