@@ -28,15 +28,15 @@ import (
 	"fmt"
 
 	"code.superseriousbusiness.org/activity/streams/vocab"
+	"code.superseriousbusiness.org/gopkg/log"
 	"code.superseriousbusiness.org/gotosocial/internal/ap"
 	"code.superseriousbusiness.org/gotosocial/internal/gtserror"
 	"code.superseriousbusiness.org/gotosocial/internal/gtsmodel"
-	"code.superseriousbusiness.org/gotosocial/internal/log"
 	"code.superseriousbusiness.org/gotosocial/internal/messages"
 )
 
 func (f *DB) Move(ctx context.Context, move vocab.ActivityStreamsMove) error {
-	log.DebugKV(ctx, "move", serialize{move})
+	log.DebugKV(ctx, "move", Serialize{move})
 
 	// Mark activity as handled.
 	f.storeActivityID(move)
