@@ -23,19 +23,19 @@ import (
 	"time"
 
 	"code.superseriousbusiness.org/activity/streams/vocab"
+	"code.superseriousbusiness.org/gopkg/log"
 	"code.superseriousbusiness.org/gotosocial/internal/ap"
 	"code.superseriousbusiness.org/gotosocial/internal/db"
 	"code.superseriousbusiness.org/gotosocial/internal/gtserror"
 	"code.superseriousbusiness.org/gotosocial/internal/gtsmodel"
 	"code.superseriousbusiness.org/gotosocial/internal/id"
-	"code.superseriousbusiness.org/gotosocial/internal/log"
 	"code.superseriousbusiness.org/gotosocial/internal/messages"
 	"code.superseriousbusiness.org/gotosocial/internal/uris"
 	"code.superseriousbusiness.org/gotosocial/internal/util"
 )
 
 func (f *DB) Reject(ctx context.Context, reject vocab.ActivityStreamsReject) error {
-	log.DebugKV(ctx, "reject", serialize{reject})
+	log.DebugKV(ctx, "reject", Serialize{reject})
 
 	activityContext := getActivityContext(ctx)
 	if activityContext.internal {
@@ -313,14 +313,14 @@ func (f *DB) rejectStatusIRI(
 
 		if apObjectType == ap.ObjectNote {
 			// Reply.
-			req.InteractionRequestURI = gtsmodel.ForwardCompatibleInteractionRequestURI(status.URI, gtsmodel.ReplyRequestSuffix)
+			req.InteractionRequestURI = status.URI + gtsmodel.ImpoliteReplyRequestSuffix
 			req.InteractionType = gtsmodel.InteractionReply
 			req.TargetStatusID = status.InReplyToID
 			req.TargetStatus = status.InReplyTo
 			req.Reply = status
 		} else {
 			// Announce.
-			req.InteractionRequestURI = gtsmodel.ForwardCompatibleInteractionRequestURI(status.URI, gtsmodel.AnnounceRequestSuffix)
+			req.InteractionRequestURI = status.URI + gtsmodel.ImpoliteAnnounceRequestSuffix
 			req.InteractionType = gtsmodel.InteractionAnnounce
 			req.TargetStatusID = status.BoostOfID
 			req.TargetStatus = status.BoostOf
@@ -439,7 +439,7 @@ func (f *DB) rejectLikeIRI(
 			TargetAccount:         requestingAcct,
 			InteractingAccountID:  receivingAcct.ID,
 			InteractingAccount:    receivingAcct,
-			InteractionRequestURI: gtsmodel.ForwardCompatibleInteractionRequestURI(fave.URI, gtsmodel.LikeRequestSuffix),
+			InteractionRequestURI: fave.URI + gtsmodel.ImpoliteLikeRequestSuffix,
 			InteractionURI:        fave.URI,
 			InteractionType:       gtsmodel.InteractionLike,
 			Polite:                util.Ptr(false),
