@@ -23,17 +23,17 @@ import (
 	"fmt"
 
 	"code.superseriousbusiness.org/activity/streams/vocab"
+	"code.superseriousbusiness.org/gopkg/log"
 	"code.superseriousbusiness.org/gotosocial/internal/ap"
 	"code.superseriousbusiness.org/gotosocial/internal/db"
 	"code.superseriousbusiness.org/gotosocial/internal/gtscontext"
 	"code.superseriousbusiness.org/gotosocial/internal/gtserror"
 	"code.superseriousbusiness.org/gotosocial/internal/gtsmodel"
-	"code.superseriousbusiness.org/gotosocial/internal/log"
 	"code.superseriousbusiness.org/gotosocial/internal/messages"
 )
 
 func (f *DB) Undo(ctx context.Context, undo vocab.ActivityStreamsUndo) error {
-	log.DebugKV(ctx, "undo", serialize{undo})
+	log.DebugKV(ctx, "undo", Serialize{undo})
 
 	activityContext := getActivityContext(ctx)
 	if activityContext.internal {
