@@ -22,12 +22,12 @@ import (
 	"errors"
 
 	"code.superseriousbusiness.org/activity/streams/vocab"
+	"code.superseriousbusiness.org/gopkg/log"
 	"code.superseriousbusiness.org/gotosocial/internal/ap"
 	"code.superseriousbusiness.org/gotosocial/internal/config"
 	"code.superseriousbusiness.org/gotosocial/internal/db"
 	"code.superseriousbusiness.org/gotosocial/internal/gtserror"
 	"code.superseriousbusiness.org/gotosocial/internal/gtsmodel"
-	"code.superseriousbusiness.org/gotosocial/internal/log"
 	"code.superseriousbusiness.org/gotosocial/internal/messages"
 )
 
@@ -41,7 +41,7 @@ import (
 //
 // The library makes this call only after acquiring a lock first.
 func (f *DB) Update(ctx context.Context, asType vocab.Type) error {
-	log.DebugKV(ctx, "update", serialize{asType})
+	log.DebugKV(ctx, "update", Serialize{asType})
 
 	// Mark activity as handled.
 	f.storeActivityID(asType)
