@@ -28,6 +28,7 @@ import (
 	"code.superseriousbusiness.org/gotosocial/internal/gtscontext"
 	"code.superseriousbusiness.org/gotosocial/internal/gtserror"
 	"code.superseriousbusiness.org/gotosocial/internal/gtsmodel"
+	"code.superseriousbusiness.org/gotosocial/internal/typeutils"
 )
 
 // StatusFilterResultsInContext returns status filtering results, limited
@@ -223,7 +224,7 @@ func (f *Filter) getStatusFilterResults(
 
 			// Wrap matches in frontend API model.
 			apiResult = &apimodel.FilterResult{
-				Filter: toAPIFilterV2(filter),
+				Filter: (*typeutils.FilterToAPIFilterV2(filter)),
 
 				KeywordMatches: keywordMatches,
 				StatusMatches:  statusMatches,
@@ -283,6 +284,59 @@ func (f *Filter) getStatusFilterResults(
 		}
 	}
 
+	// If requester doesn't follow the author, check if this status is from a
+	// domain that's limited, as we may need to apply an ad-hoc warn / hide filter.
+	following, err := f.state.DB.IsFollowing(ctx, requester.ID, status.AccountID)
+	if err != nil {
+		return results, gtserror.Newf("db error checking following: %w", err)
+	}
+
+	if !following {
+		// Check if account's domain has domain limits.
+		limit, err := f.state.DB.MatchDomainLimit(ctx,
+			status.Account.Domain)
+		if err != nil {
+			return results, gtserror.Newf("error matching domain limit: %w", err)
+		}
+
+		if limit.StatusesFilter() {
+			// Later stored API result, if any.
+			// (for the HIDE action, it is unset).
+			var apiResult *apimodel.FilterResult
+
+			switch limit.StatusesPolicy {
+			case gtsmodel.StatusesPolicyFilterHide:
+			case gtsmodel.StatusesPolicyFilterWarn:
+				// Wrap domain match in API model.
+				apiResult = &apimodel.FilterResult{
+					Filter:         *typeutils.DomainLimitToAPIFilterV2(limit),
+					KeywordMatches: []string{limit.Domain},
+				}
+			}
+
+			// Wrap the filter policy in our cache model.
+			// This model simply existing implies this
+			// status has been filtered, defaulting to
+			// action HIDE, or WARN on a non-nil result.
+			result := cache.StatusFilterResult{
+				Result: apiResult,
+
+				// limits *never* expire.
+				Expiry: time.Time{},
+			}
+
+			// Append domain limit result to apply
+			// in HOME, PUBLIC and THREAD contexts.
+			for _, key := range [3]int{
+				cache.KeyContextHome,
+				cache.KeyContextPublic,
+				cache.KeyContextThread,
+			} {
+				results[key] = append(results[key], result)
+			}
+		}
+	}
+
 	// Iterate all filter results.
 	for _, key := range [5]int{
 		cache.KeyContextHome,
