@@ -24,23 +24,22 @@ import (
 // MediaAttachment represents a user-uploaded media attachment: an image/video/audio/gif that is
 // somewhere in storage and that can be retrieved and served by the router.
 type MediaAttachment struct {
-	ID                string           `bun:"type:CHAR(26),pk,nullzero,notnull,unique"`                    // id of this item in the database
-	CreatedAt         time.Time        `bun:"type:timestamptz,nullzero,notnull,default:current_timestamp"` // when was item created
-	StatusID          string           `bun:"type:CHAR(26),nullzero"`                                      // ID of the status to which this is attached
-	URL               string           `bun:",nullzero"`                                                   // Where can the attachment be retrieved on *this* server
-	RemoteURL         string           `bun:",nullzero"`                                                   // Where can the attachment be retrieved on a remote server (empty for local media)
-	Type              FileType         `bun:",notnull,default:0"`                                          // Type of file (image/gifv/audio/video/unknown)
-	FileMeta          FileMeta         `bun:",embed:,notnull"`                                             // Metadata about the file
-	AccountID         string           `bun:"type:CHAR(26),nullzero,notnull"`                              // To which account does this attachment belong
-	Description       string           `bun:""`                                                            // Description of the attachment (for screenreaders)
-	ScheduledStatusID string           `bun:"type:CHAR(26),nullzero"`                                      // To which scheduled status does this attachment belong
-	Blurhash          string           `bun:",nullzero"`                                                   // What is the generated blurhash of this attachment
-	Processing        ProcessingStatus `bun:",notnull,default:2"`                                          // What is the processing status of this attachment
-	File              File             `bun:",embed:file_,notnull,nullzero"`                               // metadata for the whole file
-	Thumbnail         Thumbnail        `bun:",embed:thumbnail_,notnull,nullzero"`                          // small image thumbnail derived from a larger image, video, or audio file.
-	Avatar            *bool            `bun:",nullzero,notnull,default:false"`                             // Is this attachment being used as an avatar?
-	Header            *bool            `bun:",nullzero,notnull,default:false"`                             // Is this attachment being used as a header?
-	Cached            *bool            `bun:",nullzero,notnull,default:false"`                             // Is this attachment currently cached by our instance?
+	ID                string            `bun:"type:CHAR(26),pk,nullzero,notnull,unique"`                    // id of this item in the database
+	CreatedAt         time.Time         `bun:"type:timestamptz,nullzero,notnull,default:current_timestamp"` // when was item created
+	StatusID          string            `bun:"type:CHAR(26),nullzero"`                                      // ID of the status to which this is attached
+	URL               string            `bun:",nullzero"`                                                   // Where can the attachment be retrieved on *this* server
+	RemoteURL         string            `bun:",nullzero"`                                                   // Where can the attachment be retrieved on a remote server (empty for local media)
+	Type              FileType          `bun:",notnull,default:0"`                                          // Type of file (image/gifv/audio/video/unknown)
+	Error             MediaErrorDetails `bun:",notnull,default:0"`                                          // Details about any error encountered downloading file
+	FileMeta          FileMeta          `bun:",embed:,notnull"`                                             // Metadata about the file
+	AccountID         string            `bun:"type:CHAR(26),nullzero,notnull"`                              // To which account does this attachment belong
+	Description       string            `bun:""`                                                            // Description of the attachment (for screenreaders)
+	ScheduledStatusID string            `bun:"type:CHAR(26),nullzero"`                                      // To which scheduled status does this attachment belong
+	Blurhash          string            `bun:",nullzero"`                                                   // What is the generated blurhash of this attachment
+	File              File              `bun:",embed:file_,notnull,nullzero"`                               // metadata for the whole file
+	Thumbnail         Thumbnail         `bun:",embed:thumbnail_,notnull,nullzero"`                          // small image thumbnail derived from a larger image, video, or audio file.
+	Avatar            *bool             `bun:",nullzero,notnull,default:false"`                             // Is this attachment being used as an avatar?
+	Header            *bool             `bun:",nullzero,notnull,default:false"`                             // Is this attachment being used as a header?
 }
 
 // IsLocal returns whether media attachment is local.
@@ -53,13 +52,37 @@ func (m *MediaAttachment) IsRemote() bool {
 	return m.RemoteURL != ""
 }
 
-// File refers to the metadata for the whole file
+// Cached returns whether MediaAttachment is cached locally.
+func (m *MediaAttachment) Cached() bool {
+	return m.File.Cached() && m.Thumbnail.Cached()
+}
+
+// Stub will reset all non-essential attachment
+// fields, leaving it in the bare never-downloaded state.
+func (m *MediaAttachment) Stub() {
+
+	// we specifically don't stub
+	// out filemeta or URLs, as it
+	// can be useful if it's going
+	// to be later recached.
+	m.File.ContentType = ""
+	m.File.FileSize = 0
+	m.File.Path = ""
+	m.Thumbnail.FileSize = 0
+	m.Thumbnail.ContentType = ""
+	m.Thumbnail.Path = ""
+}
+
+// File refers to the metadata for the whole file.
 type File struct {
 	Path        string `bun:",notnull"` // Path of the file in storage.
 	ContentType string `bun:",notnull"` // MIME content type of the file.
 	FileSize    int    `bun:",notnull"` // File size in bytes
 }
 
+// Cached returns whether this File is cached locally.
+func (f File) Cached() bool { return f.Path != "" }
+
 // Thumbnail refers to a small image thumbnail derived from a larger image, video, or audio file.
 type Thumbnail struct {
 	Path        string `bun:",notnull"`  // Path of the file in storage.
@@ -69,20 +92,12 @@ type Thumbnail struct {
 	RemoteURL   string `bun:",nullzero"` // What is the remote URL of the thumbnail (empty for local media)
 }
 
-// ProcessingStatus refers to how far along in the processing stage the attachment is.
-type ProcessingStatus int
-
-// MediaAttachment processing states.
-const (
-	ProcessingStatusReceived   ProcessingStatus = 0   // ProcessingStatusReceived indicates the attachment has been received and is awaiting processing. No thumbnail available yet.
-	ProcessingStatusProcessing ProcessingStatus = 1   // ProcessingStatusProcessing indicates the attachment is currently being processed. Thumbnail is available but full media is not.
-	ProcessingStatusProcessed  ProcessingStatus = 2   // ProcessingStatusProcessed indicates the attachment has been fully processed and is ready to be served.
-	ProcessingStatusError      ProcessingStatus = 666 // ProcessingStatusError indicates something went wrong processing the attachment and it won't be tried again--these can be deleted.
-)
+// Cached returns whether this Thumbnail is cached locally.
+func (t Thumbnail) Cached() bool { return t.Path != "" }
 
 // FileType refers to the file
 // type of the media attaachment.
-type FileType int
+type FileType enumType
 
 const (
 	// MediaAttachment file types.
