@@ -22,8 +22,8 @@ import (
 	"math/big"
 	"time"
 
+	"code.superseriousbusiness.org/gopkg/log"
 	"code.superseriousbusiness.org/gotosocial/internal/gtserror"
-	"code.superseriousbusiness.org/gotosocial/internal/log"
 	"codeberg.org/gruf/go-kv/v2"
 	"github.com/oklog/ulid"
 )
@@ -102,3 +102,13 @@ func TimeFromULID(id string) (time.Time, error) {
 	}
 	return ulid.Time(parsed.Time()), nil
 }
+
+// ZeroULIDForTime returns the zero-value ULID for given time.
+func ZeroULIDForTime(t time.Time) string {
+	ts := ulid.Timestamp(t)
+	var ulid ulid.ULID
+	if err := ulid.SetTime(ts); err != nil {
+		panic(err)
+	}
+	return ulid.String()
+}
