@@ -23,10 +23,10 @@ import (
 	"strings"
 	"time"
 
+	"code.superseriousbusiness.org/gopkg/log"
 	"code.superseriousbusiness.org/gotosocial/internal/gtserror"
 	"code.superseriousbusiness.org/gotosocial/internal/gtsmodel"
 	"code.superseriousbusiness.org/gotosocial/internal/id"
-	"code.superseriousbusiness.org/gotosocial/internal/log"
 	"code.superseriousbusiness.org/gotosocial/internal/state"
 	"code.superseriousbusiness.org/gotosocial/internal/storage"
 	"code.superseriousbusiness.org/gotosocial/internal/uris"
@@ -112,14 +112,12 @@ func (m *Manager) CreateMedia(
 	// leaving out fields with values we don't know
 	// yet. These will be overwritten as we go.
 	attachment := &gtsmodel.MediaAttachment{
-		ID:         id.NewULID(),
-		AccountID:  accountID,
-		Type:       gtsmodel.FileTypeUnknown,
-		Processing: gtsmodel.ProcessingStatusReceived,
-		Avatar:     util.Ptr(false),
-		Header:     util.Ptr(false),
-		Cached:     util.Ptr(false),
-		CreatedAt:  now,
+		ID:        id.NewULID(),
+		AccountID: accountID,
+		Type:      gtsmodel.FileTypeUnknown,
+		Avatar:    util.Ptr(false),
+		Header:    util.Ptr(false),
+		CreatedAt: now,
 	}
 
 	// Check if we were provided additional info
@@ -160,7 +158,7 @@ func (m *Manager) CreateMedia(
 	}
 
 	// Pass prepared media as ready to be cached.
-	return m.CacheMedia(attachment, data), nil
+	return m.CacheMedia(attachment, data, info), nil
 }
 
 // CacheMedia wraps a media model (assumed already
@@ -170,11 +168,26 @@ func (m *Manager) CreateMedia(
 func (m *Manager) CacheMedia(
 	media *gtsmodel.MediaAttachment,
 	data DataFunc,
+	info AdditionalMediaInfo,
 ) *ProcessingMedia {
+	var stubErr error
+
+	if reason := info.RejectReason; reason != nil {
+		// If a predefined reject reason was provided,
+		// don't download and return early with error.
+		stubErr = &errWithDetails{details: *reason}
+	} else if details := media.Error; !details.SupportsRetry() {
+		// If failed to download due to an existing error,
+		// don't attempt redownload, return early with error.
+		err := gtserror.New("unretryable error: " + details.String())
+		stubErr = &errWithDetails{error: err, details: details}
+	}
+
 	return &ProcessingMedia{
 		media:  media,
 		dataFn: data,
 		mgr:    m,
+		err:    stubErr,
 	}
 }
 
@@ -251,51 +264,56 @@ func (m *Manager) UpdateEmoji(
 	oldStaticPath := emoji.ImageStaticPath
 	oldPath := emoji.ImagePath
 
-	// Since this is a refresh we will end up storing new images at new
-	// paths, so we should wrap closer to delete old paths at completion.
-	wrapped := func(ctx context.Context) (io.ReadCloser, error) {
+	// Check whether old emoji paths were set.
+	if oldPath != "" || oldStaticPath != "" {
+		unwrapped := data
 
-		// Call original func.
-		rc, err := data(ctx)
-		if err != nil {
-			return nil, err
-		}
+		// Since this is a refresh we will end up storing new images at new
+		// paths, so we should wrap closer to delete old paths at completion.
+		data = func(ctx context.Context) (io.ReadCloser, error) {
 
-		// Cast as separated reader / closer types.
-		rct, ok := rc.(*iotools.ReadCloserType)
-
-		if !ok {
-			// Allocate new read closer type.
-			rct = new(iotools.ReadCloserType)
-			rct.Reader = rc
-			rct.Closer = rc
-		}
-
-		// Wrap underlying io.Closer type to cleanup old data.
-		rct.Closer = iotools.CloserCallback(rct.Closer, func() {
-
-			// Remove any *old* emoji image file path now stream is closed.
-			if err := m.state.Storage.Delete(ctx, oldPath); err != nil &&
-				!storage.IsNotFound(err) {
-				log.Errorf(ctx, "error deleting old emoji %s from storage: %v", shortcodeDomain, err)
+			// Call original data func.
+			rc, err := unwrapped(ctx)
+			if err != nil {
+				return nil, err
 			}
 
-			// Remove any *old* emoji static image file path now stream is closed.
-			if err := m.state.Storage.Delete(ctx, oldStaticPath); err != nil &&
-				!storage.IsNotFound(err) {
-				log.Errorf(ctx, "error deleting old static emoji %s from storage: %v", shortcodeDomain, err)
-			}
-		})
+			// Cast as separated reader / closer types.
+			rct, ok := rc.(*iotools.ReadCloserType)
 
-		return rct, nil
+			if !ok {
+				// Allocate new read closer type.
+				rct = new(iotools.ReadCloserType)
+				rct.Reader = rc
+				rct.Closer = rc
+			}
+
+			// Wrap underlying io.Closer type to cleanup old paths.
+			rct.Closer = iotools.CloserCallback(rct.Closer, func() {
+
+				// Remove any *old* emoji image file path now stream is closed.
+				if err := m.state.Storage.Delete(ctx, oldPath); err != nil &&
+					!storage.IsNotFound(err) {
+					log.Errorf(ctx, "error deleting old emoji %s from storage: %v", shortcodeDomain, err)
+				}
+
+				// Remove any *old* emoji static image file path now stream is closed.
+				if err := m.state.Storage.Delete(ctx, oldStaticPath); err != nil &&
+					!storage.IsNotFound(err) {
+					log.Errorf(ctx, "error deleting old static emoji %s from storage: %v", shortcodeDomain, err)
+				}
+			})
+
+			return rct, nil
+		}
 	}
 
-	// Update existing emoji in database.
+	// Update existing emoji model in the database.
 	processingEmoji, err := m.createOrUpdateEmoji(ctx,
 		func(ctx context.Context, emoji *gtsmodel.Emoji) error {
 			return m.state.DB.UpdateEmoji(ctx, emoji)
 		},
-		wrapped,
+		data,
 		emoji,
 		info,
 	)
@@ -317,6 +335,7 @@ func (m *Manager) CacheEmoji(
 	ctx context.Context,
 	emoji *gtsmodel.Emoji,
 	data DataFunc,
+	info AdditionalEmojiInfo,
 ) (
 	*ProcessingEmoji,
 	error,
@@ -336,12 +355,26 @@ func (m *Manager) CacheEmoji(
 		pathID = id
 	}
 
+	var stubErr error
+
+	if reason := info.RejectReason; reason != nil {
+		// If a predefined reject reason was provided,
+		// don't download and return early with error.
+		stubErr = &errWithDetails{details: *reason}
+	} else if details := emoji.Error; !details.SupportsRetry() {
+		// If failed to download due to an existing error,
+		// don't attempt redownload, return early with error.
+		err := gtserror.New("unretryable error: " + details.String())
+		stubErr = &errWithDetails{error: err, details: details}
+	}
+
 	return &ProcessingEmoji{
 		newPathID: pathID,
 		instAccID: instanceAcc.ID,
 		emoji:     emoji,
 		dataFn:    data,
 		mgr:       m,
+		err:       stubErr,
 	}, nil
 }
 
@@ -365,6 +398,8 @@ func (m *Manager) createOrUpdateEmoji(
 		return nil, gtserror.Newf("error fetching instance account: %w", err)
 	}
 
+	var stubErr error
+
 	// Check if we have additional info to add to the emoji,
 	// and overwrite some of the emoji fields if so.
 	if info.URI != nil {
@@ -388,6 +423,16 @@ func (m *Manager) createOrUpdateEmoji(
 	if info.CategoryID != nil {
 		emoji.CategoryID = *info.CategoryID
 	}
+	if reason := info.RejectReason; reason != nil {
+		// If a predefined reject reason was provided,
+		// don't download and return early with error.
+		stubErr = &errWithDetails{details: *reason}
+	} else if details := emoji.Error; !details.SupportsRetry() {
+		// If failed to download due to an existing error,
+		// don't attempt redownload, return early with error.
+		err := gtserror.New("unretryable error: " + details.String())
+		stubErr = &errWithDetails{error: err, details: details}
+	}
 
 	// Put or update emoji in database.
 	if err := storeDB(ctx, emoji); err != nil {
@@ -400,6 +445,7 @@ func (m *Manager) createOrUpdateEmoji(
 		emoji:     emoji,
 		dataFn:    data,
 		mgr:       m,
+		err:       stubErr,
 	}
 
 	return processingEmoji, nil
@@ -407,6 +453,7 @@ func (m *Manager) createOrUpdateEmoji(
 
 // extractEmojiPathID pulls the ID used in the final path segment of an emoji path (can be URL).
 func extractEmojiPathID(path string) string {
+
 	// Look for '.' indicating file ext.
 	i := strings.LastIndexByte(path, '.')
 	if i == -1 {
