@@ -21,14 +21,14 @@ import (
 	"context"
 	"os"
 
+	"codeberg.org/gruf/go-errors/v2"
 	errorsv2 "codeberg.org/gruf/go-errors/v2"
-	"codeberg.org/gruf/go-kv/v2"
 	"codeberg.org/gruf/go-runners"
 
+	"code.superseriousbusiness.org/gopkg/log"
 	"code.superseriousbusiness.org/gotosocial/internal/config"
 	"code.superseriousbusiness.org/gotosocial/internal/gtserror"
 	"code.superseriousbusiness.org/gotosocial/internal/gtsmodel"
-	"code.superseriousbusiness.org/gotosocial/internal/log"
 	"code.superseriousbusiness.org/gotosocial/internal/storage"
 	"code.superseriousbusiness.org/gotosocial/internal/uris"
 	"code.superseriousbusiness.org/gotosocial/internal/util"
@@ -38,29 +38,41 @@ import (
 // currently being processed. It exposes functions
 // for retrieving data from the process.
 type ProcessingMedia struct {
-	media  *gtsmodel.MediaAttachment // processing media attachment details
-	dataFn DataFunc                  // load-data function, returns media stream
-	done   bool                      // done is set when process finishes with non ctx canceled type error
-	proc   runners.Processor         // proc helps synchronize only a singular running processing instance
-	err    error                     // error stores permanent error value when done
-	mgr    *Manager                  // mgr instance (access to db / storage)
+
+	// processing media attach details.
+	media *gtsmodel.MediaAttachment
+
+	// load data function,
+	// returns media stream.
+	dataFn DataFunc
+
+	// proc helps synchronize only a
+	// singular running processing instance
+	proc runners.Processor
+
+	// error stores permanent value when done,
+	// or alternatively may store a preset stubError{}
+	// value with details to allow skipping processing.
+	err error
+
+	// mgr instance, for access to
+	// db / storage during processing
+	mgr *Manager
+
+	// done is set when process finishes
+	// with non ctx canceled type error
+	done bool
 }
 
-// ID returns the ID of the underlying media.
-func (p *ProcessingMedia) ID() string {
-	return p.media.ID // immutable, safe outside mutex.
-}
-
-// LoadAttachment blocks until the thumbnail and
-// fullsize content has been processed, and then
-// returns the attachment.
-//
-// If processing could not be completed fully
-// then an error will be returned. The attachment
-// will still be returned in that case, but it will
-// only be partially complete and should be treated
-// as a placeholder.
+// MustLoad blocks until the thumbnail and fullsize image has been processed, and then returns the completed media.
 func (p *ProcessingMedia) Load(ctx context.Context) (*gtsmodel.MediaAttachment, error) {
+	media, _, err := p.load(ctx)
+	return media, err
+}
+
+// MustLoad blocks until the thumbnail and fullsize image has been processed, and then returns the completed
+// media. On context cancelled this will enqueue the load for asynchronous operation by dereference worker.
+func (p *ProcessingMedia) MustLoad(ctx context.Context) (*gtsmodel.MediaAttachment, error) {
 	media, done, err := p.load(ctx)
 	if !done {
 		// On a context-canceled error (marked as !done), requeue for loading.
@@ -74,16 +86,46 @@ func (p *ProcessingMedia) Load(ctx context.Context) (*gtsmodel.MediaAttachment,
 	return media, err
 }
 
+// Placeholder returns a copy of internally stored processing placeholder,
+// returning only the fields that may be known *before* completion, and as
+// such all fields which are safe to concurrently read.
+func (p *ProcessingMedia) Placeholder() *gtsmodel.MediaAttachment {
+	media := new(gtsmodel.MediaAttachment)
+	media.ID = p.media.ID
+	media.AccountID = p.media.AccountID
+	media.StatusID = p.media.StatusID
+	media.ScheduledStatusID = p.media.ScheduledStatusID
+	media.Description = p.media.Description
+	media.Avatar = p.media.Avatar
+	media.Header = p.media.Header
+	media.RemoteURL = p.media.RemoteURL
+	media.Thumbnail.RemoteURL = p.media.Thumbnail.RemoteURL
+	media.Blurhash = p.media.Blurhash
+	media.FileMeta.Focus.X = p.media.FileMeta.Focus.X
+	media.FileMeta.Focus.Y = p.media.FileMeta.Focus.Y
+	media.CreatedAt = p.media.CreatedAt
+
+	// We specifically set placeholder URL values that allow an API user to fetch the appropriate
+	// media, even if we don't know what filetype it is yet. (since we just parse the IDs from URL path).
+	//
+	// This way the API caller can (in the worst case that it hasn't loaded yet) attempt to fetch the media,
+	// then block on ProcessingMedia{}.Load() for the processing entry it gets from a call to the dereferencer.
+	media.Thumbnail.URL = uris.URIForAttachment(media.AccountID, string(TypeAttachment), string(SizeSmall), media.ID, "loading")
+	media.URL = uris.URIForAttachment(media.AccountID, string(TypeAttachment), string(SizeOriginal), media.ID, "loading")
+	return media
+}
+
 // load is the package private form of load() that is wrapped to catch context canceled.
 func (p *ProcessingMedia) load(ctx context.Context) (
 	media *gtsmodel.MediaAttachment,
 	done bool,
 	err error,
 ) {
-	err = p.proc.Process(func() error {
+	err = p.proc.Process(func() (err error) {
 		if done = p.done; done {
 			// Already proc'd.
-			return p.err
+			err = p.err
+			return
 		}
 
 		defer func() {
@@ -100,29 +142,44 @@ func (p *ProcessingMedia) load(ctx context.Context) (
 				// (i.e. no ctx canceled).
 				ctx = context.WithoutCancel(ctx)
 
-				// On error or unknown media types, perform error cleanup.
-				if err != nil || p.media.Type == gtsmodel.FileTypeUnknown {
+				// Store values.
+				p.done = done
+				p.err = err
+
+				// If any error value is stored, including
+				// stubError (e.g. unknown type), do cleanup().
+				if p.err != nil {
 					p.cleanup(ctx)
 				}
 
+				// Check the extracted error details on media for
+				// stub type error. i.e. policy or media type issue.
+				if isStubError(p.media.Error) {
+					log.Warnf(ctx, "stubbed %s due to: %v", p.media.RemoteURL, p.err)
+					err = nil // don't return stub errors
+				}
+
 				// Update with latest details, whatever happened.
 				e := p.mgr.state.DB.UpdateAttachment(ctx, p.media)
 				if e != nil {
 					log.Errorf(ctx, "error updating media in db: %v", e)
 				}
-
-				// Store values.
-				p.done = true
-				p.err = err
 			}
 		}()
 
+		// If existing error details exists, check if supports retry.
+		if withDetails := errors.AsV2[*errWithDetails](p.err); //
+		withDetails != nil && !withDetails.details.SupportsRetry() {
+			err = p.err
+			return
+		}
+
 		// Attempt to store media and calculate
 		// full-size media attachment details.
 		//
 		// This will update p.media as it goes.
 		err = p.store(ctx)
-		return err
+		return
 	})
 
 	// Return a copy of media attachment.
@@ -135,14 +192,22 @@ func (p *ProcessingMedia) load(ctx context.Context) (
 // and updates the underlying attachment fields as necessary. It will then stream
 // bytes from p's reader directly into storage so that it can be retrieved later.
 func (p *ProcessingMedia) store(ctx context.Context) error {
+
 	// Load media from data func.
 	rc, err := p.dataFn(ctx)
 	if err != nil {
+
+		// If a network error, include these details.
+		if details := extractNetworkErrorDetails(err); //
+		details != 0 {
+			err = withDetails(err, details)
+		}
+
 		return gtserror.Newf("error executing data function: %w", err)
 	}
 
 	var (
-		// predfine temporary media
+		// predefine temporary media
 		// file path variables so we
 		// can remove them on error.
 		temppath  string
@@ -165,11 +230,8 @@ func (p *ProcessingMedia) store(ctx context.Context) error {
 	// Pass input file through ffprobe to
 	// parse further metadata information.
 	result, err := probe(ctx, temppath)
-	if err != nil && !isUnsupportedTypeErr(err) {
+	if err != nil {
 		return gtserror.Newf("ffprobe error: %w", err)
-	} else if result == nil {
-		log.Warnf(ctx, "unsupported data type by ffprobe: %v", err)
-		return nil
 	}
 
 	var ext string
@@ -189,6 +251,15 @@ func (p *ProcessingMedia) store(ctx context.Context) error {
 
 	// Set generic media type and mimetype from ffprobe format data.
 	p.media.Type, p.media.File.ContentType, ext = result.GetFileType()
+	if p.media.Type == gtsmodel.FileTypeUnknown {
+
+		// On unsupported return a stub error that doesn't
+		// get returned to the caller, but indicates details.
+		return withDetails(nil, gtsmodel.NewMediaErrorDetails(
+			gtsmodel.MediaErrorTypeCodec,
+			gtsmodel.MediaErrorTypeCodec_Unsupported,
+		))
+	}
 
 	// Add file extension to path.
 	newpath := temppath + "." + ext
@@ -206,7 +277,7 @@ func (p *ProcessingMedia) store(ctx context.Context) error {
 	case gtsmodel.FileTypeImage,
 		gtsmodel.FileTypeVideo,
 		gtsmodel.FileTypeGifv:
-		// Attempt to clean as metadata from file as possible.
+		// Attempt to clean as much metadata from file as possible.
 		if err := clearMetadata(ctx, temppath); err != nil {
 			return gtserror.Newf("error cleaning metadata: %w", err)
 		}
@@ -214,13 +285,6 @@ func (p *ProcessingMedia) store(ctx context.Context) error {
 	case gtsmodel.FileTypeAudio:
 		// NOTE: we do not clean audio file
 		// metadata, in order to keep tags.
-
-	default:
-		log.WarnKVs(ctx, kv.Fields{
-			{K: "format", V: result.format},
-			{K: "msg", V: "unsupported data type"},
-		}...)
-		return nil
 	}
 
 	if width > 0 && height > 0 {
@@ -328,11 +392,9 @@ func (p *ProcessingMedia) store(ctx context.Context) error {
 		ext,
 	)
 
-	// We can now consider this cached.
-	p.media.Cached = util.Ptr(true)
-
-	// Finally set the attachment as finished processing.
-	p.media.Processing = gtsmodel.ProcessingStatusProcessed
+	// Success! Unset previous
+	// error details for media.
+	p.media.Error = 0
 
 	return nil
 }
@@ -356,21 +418,13 @@ func (p *ProcessingMedia) cleanup(ctx context.Context) {
 		}
 	}
 
-	// Unset all processor-calculated media fields.
-	p.media.FileMeta.Original = gtsmodel.Original{}
-	p.media.FileMeta.Small = gtsmodel.Small{}
-	p.media.File.ContentType = ""
-	p.media.File.FileSize = 0
-	p.media.File.Path = ""
-	p.media.Thumbnail.FileSize = 0
-	p.media.Thumbnail.ContentType = ""
-	p.media.Thumbnail.Path = ""
-	p.media.Thumbnail.URL = ""
-	p.media.URL = ""
+	// Unset fields.
+	p.media.Stub()
 
-	// Also ensure marked as unknown and finished
-	// processing so gets inserted as placeholder URL.
-	p.media.Processing = gtsmodel.ProcessingStatusProcessed
+	// Extract any error details for db.
+	p.media.Error = toErrorDetails(p.err)
+
+	// Also ensure marked as unknown
+	// so gets inserted as placeholder URL.
 	p.media.Type = gtsmodel.FileTypeUnknown
-	p.media.Cached = util.Ptr(false)
 }
