@@ -25,11 +25,10 @@ import (
 // Gzip returns a gzip gin middleware using default compression.
 func Gzip() gin.HandlerFunc {
 	const enabled = true
-
 	if !enabled {
-		// use noop middleware if gzip is disabled
-		return func(ctx *gin.Context) {}
+		// use noop middleware
+		// if gzip is disabled
+		return nil
 	}
-
 	return gzip.Gzip(gzip.DefaultCompression)
 }
