@@ -20,10 +20,10 @@ package middleware
 import (
 	"errors"
 
+	"code.superseriousbusiness.org/gopkg/log"
 	"code.superseriousbusiness.org/gotosocial/internal/config"
 	"code.superseriousbusiness.org/gotosocial/internal/gtserror"
 	"code.superseriousbusiness.org/gotosocial/internal/headerfilter"
-	"code.superseriousbusiness.org/gotosocial/internal/log"
 	"code.superseriousbusiness.org/gotosocial/internal/state"
 	"github.com/gin-gonic/gin"
 )
@@ -39,7 +39,7 @@ var (
 func HeaderFilter(state *state.State) gin.HandlerFunc {
 	switch mode := config.GetAdvancedHeaderFilterMode(); mode {
 	case config.RequestHeaderFilterModeDisabled:
-		return func(ctx *gin.Context) {}
+		return nil
 
 	case config.RequestHeaderFilterModeAllow:
 		return headerFilterAllowMode(state)
