@@ -23,9 +23,9 @@ import (
 	"strings"
 	"time"
 
+	"code.superseriousbusiness.org/gopkg/log"
 	"code.superseriousbusiness.org/gotosocial/internal/gtscontext"
 	"code.superseriousbusiness.org/gotosocial/internal/gtserror"
-	"code.superseriousbusiness.org/gotosocial/internal/log"
 	"code.superseriousbusiness.org/gotosocial/internal/util"
 	"codeberg.org/gruf/go-bytesize"
 	"codeberg.org/gruf/go-kv/v2"
@@ -96,6 +96,13 @@ func Logger(logClientIP bool) gin.HandlerFunc {
 			}
 
 			if len(c.Errors) > 0 {
+				// Append any extra log fields
+				// attached to request errors.
+				for _, err := range c.Errors {
+					extra := gtserror.LogFields(err.Err)
+					fields = append(fields, extra...)
+				}
+
 				// Always attach any found errors.
 				fields = append(fields, kv.Field{
 					"errors", c.Errors,
@@ -119,7 +126,9 @@ func Logger(logClientIP bool) gin.HandlerFunc {
 			// Get appropriate text for this code.
 			statusText := http.StatusText(code)
 			if statusText == "" {
-				// Look for custom codes.
+
+				// Look for
+				// custom codes.
 				switch code {
 				case gtserror.StatusClientClosedRequest:
 					statusText = gtserror.StatusTextClientClosedRequest
@@ -129,7 +138,8 @@ func Logger(logClientIP bool) gin.HandlerFunc {
 			}
 
 			// Generate a nicer looking bytecount.
-			size := bytesize.Size(c.Writer.Size()) // #nosec G115 -- Just logging
+			sizeInt64 := max(0, c.Writer.Size())
+			size := bytesize.Size(sizeInt64) // #nosec G115 -- Just logging
 
 			// Write log entry with status text + body size.
 			l.Logf(lvl, "%s: wrote %s", statusText, size)
