@@ -24,12 +24,12 @@ import (
 	"io"
 	"mime/multipart"
 
+	"code.superseriousbusiness.org/gopkg/log"
 	"code.superseriousbusiness.org/gotosocial/internal/ap"
 	apimodel "code.superseriousbusiness.org/gotosocial/internal/api/model"
 	"code.superseriousbusiness.org/gotosocial/internal/config"
 	"code.superseriousbusiness.org/gotosocial/internal/gtserror"
 	"code.superseriousbusiness.org/gotosocial/internal/gtsmodel"
-	"code.superseriousbusiness.org/gotosocial/internal/log"
 	"code.superseriousbusiness.org/gotosocial/internal/media"
 	"code.superseriousbusiness.org/gotosocial/internal/messages"
 	"code.superseriousbusiness.org/gotosocial/internal/text"
@@ -77,11 +77,16 @@ func (p *Processor) Update(ctx context.Context, account *gtsmodel.Account, form
 		acctColumns = append(acctColumns, "discoverable")
 	}
 
+	if form.Indexable != nil {
+		account.Indexable = form.Indexable
+		acctColumns = append(acctColumns, "indexable")
+	}
+
 	if bot := form.Bot; bot != nil {
 		if *bot {
-			// Mark account as an Application.
-			// See: https://www.w3.org/TR/activitystreams-vocabulary/#dfn-application
-			account.ActorType = gtsmodel.AccountActorTypeApplication
+			// Mark account as a Service.
+			// See: https://www.w3.org/TR/activitystreams-vocabulary/#dfn-service
+			account.ActorType = gtsmodel.AccountActorTypeService
 		} else {
 			// Mark account as a Person.
 			// See: https://www.w3.org/TR/activitystreams-vocabulary/#dfn-person
@@ -330,6 +335,11 @@ func (p *Processor) Update(ctx context.Context, account *gtsmodel.Account, form
 		settingsColumns = append(settingsColumns, "web_layout")
 	}
 
+	if form.WebIncludeBoosts != nil {
+		account.Settings.WebIncludeBoosts = form.WebIncludeBoosts
+		settingsColumns = append(settingsColumns, "web_include_boosts")
+	}
+
 	// We've parsed + set everything, do
 	// necessary database updates now.
 
