@@ -290,7 +290,8 @@ func (p *Processor) emojiUpdateCopy(
 	// Ensure target emoji is locally cached.
 	target, err := p.federator.RecacheEmoji(ctx,
 		target,
-		false,
+		media.AdditionalEmojiInfo{},
+		false, // async
 	)
 	if err != nil {
 		err := gtserror.Newf("error recaching emoji %s: %w", target.ImageRemoteURL, err)
