@@ -21,11 +21,11 @@ import (
 	"context"
 	"errors"
 
+	"code.superseriousbusiness.org/gopkg/log"
 	apimodel "code.superseriousbusiness.org/gotosocial/internal/api/model"
 	"code.superseriousbusiness.org/gotosocial/internal/db"
 	"code.superseriousbusiness.org/gotosocial/internal/gtserror"
 	"code.superseriousbusiness.org/gotosocial/internal/gtsmodel"
-	"code.superseriousbusiness.org/gotosocial/internal/log"
 )
 
 // GetTargetAccountBy fetches the target account with db load function, given the authorized (or, nil) requester's
@@ -146,6 +146,9 @@ func (p *Processor) GetAPIAccount(
 		// Only return sensitive account model _if_ requester = target.
 		apiAcc, err = p.converter.AccountToAPIAccountSensitive(ctx, target)
 	} else {
+		// Ensure account media attachments loaded.
+		p.LoadAccountMedia(ctx, requester, target)
+
 		// Else, fall back to returning the public account model.
 		apiAcc, err = p.converter.AccountToAPIAccountPublic(ctx, target)
 	}
@@ -255,6 +258,9 @@ func (p *Processor) getVisibleAPIAccounts(
 			continue
 		}
 
+		// Ensure account media attachments loaded.
+		p.LoadAccountMedia(ctx, requester, account)
+
 		// Convert the account to a public API model representation.
 		apiAcc, err := p.converter.AccountToAPIAccountPublic(ctx, account)
 		if err != nil {
