@@ -21,12 +21,12 @@ import (
 	"context"
 	"errors"
 
+	"code.superseriousbusiness.org/gopkg/log"
 	apimodel "code.superseriousbusiness.org/gotosocial/internal/api/model"
 	"code.superseriousbusiness.org/gotosocial/internal/db"
 	"code.superseriousbusiness.org/gotosocial/internal/federation/dereferencing"
 	"code.superseriousbusiness.org/gotosocial/internal/gtserror"
 	"code.superseriousbusiness.org/gotosocial/internal/gtsmodel"
-	"code.superseriousbusiness.org/gotosocial/internal/log"
 )
 
 // GetOwnStatus fetches the given status with ID,
@@ -112,6 +112,11 @@ func (p *Processor) GetTargetStatusBy(
 			target,
 			nil,
 			window,
+
+			// Pass callback to insert
+			// other statuses in thread
+			// into timelines (as appropriate).
+			p.surfacer.TimelineAndNotifyStatus,
 		)
 		if err != nil {
 			log.Errorf(ctx, "error refreshing target %s: %v", target.URI, err)
@@ -209,6 +214,10 @@ func (p *Processor) GetAPIStatus(
 	apiStatus *apimodel.Status,
 	errWithCode gtserror.WithCode,
 ) {
+	// Ensure status media is cached locally.
+	p.LoadStatusMedia(ctx, requester, target)
+
+	// Convert the target status to frontend API model.
 	apiStatus, err := p.converter.StatusToAPIStatus(ctx,
 		target,
 		requester,
@@ -217,6 +226,7 @@ func (p *Processor) GetAPIStatus(
 		err := gtserror.Newf("error converting: %w", err)
 		return nil, gtserror.NewErrorInternalError(err)
 	}
+
 	return apiStatus, nil
 }
 
@@ -284,7 +294,10 @@ func (p *Processor) GetVisibleAPIStatuses(
 			continue
 		}
 
-		// Convert to API status, taking mute / filter into account.
+		// Ensure status media is cached locally.
+		p.LoadStatusMedia(ctx, requester, status)
+
+		// Not muted or "hide" filtered. Convert to API status.
 		apiStatus, err := p.converter.StatusToAPIStatus(ctx,
 			status,
 			requester,
@@ -303,24 +316,3 @@ func (p *Processor) GetVisibleAPIStatuses(
 
 	return apiStatuses
 }
-
-// InvalidateTimelinedStatus is a shortcut function for invalidating the cached
-// representation one status in the home timeline and all list timelines of the
-// given accountID. It should only be called in cases where a status update
-// does *not* need to be passed into the processor via the worker queue, since
-// such invalidation will, in that case, be handled by the processor instead.
-func (p *Processor) InvalidateTimelinedStatus(ctx context.Context, accountID string, statusID string) error {
-	// Get lists first + bail if this fails.
-	lists, err := p.state.DB.GetListsByAccountID(ctx, accountID)
-	if err != nil {
-		return gtserror.Newf("db error getting lists for account %s: %w", accountID, err)
-	}
-
-	// Unprepare item from home + list timelines.
-	p.state.Caches.Timelines.Home.MustGet(accountID).UnprepareByStatusIDs(statusID)
-	for _, list := range lists {
-		p.state.Caches.Timelines.List.MustGet(list.ID).UnprepareByStatusIDs(statusID)
-	}
-
-	return nil
-}
