@@ -18,17 +18,23 @@
 package v1
 
 import (
-	"github.com/superseriousbusiness/gotosocial/internal/state"
-	"github.com/superseriousbusiness/gotosocial/internal/typeutils"
+	"code.superseriousbusiness.org/gotosocial/internal/processing/filters/common"
+	"code.superseriousbusiness.org/gotosocial/internal/state"
+	"code.superseriousbusiness.org/gotosocial/internal/typeutils"
 )
 
 type Processor struct {
+	// embedded common logic
+	c *common.Processor
+
 	state     *state.State
 	converter *typeutils.Converter
 }
 
-func New(state *state.State, converter *typeutils.Converter) Processor {
+func New(state *state.State, converter *typeutils.Converter, common *common.Processor) Processor {
 	return Processor{
+		c: common,
+
 		state:     state,
 		converter: converter,
 	}
