@@ -21,15 +21,17 @@ import (
 	"context"
 	"time"
 
+	"code.superseriousbusiness.org/gopkg/log"
 	"code.superseriousbusiness.org/gotosocial/internal/ap"
 	"code.superseriousbusiness.org/gotosocial/internal/gtscontext"
 	"code.superseriousbusiness.org/gotosocial/internal/gtserror"
 	"code.superseriousbusiness.org/gotosocial/internal/gtsmodel"
-	"code.superseriousbusiness.org/gotosocial/internal/log"
 	"code.superseriousbusiness.org/gotosocial/internal/messages"
 )
 
 func (p *Processor) ScheduleAll(ctx context.Context) error {
+	log.Info(ctx, "scheduling poll expiries...")
+
 	// Fetch all open polls from the database (barebones models are enough).
 	polls, err := p.state.DB.GetOpenPolls(gtscontext.SetBarebones(ctx))
 	if err != nil {
