@@ -54,6 +54,7 @@ import (
 	"code.superseriousbusiness.org/gotosocial/internal/processing/workers"
 	"code.superseriousbusiness.org/gotosocial/internal/state"
 	"code.superseriousbusiness.org/gotosocial/internal/subscriptions"
+	"code.superseriousbusiness.org/gotosocial/internal/surfacing"
 	"code.superseriousbusiness.org/gotosocial/internal/text"
 	"code.superseriousbusiness.org/gotosocial/internal/typeutils"
 	"code.superseriousbusiness.org/gotosocial/internal/webpush"
@@ -220,14 +221,13 @@ func NewProcessor(
 		parseMentionFunc: parseMentionFunc,
 	}
 
-	// Instantiate sub processors.
-	//
-	// Start with sub processors that will
-	// be required by the workers processor.
-	common := common.New(state, mediaManager, converter, federator, visFilter, muteFilter, statusFilter)
+	// Instantiate sub processors used by other sub-processors.
+	processor.stream = stream.New(state, oauthServer)
+	processor.conversations = conversations.New(state, converter, visFilter, muteFilter, statusFilter)
+	surfacer := surfacing.New(state, converter, federator, &processor.stream, visFilter, muteFilter, statusFilter, emailSender, webPushSender, &processor.conversations)
+	common := common.New(state, mediaManager, converter, federator, visFilter, muteFilter, statusFilter, surfacer)
 	processor.account = account.New(&common, state, converter, mediaManager, federator, visFilter, statusFilter, parseMentionFunc)
 	processor.media = media.New(&common, state, converter, federator, mediaManager, federator.TransportController())
-	processor.stream = stream.New(state, oauthServer)
 	filterCommon := filterCommon.New(state, &processor.stream)
 
 	// Instantiate the rest of the sub
@@ -235,7 +235,6 @@ func NewProcessor(
 	processor.account = account.New(&common, state, converter, mediaManager, federator, visFilter, statusFilter, parseMentionFunc)
 	processor.admin = admin.New(&common, state, cleaner, subscriptions, federator, converter, mediaManager, federator.TransportController(), emailSender)
 	processor.application = application.New(state, converter)
-	processor.conversations = conversations.New(state, converter, visFilter, muteFilter, statusFilter)
 	processor.fedi = fedi.New(state, &common, converter, federator, visFilter)
 	processor.filtersv1 = filtersv1.New(state, converter, filterCommon)
 	processor.filtersv2 = filtersv2.New(state, converter, filterCommon)
@@ -246,9 +245,9 @@ func NewProcessor(
 	processor.push = push.New(state, converter)
 	processor.report = report.New(state, converter)
 	processor.tags = tags.New(state, converter)
-	processor.timeline = timeline.New(state, converter, visFilter, muteFilter, statusFilter)
-	processor.search = search.New(state, federator, converter, visFilter)
-	processor.status = status.New(state, &common, &processor.polls, &processor.interactionRequests, federator, converter, visFilter, intFilter, parseMentionFunc)
+	processor.timeline = timeline.New(state, &common, converter, visFilter, muteFilter, statusFilter)
+	processor.search = search.New(state, federator, converter, visFilter, surfacer)
+	processor.status = status.New(state, &common, &processor.polls, &processor.interactionRequests, federator, converter, visFilter, muteFilter, statusFilter, intFilter, parseMentionFunc)
 	processor.user = user.New(state, converter, oauthServer, emailSender)
 
 	// The advanced migrations processor sequences advanced migrations from all other processors.
@@ -259,18 +258,11 @@ func NewProcessor(
 	// and pass subset of sub processors it needs.
 	processor.workers = workers.New(
 		state,
-		&common,
 		federator,
 		converter,
-		visFilter,
-		muteFilter,
-		statusFilter,
-		emailSender,
-		webPushSender,
+		surfacer,
 		&processor.account,
 		&processor.media,
-		&processor.stream,
-		&processor.conversations,
 	)
 
 	return processor
