@@ -57,11 +57,6 @@ func (p *Processor) BookmarkCreate(ctx context.Context, requestingAccount *gtsmo
 		return nil, gtserror.NewErrorInternalError(err)
 	}
 
-	if err := p.c.InvalidateTimelinedStatus(ctx, requestingAccount.ID, targetStatusID); err != nil {
-		err = gtserror.Newf("error invalidating status from timelines: %w", err)
-		return nil, gtserror.NewErrorInternalError(err)
-	}
-
 	return p.c.GetAPIStatus(ctx, requestingAccount, targetStatus)
 }
 
@@ -83,11 +78,6 @@ func (p *Processor) BookmarkRemove(ctx context.Context, requestingAccount *gtsmo
 		return nil, gtserror.NewErrorInternalError(err)
 	}
 
-	if err := p.c.InvalidateTimelinedStatus(ctx, requestingAccount.ID, targetStatusID); err != nil {
-		err = gtserror.Newf("error invalidating status from timelines: %w", err)
-		return nil, gtserror.NewErrorInternalError(err)
-	}
-
 	return p.c.GetAPIStatus(ctx, requestingAccount, targetStatus)
 }
 
