@@ -24,12 +24,12 @@ import (
 	"net/http"
 	"net/url"
 
+	"code.superseriousbusiness.org/gopkg/log"
 	apimodel "code.superseriousbusiness.org/gotosocial/internal/api/model"
 	apiutil "code.superseriousbusiness.org/gotosocial/internal/api/util"
 	"code.superseriousbusiness.org/gotosocial/internal/db"
 	"code.superseriousbusiness.org/gotosocial/internal/gtserror"
 	"code.superseriousbusiness.org/gotosocial/internal/gtsmodel"
-	"code.superseriousbusiness.org/gotosocial/internal/log"
 	"code.superseriousbusiness.org/gotosocial/internal/paging"
 	"code.superseriousbusiness.org/gotosocial/internal/util"
 )
@@ -80,8 +80,8 @@ func (p *Processor) NotificationsGet(
 
 		// Check whether notification origin account is muted.
 		muted, err := p.muteFilter.AccountNotificationsMuted(ctx,
-			requester,
-			n.OriginAccount,
+			requester.ID,
+			n.OriginAccountID,
 		)
 		if err != nil {
 			log.Errorf(ctx, "error checking account mute: %v", err)
