@@ -20,19 +20,18 @@ package workers
 import (
 	"context"
 	"errors"
-	"time"
 
+	"code.superseriousbusiness.org/gopkg/log"
 	"code.superseriousbusiness.org/gotosocial/internal/ap"
 	"code.superseriousbusiness.org/gotosocial/internal/db"
 	"code.superseriousbusiness.org/gotosocial/internal/gtscontext"
 	"code.superseriousbusiness.org/gotosocial/internal/gtserror"
 	"code.superseriousbusiness.org/gotosocial/internal/gtsmodel"
 	"code.superseriousbusiness.org/gotosocial/internal/id"
-	"code.superseriousbusiness.org/gotosocial/internal/log"
 	"code.superseriousbusiness.org/gotosocial/internal/messages"
 	"code.superseriousbusiness.org/gotosocial/internal/processing/account"
-	"code.superseriousbusiness.org/gotosocial/internal/processing/common"
 	"code.superseriousbusiness.org/gotosocial/internal/state"
+	"code.superseriousbusiness.org/gotosocial/internal/surfacing"
 	"code.superseriousbusiness.org/gotosocial/internal/typeutils"
 	"code.superseriousbusiness.org/gotosocial/internal/uris"
 	"code.superseriousbusiness.org/gotosocial/internal/util"
@@ -43,13 +42,11 @@ import (
 // specifically for messages originating
 // from the client/REST API.
 type clientAPI struct {
-	state     *state.State
-	converter *typeutils.Converter
-	surface   *Surface
-	federate  *federate
-	account   *account.Processor
-	common    *common.Processor
-	utils     *utils
+	state    *state.State
+	surfacer *surfacing.Surfacer
+	federate *federate
+	account  *account.Processor
+	utils    *utils
 }
 
 func (p *Processor) ProcessFromClientAPI(ctx context.Context, cMsg *messages.FromClientAPI) error {
@@ -61,7 +58,7 @@ func (p *Processor) ProcessFromClientAPI(ctx context.Context, cMsg *messages.Fro
 
 	// Include GTSModel in logs if appropriate.
 	if cMsg.GTSModel != nil &&
-		log.Level() >= log.DEBUG {
+		log.Level() <= log.DEBUG {
 		fields = append(fields, kv.Field{
 			"model", cMsg.GTSModel,
 		})
@@ -91,6 +88,10 @@ func (p *Processor) ProcessFromClientAPI(ctx context.Context, cMsg *messages.Fro
 		case ap.ActivityQuestion:
 			return p.clientAPI.CreatePollVote(ctx, cMsg)
 
+		// CREATE REPLY REQUEST
+		case ap.ActivityReplyRequest:
+			return p.clientAPI.CreateReplyRequest(ctx, cMsg)
+
 		// CREATE FOLLOW (request)
 		case ap.ActivityFollow:
 			return p.clientAPI.CreateFollowReq(ctx, cMsg)
@@ -99,10 +100,18 @@ func (p *Processor) ProcessFromClientAPI(ctx context.Context, cMsg *messages.Fro
 		case ap.ActivityLike:
 			return p.clientAPI.CreateLike(ctx, cMsg)
 
+		// CREATE LIKE REQUEST
+		case ap.ActivityLikeRequest:
+			return p.clientAPI.CreateLikeRequest(ctx, cMsg)
+
 		// CREATE ANNOUNCE/BOOST
 		case ap.ActivityAnnounce:
 			return p.clientAPI.CreateAnnounce(ctx, cMsg)
 
+		// CREATE ANNOUNCE REQUEST
+		case ap.ActivityAnnounceRequest:
+			return p.clientAPI.CreateAnnounceRequest(ctx, cMsg)
+
 		// CREATE BLOCK
 		case ap.ActivityBlock:
 			return p.clientAPI.CreateBlock(ctx, cMsg)
@@ -242,17 +251,17 @@ func (p *clientAPI) CreateUser(ctx context.Context, cMsg *messages.FromClientAPI
 	}
 
 	// Notify mods of the new signup.
-	if err := p.surface.notifySignup(ctx, newUser); err != nil {
+	if err := p.surfacer.NotifySignup(ctx, newUser); err != nil {
 		log.Errorf(ctx, "error notifying mods of new sign-up: %v", err)
 	}
 
 	// Send "new sign up" email to mods.
-	if err := p.surface.emailAdminNewSignup(ctx, newUser); err != nil {
+	if err := p.surfacer.EmailAdminNewSignup(ctx, newUser); err != nil {
 		log.Errorf(ctx, "error emailing new signup: %v", err)
 	}
 
 	// Send "please confirm your address" email to the new user.
-	if err := p.surface.emailUserPleaseConfirm(ctx, newUser, true); err != nil {
+	if err := p.surfacer.EmailUserPleaseConfirm(ctx, newUser, true); err != nil {
 		log.Errorf(ctx, "error emailing confirm: %v", err)
 	}
 
@@ -260,116 +269,115 @@ func (p *clientAPI) CreateUser(ctx context.Context, cMsg *messages.FromClientAPI
 }
 
 func (p *clientAPI) CreateStatus(ctx context.Context, cMsg *messages.FromClientAPI) error {
-	var status *gtsmodel.Status
-	var backfill bool
-
-	// Check passed client message model type.
-	switch model := cMsg.GTSModel.(type) {
-	case *gtsmodel.Status:
-		status = model
-	case *gtsmodel.BackfillStatus:
-		status = model.Status
-		backfill = true
-	default:
-		return gtserror.Newf("%T not parseable as *gtsmodel.Status or *gtsmodel.BackfillStatus", cMsg.GTSModel)
+	status, ok := cMsg.GTSModel.(*gtsmodel.Status)
+	if !ok {
+		return gtserror.Newf("%T not parseable as *gtsmodel.Status", cMsg.GTSModel)
 	}
 
-	// If pending approval is true then status must
-	// reply to a status (either one of ours or a
-	// remote) that requires approval for the reply.
-	pendingApproval := util.PtrOrZero(status.PendingApproval)
+	if err := p.surfacer.TimelineAndNotifyStatus(ctx, status); err != nil {
+		log.Errorf(ctx, "error timelining and notifying status: %v", err)
+	}
 
-	switch {
-	case pendingApproval && !status.PreApproved:
-		// If approval is required and status isn't
-		// preapproved, then send out the Create to
-		// only the replied-to account (if it's remote),
-		// and/or notify the account that's being
-		// interacted with (if it's local): they can
-		// approve or deny the interaction later.
-		if err := p.utils.impoliteReplyRequest(ctx, status); err != nil {
-			return gtserror.Newf("error pending reply: %w", err)
-		}
+	if err := p.federate.CreateStatus(ctx, status); err != nil {
+		log.Errorf(ctx, "error federating status: %v", err)
+	}
 
-		// Send Create to *remote* account inbox ONLY.
-		if err := p.federate.CreateStatus(ctx, status); err != nil {
-			return gtserror.Newf("error federating pending reply: %w", err)
-		}
+	return nil
+}
 
-		// Return early.
-		return nil
+func (p *clientAPI) CreateReplyRequest(ctx context.Context, cMsg *messages.FromClientAPI) error {
+	reply, ok := cMsg.GTSModel.(*gtsmodel.Status)
+	if !ok {
+		return gtserror.Newf("%T not parseable as *gtsmodel.Status", cMsg.GTSModel)
+	}
 
-	case pendingApproval && status.PreApproved:
-		// If approval is required and status is
-		// preapproved, that means this is a reply
-		// to one of our statuses with permission
-		// that matched on a following/followers
-		// collection. Do the Accept immediately and
-		// then process everything else as normal,
-		// sending out the Create with the approval
-		// URI attached.
+	// Create a polite reply request.
+	intReqID := id.NewULIDFromTime(reply.CreatedAt)
+	intReq := &gtsmodel.InteractionRequest{
+		ID:                    intReqID,
+		TargetStatusID:        reply.InReplyToID,
+		TargetStatus:          reply.InReplyTo,
+		TargetAccountID:       reply.InReplyToAccountID,
+		TargetAccount:         reply.InReplyToAccount,
+		InteractingAccountID:  reply.AccountID,
+		InteractingAccount:    reply.Account,
+		InteractionRequestURI: uris.GenerateURIForReplyRequest(reply.Account.Username, intReqID),
+		InteractionURI:        reply.URI,
+		InteractionType:       gtsmodel.InteractionReply,
+		Polite:                util.Ptr(true),
+		Reply:                 reply,
+	}
 
-		// Store an already-accepted interaction request.
-		requestID := id.NewULID()
-		approval := &gtsmodel.InteractionRequest{
-			ID:                    requestID,
-			TargetStatusID:        status.InReplyToID,
-			TargetAccountID:       status.InReplyToAccountID,
-			TargetAccount:         status.InReplyToAccount,
-			InteractingAccountID:  status.AccountID,
-			InteractingAccount:    status.Account,
-			InteractionRequestURI: gtsmodel.ForwardCompatibleInteractionRequestURI(status.URI, gtsmodel.ReplyRequestSuffix),
-			InteractionURI:        status.URI,
-			InteractionType:       gtsmodel.InteractionReply,
-			Polite:                util.Ptr(false), // TODO: Change this in v0.21.0 when we only send out polite requests.
-			Reply:                 status,
-			ResponseURI:           uris.GenerateURIForAccept(status.InReplyToAccount.Username, requestID),
-			AuthorizationURI:      uris.GenerateURIForAuthorization(status.InReplyToAccount.Username, requestID),
-			AcceptedAt:            time.Now(),
-		}
-		if err := p.state.DB.PutInteractionRequest(ctx, approval); err != nil {
-			return gtserror.Newf("db error putting pre-approved interaction request: %w", err)
-		}
-
-		// Mark the status as now approved.
-		status.PendingApproval = util.Ptr(false)
-		status.PreApproved = false
-		status.ApprovedByURI = approval.AuthorizationURI
-		if err := p.state.DB.UpdateStatus(
-			ctx,
-			status,
-			"pending_approval",
-			"approved_by_uri",
+	if !reply.PreApproved {
+		// If the reply is not pre-approved, just
+		// store the interaction request, notify
+		// (local) target or federate request.
+		if err := p.utils.storeInteractionRequest(
+			ctx, intReq,
 		); err != nil {
-			return gtserror.Newf("db error updating status: %w", err)
+			return gtserror.Newf("error storing interaction request: %w", err)
 		}
 
-		if err := p.federate.AcceptInteraction(ctx, approval); err != nil {
-			return gtserror.Newf("error federating pre-approval of reply: %w", err)
+		// Notify target account (if local) of pending reply.
+		if err := p.surfacer.NotifyPendingReply(ctx, intReq.Reply); err != nil {
+			return gtserror.Newf("error notifying pending reply: %w", err)
 		}
 
-		// Don't return, just continue as normal.
+		// Send interaction request to target account (if remote).
+		if err := p.federate.InteractionRequest(ctx, intReq); err != nil {
+			return gtserror.Newf("error federating interaction request: %w", err)
+		}
+
+		return nil
 	}
 
-	// We specifically do not timeline
-	// or notify for backfilled statuses,
-	// as these are more for archival than
-	// newly posted content for user feeds.
-	if !backfill {
+	// If the reply is pre-approved, then it must
+	// target a status on our instance, and the
+	// replier gets automatic approval due to being
+	// in the author's followers/following collection.
+	//
+	// Mark the interaction request as accepted, store it,
+	// mark the interaction as approved, and then continue
+	// with side effects as normal.
 
-		if err := p.surface.timelineAndNotifyStatus(ctx, status); err != nil {
-			log.Errorf(ctx, "error timelining and notifying status: %v", err)
-		}
+	// Update intReq fields to
+	// mark it as accepted.
+	intReq.MarkAccepted()
 
-		if err := p.federate.CreateStatus(ctx, status); err != nil {
-			log.Errorf(ctx, "error federating status: %v", err)
-		}
+	// Put it in the DB.
+	if err := p.utils.storeInteractionRequest(
+		ctx, intReq,
+	); err != nil {
+		return gtserror.Newf("error storing interaction request: %w", err)
 	}
 
-	if status.InReplyToID != "" {
-		// Interaction counts changed on the replied status;
-		// uncache the prepared version from all timelines.
-		p.surface.invalidateStatusFromTimelines(status.InReplyToID)
+	// Mark the status as now approved, referring to
+	// the accepted interaction request we just stored.
+	reply.PendingApproval = util.Ptr(false)
+	reply.PreApproved = false
+	reply.ApprovedByURI = intReq.AuthorizationURI
+	if err := p.state.DB.UpdateStatus(
+		ctx,
+		reply,
+		"pending_approval",
+		"approved_by_uri",
+	); err != nil {
+		return gtserror.Newf("db error updating status: %w", err)
+	}
+
+	// Send out the approval as Accept.
+	if err := p.federate.AcceptInteraction(ctx, intReq); err != nil {
+		return gtserror.Newf("error federating pre-approval of reply: %w", err)
+	}
+
+	// Timeline + notify the reply.
+	if err := p.surfacer.TimelineAndNotifyStatus(ctx, reply); err != nil {
+		log.Errorf(ctx, "error timelining and notifying status: %v", err)
+	}
+
+	// Send out the approved reply.
+	if err := p.federate.CreateStatus(ctx, reply); err != nil {
+		log.Errorf(ctx, "error federating status: %v", err)
 	}
 
 	return nil
@@ -410,9 +418,6 @@ func (p *clientAPI) CreatePollVote(ctx context.Context, cMsg *messages.FromClien
 		}
 	}
 
-	// Interaction counts changed on the source status, uncache from timelines.
-	p.surface.invalidateStatusFromTimelines(vote.Poll.StatusID)
-
 	return nil
 }
 
@@ -446,12 +451,12 @@ func (p *clientAPI) CreateFollowReq(ctx context.Context, cMsg *messages.FromClie
 		})
 	}
 
-	if err := p.surface.notifyFollowRequest(ctx, followRequest); err != nil {
+	if err := p.surfacer.NotifyFollowRequest(ctx, followRequest); err != nil {
 		log.Errorf(ctx, "error notifying follow request: %v", err)
 	}
 
 	// Convert the follow request to follow model (requests are sent as follows).
-	follow := p.converter.FollowRequestToFollow(ctx, followRequest)
+	follow := typeutils.FollowRequestToFollow(followRequest)
 
 	if err := p.federate.Follow(
 		ctx,
@@ -474,84 +479,7 @@ func (p *clientAPI) CreateLike(ctx context.Context, cMsg *messages.FromClientAPI
 		return gtserror.Newf("error populating status fave: %w", err)
 	}
 
-	// If pending approval is true then fave must
-	// target a status (either one of ours or a
-	// remote) that requires approval for the fave.
-	pendingApproval := util.PtrOrZero(fave.PendingApproval)
-
-	switch {
-	case pendingApproval && !fave.PreApproved:
-		// If approval is required and fave isn't
-		// preapproved, then send out the Like to
-		// only the faved account (if it's remote),
-		// and/or notify the account that's being
-		// interacted with (if it's local): they can
-		// approve or deny the interaction later.
-		if err := p.utils.impoliteFaveRequest(ctx, fave); err != nil {
-			return gtserror.Newf("error pending fave: %w", err)
-		}
-
-		// Send Like to *remote* account inbox ONLY.
-		if err := p.federate.Like(ctx, fave); err != nil {
-			return gtserror.Newf("error federating pending Like: %v", err)
-		}
-
-		// Return early.
-		return nil
-
-	case pendingApproval && fave.PreApproved:
-		// If approval is required and fave is
-		// preapproved, that means this is a fave
-		// of one of our statuses with permission
-		// that matched on a following/followers
-		// collection. Do the Accept immediately and
-		// then process everything else as normal,
-		// sending out the Like with the approval
-		// URI attached.
-
-		// Store an already-accepted interaction request.
-		requestID := id.NewULID()
-		approval := &gtsmodel.InteractionRequest{
-			ID:                    requestID,
-			TargetStatusID:        fave.StatusID,
-			TargetAccountID:       fave.TargetAccountID,
-			TargetAccount:         fave.TargetAccount,
-			InteractingAccountID:  fave.AccountID,
-			InteractingAccount:    fave.Account,
-			InteractionRequestURI: gtsmodel.ForwardCompatibleInteractionRequestURI(fave.URI, gtsmodel.LikeRequestSuffix),
-			InteractionURI:        fave.URI,
-			InteractionType:       gtsmodel.InteractionLike,
-			Polite:                util.Ptr(false), // TODO: Change this in v0.21.0 when we only send out polite requests.
-			Like:                  fave,
-			ResponseURI:           uris.GenerateURIForAccept(fave.TargetAccount.Username, requestID),
-			AuthorizationURI:      uris.GenerateURIForAuthorization(fave.TargetAccount.Username, requestID),
-			AcceptedAt:            time.Now(),
-		}
-		if err := p.state.DB.PutInteractionRequest(ctx, approval); err != nil {
-			return gtserror.Newf("db error putting pre-approved interaction request: %w", err)
-		}
-
-		// Mark the fave itself as now approved.
-		fave.PendingApproval = util.Ptr(false)
-		fave.PreApproved = false
-		fave.ApprovedByURI = approval.AuthorizationURI
-		if err := p.state.DB.UpdateStatusFave(
-			ctx,
-			fave,
-			"pending_approval",
-			"approved_by_uri",
-		); err != nil {
-			return gtserror.Newf("db error updating status fave: %w", err)
-		}
-
-		if err := p.federate.AcceptInteraction(ctx, approval); err != nil {
-			return gtserror.Newf("error federating pre-approval of fave: %w", err)
-		}
-
-		// Don't return, just continue as normal.
-	}
-
-	if err := p.surface.notifyFave(ctx, fave); err != nil {
+	if err := p.surfacer.NotifyFave(ctx, fave); err != nil {
 		log.Errorf(ctx, "error notifying fave: %v", err)
 	}
 
@@ -559,10 +487,103 @@ func (p *clientAPI) CreateLike(ctx context.Context, cMsg *messages.FromClientAPI
 		log.Errorf(ctx, "error federating like: %v", err)
 	}
 
-	// Interaction counts changed on the faved status;
-	// uncache the prepared version from all timelines.
-	p.surface.invalidateStatusFromTimelines(fave.StatusID)
+	return nil
+}
 
+func (p *clientAPI) CreateLikeRequest(ctx context.Context, cMsg *messages.FromClientAPI) error {
+	fave, ok := cMsg.GTSModel.(*gtsmodel.StatusFave)
+	if !ok {
+		return gtserror.Newf("%T not parseable as *gtsmodel.StatusFave", cMsg.GTSModel)
+	}
+
+	// Create a polite like request.
+	intReqID := id.NewULIDFromTime(fave.CreatedAt)
+	intReq := &gtsmodel.InteractionRequest{
+		ID:                    intReqID,
+		TargetStatusID:        fave.StatusID,
+		TargetStatus:          fave.Status,
+		TargetAccountID:       fave.TargetAccountID,
+		TargetAccount:         fave.TargetAccount,
+		InteractingAccountID:  fave.AccountID,
+		InteractingAccount:    fave.Account,
+		InteractionRequestURI: uris.GenerateURIForLikeRequest(fave.Account.Username, intReqID),
+		InteractionURI:        fave.URI,
+		InteractionType:       gtsmodel.InteractionLike,
+		Polite:                util.Ptr(true),
+		Like:                  fave,
+	}
+
+	if !fave.PreApproved {
+		// If the fave is not pre-approved, just
+		// store the interaction request, notify
+		// (local) target or federate request.
+		if err := p.utils.storeInteractionRequest(
+			ctx, intReq,
+		); err != nil {
+			return gtserror.Newf("error storing interaction request: %w", err)
+		}
+
+		// Notify target account (if local) of pending fave.
+		if err := p.surfacer.NotifyPendingFave(ctx, intReq.Like); err != nil {
+			return gtserror.Newf("error notifying pending fave: %w", err)
+		}
+
+		// Send interaction request to target account (if remote).
+		if err := p.federate.InteractionRequest(ctx, intReq); err != nil {
+			return gtserror.Newf("error federating interaction request: %w", err)
+		}
+
+		return nil
+	}
+
+	// If the fave is pre-approved, then it must
+	// target a status on our instance, and the
+	// faver gets automatic approval due to being
+	// in the author's followers/following collection.
+	//
+	// Mark the interaction request as accepted, store it,
+	// mark the interaction as approved, and then continue
+	// with side effects as normal.
+
+	// Update intReq fields to
+	// mark it as accepted.
+	intReq.MarkAccepted()
+
+	// Put it in the DB.
+	if err := p.utils.storeInteractionRequest(
+		ctx, intReq,
+	); err != nil {
+		return gtserror.Newf("error storing interaction request: %w", err)
+	}
+
+	// Mark the fave as now approved, referring to
+	// the accepted interaction request we just stored.
+	fave.PendingApproval = util.Ptr(false)
+	fave.PreApproved = false
+	fave.ApprovedByURI = intReq.AuthorizationURI
+	if err := p.state.DB.UpdateStatusFave(
+		ctx,
+		fave,
+		"pending_approval",
+		"approved_by_uri",
+	); err != nil {
+		return gtserror.Newf("db error updating status fave: %w", err)
+	}
+
+	// Send out the approval as an Accept.
+	if err := p.federate.AcceptInteraction(ctx, intReq); err != nil {
+		return gtserror.Newf("error federating pre-approval of fave: %w", err)
+	}
+
+	// Notify the status author about the fave.
+	if err := p.surfacer.NotifyFave(ctx, fave); err != nil {
+		log.Errorf(ctx, "error notifying fave: %v", err)
+	}
+
+	// We don't (yet) federate Likes out
+	// to anyone but the target of the like,
+	// so there's no need to send it anywhere.
+	// Just return.
 	return nil
 }
 
@@ -572,100 +593,123 @@ func (p *clientAPI) CreateAnnounce(ctx context.Context, cMsg *messages.FromClien
 		return gtserror.Newf("%T not parseable as *gtsmodel.Status", cMsg.GTSModel)
 	}
 
-	// If pending approval is true then status must
-	// boost a status (either one of ours or a
-	// remote) that requires approval for the boost.
-	pendingApproval := util.PtrOrZero(boost.PendingApproval)
-
-	switch {
-	case pendingApproval && !boost.PreApproved:
-		// If approval is required and boost isn't
-		// preapproved, then send out the Announce to
-		// only the boosted account (if it's remote),
-		// and/or notify the account that's being
-		// interacted with (if it's local): they can
-		// approve or deny the interaction later.
-		if err := p.utils.impoliteAnnounceRequest(ctx, boost); err != nil {
-			return gtserror.Newf("error pending boost: %w", err)
-		}
-
-		// Send Announce to *remote* account inbox ONLY.
-		if err := p.federate.Announce(ctx, boost); err != nil {
-			return gtserror.Newf("error federating pending Announce: %v", err)
-		}
-
-		// Return early.
-		return nil
-
-	case pendingApproval && boost.PreApproved:
-		// If approval is required and boost is
-		// preapproved, that means this is a boost
-		// of one of our statuses with permission
-		// that matched on a following/followers
-		// collection. Do the Accept immediately and
-		// then process everything else as normal,
-		// sending out the Create with the approval
-		// URI attached.
-
-		// Store an already-accepted interaction request.
-		requestID := id.NewULID()
-		approval := &gtsmodel.InteractionRequest{
-			ID:                    requestID,
-			TargetStatusID:        boost.BoostOfID,
-			TargetAccountID:       boost.BoostOfAccountID,
-			TargetAccount:         boost.BoostOfAccount,
-			InteractingAccountID:  boost.AccountID,
-			InteractingAccount:    boost.Account,
-			InteractionRequestURI: gtsmodel.ForwardCompatibleInteractionRequestURI(boost.URI, gtsmodel.AnnounceRequestSuffix),
-			InteractionURI:        boost.URI,
-			InteractionType:       gtsmodel.InteractionAnnounce,
-			Polite:                util.Ptr(false), // TODO: Change this in v0.21.0 when we only send out polite requests.
-			Announce:              boost,
-			ResponseURI:           uris.GenerateURIForAccept(boost.BoostOfAccount.Username, requestID),
-			AuthorizationURI:      uris.GenerateURIForAuthorization(boost.BoostOfAccount.Username, requestID),
-			AcceptedAt:            time.Now(),
-		}
-		if err := p.state.DB.PutInteractionRequest(ctx, approval); err != nil {
-			return gtserror.Newf("db error putting pre-approved interaction request: %w", err)
-		}
-
-		// Mark the boost itself as now approved.
-		boost.PendingApproval = util.Ptr(false)
-		boost.PreApproved = false
-		boost.ApprovedByURI = approval.AuthorizationURI
-		if err := p.state.DB.UpdateStatus(
-			ctx,
-			boost,
-			"pending_approval",
-			"approved_by_uri",
-		); err != nil {
-			return gtserror.Newf("db error updating status: %w", err)
-		}
-
-		if err := p.federate.AcceptInteraction(ctx, approval); err != nil {
-			return gtserror.Newf("error federating pre-approval of boost: %w", err)
-		}
-
-		// Don't return, just continue as normal.
-	}
-
 	// Timeline and notify the boost wrapper status.
-	if err := p.surface.timelineAndNotifyStatus(ctx, boost); err != nil {
+	if err := p.surfacer.TimelineAndNotifyStatus(ctx, boost); err != nil {
 		log.Errorf(ctx, "error timelining and notifying status: %v", err)
 	}
 
-	// Notify the boost target account.
-	if err := p.surface.notifyAnnounce(ctx, boost); err != nil {
+	// Notify the boost target account (if local).
+	if err := p.surfacer.NotifyAnnounce(ctx, boost); err != nil {
 		log.Errorf(ctx, "error notifying boost: %v", err)
 	}
 
+	// Send out the Announce.
 	if err := p.federate.Announce(ctx, boost); err != nil {
 		log.Errorf(ctx, "error federating announce: %v", err)
 	}
 
-	// Interaction counts changed on the boosted status;
-	// uncache the prepared version from all timelines.
-	p.surface.invalidateStatusFromTimelines(boost.BoostOfID)
+	return nil
+}
+
+func (p *clientAPI) CreateAnnounceRequest(ctx context.Context, cMsg *messages.FromClientAPI) error {
+	boost, ok := cMsg.GTSModel.(*gtsmodel.Status)
+	if !ok {
+		return gtserror.Newf("%T not parseable as *gtsmodel.Status", cMsg.GTSModel)
+	}
+
+	// Create a polite reply request.
+	intReqID := id.NewULIDFromTime(boost.CreatedAt)
+	intReq := &gtsmodel.InteractionRequest{
+		ID:                    intReqID,
+		TargetStatusID:        boost.BoostOfID,
+		TargetStatus:          boost.BoostOf,
+		TargetAccountID:       boost.BoostOfAccountID,
+		TargetAccount:         boost.BoostOfAccount,
+		InteractingAccountID:  boost.AccountID,
+		InteractingAccount:    boost.Account,
+		InteractionRequestURI: uris.GenerateURIForAnnounceRequest(boost.Account.Username, intReqID),
+		InteractionURI:        boost.URI,
+		InteractionType:       gtsmodel.InteractionAnnounce,
+		Polite:                util.Ptr(true),
+		Announce:              boost,
+	}
+
+	if !boost.PreApproved {
+		// If the boost is not pre-approved, just
+		// store the interaction request, notify
+		// (local) target or federate request.
+		if err := p.utils.storeInteractionRequest(
+			ctx, intReq,
+		); err != nil {
+			return gtserror.Newf("error storing interaction request: %w", err)
+		}
+
+		// Notify target account (if local) of pending announce.
+		if err := p.surfacer.NotifyPendingAnnounce(ctx, intReq.Announce); err != nil {
+			return gtserror.Newf("error notifying pending announce: %w", err)
+		}
+
+		// Send interaction request to target account (if remote).
+		if err := p.federate.InteractionRequest(ctx, intReq); err != nil {
+			return gtserror.Newf("error federating interaction request: %w", err)
+		}
+
+		return nil
+	}
+
+	// If the boost is pre-approved, then it must
+	// target a status on our instance, and the
+	// booster gets automatic approval due to being
+	// in the author's followers/following collection.
+	//
+	// Mark the interaction request as accepted, store it,
+	// mark the interaction as approved, and then continue
+	// with side effects as normal.
+
+	// Update intReq fields to
+	// mark it as accepted.
+	intReq.MarkAccepted()
+
+	// Put it in the DB.
+	if err := p.utils.storeInteractionRequest(
+		ctx, intReq,
+	); err != nil {
+		return gtserror.Newf("error storing interaction request: %w", err)
+	}
+
+	// Mark the status as now approved, referring to
+	// the accepted interaction request we just stored.
+	boost.PendingApproval = util.Ptr(false)
+	boost.PreApproved = false
+	boost.ApprovedByURI = intReq.AuthorizationURI
+	if err := p.state.DB.UpdateStatus(
+		ctx,
+		boost,
+		"pending_approval",
+		"approved_by_uri",
+	); err != nil {
+		return gtserror.Newf("db error updating status: %w", err)
+	}
+
+	// Timeline and notify the boost wrapper status.
+	if err := p.surfacer.TimelineAndNotifyStatus(ctx, boost); err != nil {
+		log.Errorf(ctx, "error timelining and notifying status: %v", err)
+	}
+
+	// Notify the boost target account.
+	if err := p.surfacer.NotifyAnnounce(ctx, boost); err != nil {
+		log.Errorf(ctx, "error notifying boost: %v", err)
+	}
+
+	// Send out the approval as an Accept.
+	if err := p.federate.AcceptInteraction(ctx, intReq); err != nil {
+		return gtserror.Newf("error federating pre-approval of boost: %w", err)
+	}
+
+	// Send out the announce itself.
+	if err := p.federate.Announce(ctx, boost); err != nil {
+		log.Errorf(ctx, "error federating announce: %v", err)
+	}
 
 	return nil
 }
@@ -678,7 +722,7 @@ func (p *clientAPI) CreateBlock(ctx context.Context, cMsg *messages.FromClientAP
 
 	if block.Account.IsLocal() {
 		// Remove posts by target from origin's timelines.
-		p.surface.removeRelationshipFromTimelines(ctx,
+		p.surfacer.RemoveRelationshipFromTimelines(ctx,
 			block.AccountID,
 			block.TargetAccountID,
 		)
@@ -686,7 +730,7 @@ func (p *clientAPI) CreateBlock(ctx context.Context, cMsg *messages.FromClientAP
 
 	if block.TargetAccount.IsLocal() {
 		// Remove posts by origin from target's timelines.
-		p.surface.removeRelationshipFromTimelines(ctx,
+		p.surfacer.RemoveRelationshipFromTimelines(ctx,
 			block.TargetAccountID,
 			block.AccountID,
 		)
@@ -714,57 +758,11 @@ func (p *clientAPI) UpdateStatus(ctx context.Context, cMsg *messages.FromClientA
 		log.Errorf(ctx, "error federating status update: %v", err)
 	}
 
-	if status.Poll != nil && status.Poll.Closing {
-
-		// If the latest status has a newly closed poll, at least compared
-		// to the existing version, then notify poll close to all voters.
-		if err := p.surface.notifyPollClose(ctx, status); err != nil {
-			log.Errorf(ctx, "error notifying poll close: %v", err)
-		}
-	}
-
-	// Notify any *new* mentions added
-	// to this status by the editor.
-	for _, mention := range status.Mentions {
-		// Check if we've seen
-		// this mention already.
-		if !mention.IsNew {
-			// Already seen
-			// it, skip.
-			continue
-		}
-
-		// Haven't seen this mention
-		// yet, notify it if necessary.
-		mention.Status = status
-		if err := p.surface.notifyMention(ctx, mention); err != nil {
-			log.Errorf(ctx, "error notifying mention: %v", err)
-		}
-	}
-
-	if len(status.EditIDs) > 0 {
-		// Ensure edits are fully populated for this status before anything.
-		if err := p.surface.State.DB.PopulateStatusEdits(ctx, status); err != nil {
-			log.Error(ctx, "error populating updated status edits: %v")
-
-			// Then send notifications of a status edit
-			// to any local interactors of the status.
-		} else if err := p.surface.notifyStatusEdit(ctx,
-			status,
-			status.Edits[len(status.Edits)-1], // latest
-		); err != nil {
-			log.Errorf(ctx, "error notifying status edit: %v", err)
-		}
-	}
-
-	// Push message that the status has been edited to streams.
-	if err := p.surface.timelineStatusUpdate(ctx, status); err != nil {
+	// Stream and notify relevant local users that the status has been edited.
+	if err := p.surfacer.TimelineAndNotifyStatusUpdate(ctx, status); err != nil {
 		log.Errorf(ctx, "error streaming status edit: %v", err)
 	}
 
-	// Status representation has changed, invalidate from timelines.
-	p.surface.invalidateStatusFromTimelines(status.ID)
-
 	return nil
 }
 
@@ -778,9 +776,6 @@ func (p *clientAPI) UpdateAccount(ctx context.Context, cMsg *messages.FromClient
 		log.Errorf(ctx, "error federating account update: %v", err)
 	}
 
-	// Account representation has changed, invalidate from timelines.
-	p.surface.invalidateTimelineEntriesByAccount(account.ID)
-
 	return nil
 }
 
@@ -796,7 +791,7 @@ func (p *clientAPI) UpdateReport(ctx context.Context, cMsg *messages.FromClientA
 		return nil
 	}
 
-	if err := p.surface.emailUserReportClosed(ctx, report); err != nil {
+	if err := p.surfacer.EmailUserReportClosed(ctx, report); err != nil {
 		log.Errorf(ctx, "error emailing report closed: %v", err)
 	}
 
@@ -812,7 +807,7 @@ func (p *clientAPI) UpdateUser(ctx context.Context, cMsg *messages.FromClientAPI
 	// The only possible "UpdateUser" action is to update the
 	// user's email address, so we can safely assume by this
 	// point that a new unconfirmed email address has been set.
-	if err := p.surface.emailUserPleaseConfirm(ctx, user, false); err != nil {
+	if err := p.surfacer.EmailUserPleaseConfirm(ctx, user, false); err != nil {
 		log.Errorf(ctx, "error emailing report closed: %v", err)
 	}
 
@@ -825,7 +820,7 @@ func (p *clientAPI) AcceptFollow(ctx context.Context, cMsg *messages.FromClientA
 		return gtserror.Newf("%T not parseable as *gtsmodel.Follow", cMsg.GTSModel)
 	}
 
-	if err := p.surface.notifyFollow(ctx, follow); err != nil {
+	if err := p.surfacer.NotifyFollow(ctx, follow); err != nil {
 		log.Errorf(ctx, "error notifying follow: %v", err)
 	}
 
@@ -843,7 +838,7 @@ func (p *clientAPI) RejectFollowRequest(ctx context.Context, cMsg *messages.From
 	}
 
 	if err := p.federate.RejectFollow(ctx,
-		p.converter.FollowRequestToFollow(ctx, followReq),
+		typeutils.FollowRequestToFollow(followReq),
 	); err != nil {
 		log.Errorf(ctx, "error federating follow reject: %v", err)
 	}
@@ -859,7 +854,7 @@ func (p *clientAPI) UndoFollow(ctx context.Context, cMsg *messages.FromClientAPI
 
 	if follow.Account.IsLocal() {
 		// Remove posts by target from origin's timelines.
-		p.surface.removeRelationshipFromTimelines(ctx,
+		p.surfacer.RemoveRelationshipFromTimelines(ctx,
 			follow.AccountID,
 			follow.TargetAccountID,
 		)
@@ -867,7 +862,7 @@ func (p *clientAPI) UndoFollow(ctx context.Context, cMsg *messages.FromClientAPI
 
 	if follow.TargetAccount.IsLocal() {
 		// Remove posts by origin from target's timelines.
-		p.surface.removeRelationshipFromTimelines(ctx,
+		p.surfacer.RemoveRelationshipFromTimelines(ctx,
 			follow.TargetAccountID,
 			follow.AccountID,
 		)
@@ -917,10 +912,6 @@ func (p *clientAPI) UndoFave(ctx context.Context, cMsg *messages.FromClientAPI)
 		log.Errorf(ctx, "error federating like undo: %v", err)
 	}
 
-	// Interaction counts changed on the faved status;
-	// uncache the prepared version from all timelines.
-	p.surface.invalidateStatusFromTimelines(statusFave.StatusID)
-
 	return nil
 }
 
@@ -931,16 +922,12 @@ func (p *clientAPI) UndoAnnounce(ctx context.Context, cMsg *messages.FromClientA
 	}
 
 	// Delete the boost wrapper status from timelines.
-	p.surface.deleteStatusFromTimelines(ctx, status.ID)
+	p.surfacer.DeleteStatusFromTimelines(ctx, status.ID)
 
 	if err := p.federate.UndoAnnounce(ctx, status); err != nil {
 		log.Errorf(ctx, "error federating announce undo: %v", err)
 	}
 
-	// Interaction counts changed on the boosted status;
-	// uncache the prepared version from all timelines.
-	p.surface.invalidateStatusFromTimelines(status.BoostOfID)
-
 	return nil
 }
 
@@ -994,12 +981,6 @@ func (p *clientAPI) DeleteStatus(ctx context.Context, cMsg *messages.FromClientA
 		log.Errorf(ctx, "error federating status delete: %v", err)
 	}
 
-	if status.InReplyToID != "" {
-		// Interaction counts changed on the replied status;
-		// uncache the prepared version from all timelines.
-		p.surface.invalidateStatusFromTimelines(status.InReplyToID)
-	}
-
 	return nil
 }
 
@@ -1041,7 +1022,7 @@ func (p *clientAPI) DeleteAccountOrUser(ctx context.Context, cMsg *messages.From
 	p.state.Workers.Federator.Queue.Delete("TargetURI", account.URI)
 
 	// Remove any entries authored by account from timelines.
-	p.surface.removeTimelineEntriesByAccount(account.ID)
+	p.surfacer.RemoveTimelineEntriesByAccount(account.ID)
 
 	// Remove any of their cached timelines.
 	p.state.Caches.Timelines.Home.Delete(account.ID)
@@ -1084,7 +1065,7 @@ func (p *clientAPI) ReportAccount(ctx context.Context, cMsg *messages.FromClient
 		}
 	}
 
-	if err := p.surface.emailAdminReportOpened(ctx, report); err != nil {
+	if err := p.surfacer.EmailAdminReportOpened(ctx, report); err != nil {
 		log.Errorf(ctx, "error emailing report opened: %v", err)
 	}
 
@@ -1137,7 +1118,7 @@ func (p *clientAPI) AcceptUser(ctx context.Context, cMsg *messages.FromClientAPI
 	}
 
 	// Send "your sign-up has been approved" email to the new user.
-	if err := p.surface.emailUserSignupApproved(ctx, newUser); err != nil {
+	if err := p.surfacer.EmailUserSignupApproved(ctx, newUser); err != nil {
 		log.Errorf(ctx, "error emailing: %v", err)
 	}
 
@@ -1176,7 +1157,7 @@ func (p *clientAPI) RejectUser(ctx context.Context, cMsg *messages.FromClientAPI
 
 	if *deniedUser.SendEmail {
 		// Send "your sign-up has been rejected" email to the denied user.
-		if err := p.surface.emailUserSignupRejected(ctx, deniedUser); err != nil {
+		if err := p.surfacer.EmailUserSignupRejected(ctx, deniedUser); err != nil {
 			log.Errorf(ctx, "error emailing: %v", err)
 		}
 	}
@@ -1191,7 +1172,7 @@ func (p *clientAPI) AcceptLike(ctx context.Context, cMsg *messages.FromClientAPI
 	}
 
 	// Notify the fave (distinct from the notif for the pending fave).
-	if err := p.surface.notifyFave(ctx, req.Like); err != nil {
+	if err := p.surfacer.NotifyFave(ctx, req.Like); err != nil {
 		log.Errorf(ctx, "error notifying fave: %v", err)
 	}
 
@@ -1200,10 +1181,6 @@ func (p *clientAPI) AcceptLike(ctx context.Context, cMsg *messages.FromClientAPI
 		log.Errorf(ctx, "error federating approval of like: %v", err)
 	}
 
-	// Interaction counts changed on the faved status;
-	// uncache the prepared version from all timelines.
-	p.surface.invalidateStatusFromTimelines(req.Like.StatusID)
-
 	return nil
 }
 
@@ -1216,7 +1193,7 @@ func (p *clientAPI) AcceptReply(ctx context.Context, cMsg *messages.FromClientAP
 	reply := req.Reply
 
 	// Timeline the reply + notify relevant accounts.
-	if err := p.surface.timelineAndNotifyStatus(ctx, reply); err != nil {
+	if err := p.surfacer.TimelineAndNotifyStatus(ctx, reply); err != nil {
 		log.Errorf(ctx, "error timelining and notifying status reply: %v", err)
 	}
 
@@ -1225,10 +1202,6 @@ func (p *clientAPI) AcceptReply(ctx context.Context, cMsg *messages.FromClientAP
 		log.Errorf(ctx, "error federating approval of reply: %v", err)
 	}
 
-	// Interaction counts changed on the replied status;
-	// uncache the prepared version from all timelines.
-	p.surface.invalidateStatusFromTimelines(reply.InReplyToID)
-
 	return nil
 }
 
@@ -1241,12 +1214,12 @@ func (p *clientAPI) AcceptAnnounce(ctx context.Context, cMsg *messages.FromClien
 	boost := req.Announce
 
 	// Timeline and notify the announce.
-	if err := p.surface.timelineAndNotifyStatus(ctx, boost); err != nil {
+	if err := p.surfacer.TimelineAndNotifyStatus(ctx, boost); err != nil {
 		log.Errorf(ctx, "error timelining and notifying status: %v", err)
 	}
 
 	// Notify the announce (distinct from the notif for the pending announce).
-	if err := p.surface.notifyAnnounce(ctx, boost); err != nil {
+	if err := p.surfacer.NotifyAnnounce(ctx, boost); err != nil {
 		log.Errorf(ctx, "error notifying announce: %v", err)
 	}
 
@@ -1255,10 +1228,6 @@ func (p *clientAPI) AcceptAnnounce(ctx context.Context, cMsg *messages.FromClien
 		log.Errorf(ctx, "error federating approval of announce: %v", err)
 	}
 
-	// Interaction counts changed on the original status;
-	// uncache the prepared version from all timelines.
-	p.surface.invalidateStatusFromTimelines(boost.BoostOfID)
-
 	return nil
 }
 
