@@ -28,15 +28,16 @@ import (
 	"code.superseriousbusiness.org/gotosocial/internal/federation/dereferencing"
 	"code.superseriousbusiness.org/gotosocial/internal/gtscontext"
 	"code.superseriousbusiness.org/gotosocial/internal/id"
+	"code.superseriousbusiness.org/gotosocial/internal/surfacing"
+	"code.superseriousbusiness.org/gotosocial/internal/typeutils"
 	"code.superseriousbusiness.org/gotosocial/internal/uris"
 	"codeberg.org/gruf/go-kv/v2"
 
+	"code.superseriousbusiness.org/gopkg/log"
 	"code.superseriousbusiness.org/gotosocial/internal/gtserror"
 	"code.superseriousbusiness.org/gotosocial/internal/gtsmodel"
-	"code.superseriousbusiness.org/gotosocial/internal/log"
 	"code.superseriousbusiness.org/gotosocial/internal/messages"
 	"code.superseriousbusiness.org/gotosocial/internal/processing/account"
-	"code.superseriousbusiness.org/gotosocial/internal/processing/common"
 	"code.superseriousbusiness.org/gotosocial/internal/state"
 	"code.superseriousbusiness.org/gotosocial/internal/util"
 )
@@ -46,10 +47,9 @@ import (
 // from the federation/ActivityPub API.
 type fediAPI struct {
 	state    *state.State
-	surface  *Surface
+	surfacer *surfacing.Surfacer
 	federate *federate
 	account  *account.Processor
-	common   *common.Processor
 	utils    *utils
 }
 
@@ -69,7 +69,7 @@ func (p *Processor) ProcessFromFediAPI(ctx context.Context, fMsg *messages.FromF
 
 	// Include GTSModel in logs if appropriate.
 	if fMsg.GTSModel != nil &&
-		log.Level() >= log.DEBUG {
+		log.Level() <= log.DEBUG {
 		fields = append(fields, kv.Field{
 			"model", fMsg.GTSModel,
 		})
@@ -269,8 +269,13 @@ func (p *fediAPI) CreateStatus(ctx context.Context, fMsg *messages.FromFediAPI)
 			fMsg.Receiving.Username,
 			bareStatus,
 			statusable,
-			// Force refresh within 5min window.
+			// Force refresh
+			// within 5min window.
 			dereferencing.Fresh,
+			// Pass callback to insert
+			// other statuses in thread
+			// into timelines (as appropriate).
+			p.surfacer.TimelineAndNotifyStatus,
 		)
 		if err != nil {
 			return gtserror.Newf("error processing new status %s: %w", bareStatus.URI, err)
@@ -279,9 +284,13 @@ func (p *fediAPI) CreateStatus(ctx context.Context, fMsg *messages.FromFediAPI)
 	case fMsg.APIRI != nil:
 		// Model was not set, deref with IRI (this is a forward).
 		// This will also cause the status to be inserted into the db.
-		status, statusable, err = p.federate.GetStatusByURI(ctx,
+		status, statusable, _, err = p.federate.GetStatusByURI(ctx,
 			fMsg.Receiving.Username,
 			fMsg.APIRI,
+			// Pass callback to insert
+			// other statuses in thread
+			// into timelines (as appropriate).
+			p.surfacer.TimelineAndNotifyStatus,
 		)
 		if err != nil {
 			return gtserror.Newf("error dereferencing forwarded status %s: %w", fMsg.APIRI, err)
@@ -302,56 +311,67 @@ func (p *fediAPI) CreateStatus(ctx context.Context, fMsg *messages.FromFediAPI)
 	// If pending approval is true then
 	// status must reply to a LOCAL status
 	// that requires approval for the reply.
-	pendingApproval := util.PtrOrZero(status.PendingApproval)
-
-	switch {
-	case pendingApproval && !status.PreApproved:
-		// If approval is required and status isn't
-		// preapproved, then just notify the account
-		// that's being interacted with: they can
-		// approve or deny the interaction later.
-		if err := p.utils.impoliteReplyRequest(ctx, status); err != nil {
-			return gtserror.Newf("error pending reply: %w", err)
-		}
-
-		// Return early.
-		return nil
-
-	case pendingApproval && status.PreApproved:
-		// If approval is required and status is
-		// preapproved, that means this is a reply
-		// to one of our statuses with permission
-		// that matched on a following/followers
-		// collection. Do the Accept immediately and
-		// then process everything else as normal.
-
-		// Store an already-accepted
-		// impolite interaction request.
-		requestID := id.NewULID()
-		approval := &gtsmodel.InteractionRequest{
-			ID:                    requestID,
+	if util.PtrOrZero(status.PendingApproval) {
+		intReqID := id.NewULIDFromTime(status.CreatedAt)
+		intReq := &gtsmodel.InteractionRequest{
+			ID:                    intReqID,
 			TargetStatusID:        status.InReplyToID,
+			TargetStatus:          status.InReplyTo,
 			TargetAccountID:       status.InReplyToAccountID,
 			TargetAccount:         status.InReplyToAccount,
 			InteractingAccountID:  status.AccountID,
 			InteractingAccount:    status.Account,
-			InteractionRequestURI: gtsmodel.ForwardCompatibleInteractionRequestURI(status.URI, gtsmodel.ReplyRequestSuffix),
+			InteractionRequestURI: status.URI + gtsmodel.ImpoliteReplyRequestSuffix,
 			InteractionURI:        status.URI,
 			InteractionType:       gtsmodel.InteractionReply,
 			Polite:                util.Ptr(false),
 			Reply:                 status,
-			ResponseURI:           uris.GenerateURIForAccept(status.InReplyToAccount.Username, requestID),
-			AuthorizationURI:      uris.GenerateURIForAuthorization(status.InReplyToAccount.Username, requestID),
-			AcceptedAt:            time.Now(),
-		}
-		if err := p.state.DB.PutInteractionRequest(ctx, approval); err != nil {
-			return gtserror.Newf("db error putting pre-approved interaction request: %w", err)
 		}
 
-		// Mark the status as now approved.
-		status.PendingApproval = util.Ptr(false)
+		if !status.PreApproved {
+			// If approval is required and reply isn't
+			// preapproved, just store the interaction request
+			// and notify the account that's being interacted
+			// with, they can handle the interaction later.
+			if err := p.utils.storeInteractionRequest(
+				ctx, intReq,
+			); err != nil {
+				return gtserror.Newf("error storing interaction request: %w", err)
+			}
+
+			// Notify target account (if local) of pending reply.
+			if err := p.surfacer.NotifyPendingReply(ctx, intReq.Reply); err != nil {
+				return gtserror.Newf("error notifying pending reply: %w", err)
+			}
+
+			return nil
+		}
+
+		// If approval is required and status *is* preapproved,
+		// that means this is a reply to one of our statuses
+		// that was allowed based on replier's presence in a
+		// following/followers collection.
+		//
+		// Mark the interaction request as accepted, store it,
+		// mark the interaction as approved, and then continue
+		// with side effects as normal.
+
+		// Update intReq fields to
+		// mark it as accepted.
+		intReq.MarkAccepted()
+
+		// Put it in the DB.
+		if err := p.utils.storeInteractionRequest(
+			ctx, intReq,
+		); err != nil {
+			return gtserror.Newf("error storing interaction request: %w", err)
+		}
+
+		// Mark the status as now approved, referring to
+		// the accepted interaction request we just stored.
 		status.PreApproved = false
-		status.ApprovedByURI = approval.AuthorizationURI
+		status.PendingApproval = util.Ptr(false)
+		status.ApprovedByURI = intReq.AuthorizationURI
 		if err := p.state.DB.UpdateStatus(
 			ctx,
 			status,
@@ -362,24 +382,18 @@ func (p *fediAPI) CreateStatus(ctx context.Context, fMsg *messages.FromFediAPI)
 		}
 
 		// Send out the approval as Accept.
-		if err := p.federate.AcceptInteraction(ctx, approval); err != nil {
+		if err := p.federate.AcceptInteraction(ctx, intReq); err != nil {
 			return gtserror.Newf("error federating pre-approval of reply: %w", err)
 		}
 
-		// Don't return, just continue as normal.
+		// Don't return, just continue
+		// side effects as normal.
 	}
 
-	if err := p.surface.timelineAndNotifyStatus(ctx, status); err != nil {
+	if err := p.surfacer.TimelineAndNotifyStatus(ctx, status); err != nil {
 		log.Errorf(ctx, "error timelining and notifying status: %v", err)
 	}
 
-	if status.InReplyToID != "" {
-		// Interaction counts changed on the replied status; uncache the
-		// prepared version from all timelines. The status dereferencer
-		// functions will ensure necessary ancestors exist before this point.
-		p.surface.invalidateStatusFromTimelines(status.InReplyToID)
-	}
-
 	return nil
 }
 
@@ -405,8 +419,13 @@ func (p *fediAPI) CreateReplyRequest(ctx context.Context, fMsg *messages.FromFed
 			Local: util.Ptr(false),
 		},
 		statusable,
-		// Force refresh within 5min window.
+		// Force refresh
+		// within 5min window.
 		dereferencing.Fresh,
+		// Don't pass callback;
+		// we're only interested
+		// in enriching the reply.
+		nil,
 	)
 
 	switch {
@@ -439,7 +458,7 @@ func (p *fediAPI) CreateReplyRequest(ctx context.Context, fMsg *messages.FromFed
 		//
 		// Just notify target account about
 		// the requested interaction.
-		if err := p.surface.notifyPendingReply(ctx, reply); err != nil {
+		if err := p.surfacer.NotifyPendingReply(ctx, reply); err != nil {
 			return gtserror.Newf("error notifying pending reply: %w", err)
 		}
 
@@ -493,14 +512,10 @@ func (p *fediAPI) CreateReplyRequest(ctx context.Context, fMsg *messages.FromFed
 	}
 
 	// Timeline the reply + notify recipient(s).
-	if err := p.surface.timelineAndNotifyStatus(ctx, reply); err != nil {
+	if err := p.surfacer.TimelineAndNotifyStatus(ctx, reply); err != nil {
 		log.Errorf(ctx, "error timelining and notifying status: %v", err)
 	}
 
-	// Interaction counts changed on the replied status;
-	// uncache the prepared version from all timelines.
-	p.surface.invalidateStatusFromTimelines(reply.InReplyToID)
-
 	return nil
 }
 
@@ -544,9 +559,6 @@ func (p *fediAPI) CreatePollVote(ctx context.Context, fMsg *messages.FromFediAPI
 		}
 	}
 
-	// Interaction counts changed, uncache from timelines.
-	p.surface.invalidateStatusFromTimelines(status.ID)
-
 	return nil
 }
 
@@ -579,38 +591,134 @@ func (p *fediAPI) UpdatePollVote(ctx context.Context, fMsg *messages.FromFediAPI
 		}
 	}
 
-	// Interaction counts changed, uncache from timelines.
-	p.surface.invalidateStatusFromTimelines(reply.ID)
-
 	return nil
 }
 
 func (p *fediAPI) CreateFollowReq(ctx context.Context, fMsg *messages.FromFediAPI) error {
-	followRequest, ok := fMsg.GTSModel.(*gtsmodel.FollowRequest)
+	followReq, ok := fMsg.GTSModel.(*gtsmodel.FollowRequest)
 	if !ok {
 		return gtserror.Newf("%T not parseable as *gtsmodel.FollowRequest", fMsg.GTSModel)
 	}
 
-	if err := p.state.DB.PopulateFollowRequest(ctx, followRequest); err != nil {
+	if err := p.state.DB.PopulateFollowRequest(ctx, followReq); err != nil {
 		return gtserror.Newf("error populating follow request: %w", err)
 	}
 
-	if *followRequest.TargetAccount.Locked {
-		// Local account is locked: just notify the follow request.
-		if err := p.surface.notifyFollowRequest(ctx, followRequest); err != nil {
-			log.Errorf(ctx, "error notifying follow request: %v", err)
+	// Figure out what we should do with this follow request.
+	//
+	// If it's from a domain with a domain limit we may need
+	// to handle it differently depending on the Follows policy.
+	var (
+		// Assume not rejecting.
+		reject bool
+
+		// Assume accepting if our account isn't locked.
+		// We'll override this if necessary.
+		accept bool = !*followReq.TargetAccount.Locked
+	)
+
+	// See if there's a limit on the would-be follower's domain.
+	limit, err := p.state.DB.MatchDomainLimit(ctx, followReq.Account.Domain)
+	if err != nil {
+		return gtserror.Newf("error matching domain limit: %w", err)
+	}
+
+	if limit != nil {
+
+		// Limit is in place so
+		// check the follows policy.
+		switch limit.FollowsPolicy {
+
+		case gtsmodel.FollowsPolicyNoAction:
+			// Noop policy,
+			// let things proceed.
+
+		case gtsmodel.FollowsPolicyManualApproval:
+			// Don't reject but don't
+			// accept automatically either.
+			accept = false
+
+		case gtsmodel.FollowsPolicyRejectNonMutual:
+			// Check if our account
+			// follows the remote.
+			if mufo, err := p.state.DB.IsFollowing(
+				ctx,
+				followReq.TargetAccountID,
+				followReq.AccountID,
+			); err != nil {
+				return gtserror.Newf("db error checking following: %w", err)
+			} else if mufo {
+				// We follow the remote so
+				// leave reject = false.
+				break
+			}
+
+			// We don't follow the remote but
+			// do we follow *request* them?
+			if mufo, err := p.state.DB.IsFollowRequested(
+				ctx,
+				followReq.TargetAccountID,
+				followReq.AccountID,
+			); err != nil {
+				return gtserror.Newf("db error checking following: %w", err)
+			} else if mufo {
+				// We follow req the remote
+				// so leave reject = false.
+				break
+			}
+
+			// We don't follow or follow
+			// request the remote so
+			// reject their follow of us.
+			reject = true
+
+		case gtsmodel.FollowsPolicyRejectAll:
+			// Reject out of hand.
+			reject = true
+		}
+	}
+
+	if reject {
+		// We're rejecting this
+		// follow request out of hand.
+		//
+		// Delete the req from the db.
+		if err := p.state.DB.RejectFollowRequest(
+			ctx,
+			followReq.AccountID,
+			followReq.TargetAccountID,
+		); err != nil {
+			return gtserror.Newf("db error rejecting follow request: %w", err)
+		}
+
+		// Reconstruct + reject the follow.
+		follow := typeutils.FollowRequestToFollow(followReq)
+		if err := p.federate.RejectFollow(ctx, follow); err != nil {
+			log.Errorf(ctx, "error federating follow reject: %w", err)
+		}
+
+		// That's it, no need to
+		// notify the target account.
+		return nil
+	}
+
+	// If we're not accepting the follow
+	// request automatically, just notify
+	// about it and leave.
+	if !accept {
+		if err := p.surfacer.NotifyFollowRequest(ctx, followReq); err != nil {
+			return gtserror.Newf("error notifying follow request: %w", err)
 		}
 
 		return nil
 	}
 
-	// Local account is not locked:
 	// Automatically accept the follow request
 	// and notify about the new follower.
 	follow, err := p.state.DB.AcceptFollowRequest(
 		ctx,
-		followRequest.AccountID,
-		followRequest.TargetAccountID,
+		followReq.AccountID,
+		followReq.TargetAccountID,
 	)
 	if err != nil {
 		return gtserror.Newf("error accepting follow request: %w", err)
@@ -620,7 +728,7 @@ func (p *fediAPI) CreateFollowReq(ctx context.Context, fMsg *messages.FromFediAP
 		log.Errorf(ctx, "error federating follow request accept: %v", err)
 	}
 
-	if err := p.surface.notifyFollow(ctx, follow); err != nil {
+	if err := p.surfacer.NotifyFollow(ctx, follow); err != nil {
 		log.Errorf(ctx, "error notifying follow: %v", err)
 	}
 
@@ -643,56 +751,67 @@ func (p *fediAPI) CreateLike(ctx context.Context, fMsg *messages.FromFediAPI) er
 	// If pending approval is true then
 	// fave must target a LOCAL status
 	// that requires approval for the fave.
-	pendingApproval := util.PtrOrZero(fave.PendingApproval)
-
-	switch {
-	case pendingApproval && !fave.PreApproved:
-		// If approval is required and fave isn't
-		// preapproved, then just notify the account
-		// that's being interacted with: they can
-		// approve or deny the interaction later.
-		if err := p.utils.impoliteFaveRequest(ctx, fave); err != nil {
-			return gtserror.Newf("error pending fave: %w", err)
-		}
-
-		// Return early.
-		return nil
-
-	case pendingApproval && fave.PreApproved:
-		// If approval is required and fave is
-		// preapproved, that means this is a fave
-		// of one of our statuses with permission
-		// that matched on a following/followers
-		// collection. Do the Accept immediately and
-		// then process everything else as normal.
-
-		// Store an already-accepted
-		// impolite interaction request.
-		requestID := id.NewULID()
-		approval := &gtsmodel.InteractionRequest{
-			ID:                    requestID,
+	if util.PtrOrZero(fave.PendingApproval) {
+		intReqID := id.NewULIDFromTime(fave.CreatedAt)
+		intReq := &gtsmodel.InteractionRequest{
+			ID:                    intReqID,
 			TargetStatusID:        fave.StatusID,
+			TargetStatus:          fave.Status,
 			TargetAccountID:       fave.TargetAccountID,
 			TargetAccount:         fave.TargetAccount,
 			InteractingAccountID:  fave.AccountID,
 			InteractingAccount:    fave.Account,
-			InteractionRequestURI: gtsmodel.ForwardCompatibleInteractionRequestURI(fave.URI, gtsmodel.LikeRequestSuffix),
+			InteractionRequestURI: fave.URI + gtsmodel.ImpoliteLikeRequestSuffix,
 			InteractionURI:        fave.URI,
 			InteractionType:       gtsmodel.InteractionLike,
 			Polite:                util.Ptr(false),
 			Like:                  fave,
-			ResponseURI:           uris.GenerateURIForAccept(fave.TargetAccount.Username, requestID),
-			AuthorizationURI:      uris.GenerateURIForAuthorization(fave.TargetAccount.Username, requestID),
-			AcceptedAt:            time.Now(),
-		}
-		if err := p.state.DB.PutInteractionRequest(ctx, approval); err != nil {
-			return gtserror.Newf("db error putting pre-approved interaction request: %w", err)
 		}
 
-		// Mark the fave itself as now approved.
+		if !fave.PreApproved {
+			// If approval is required and status fave isn't
+			// preapproved, just store the interaction request
+			// and notify the account that's being interacted
+			// with, they can handle the interaction later.
+			if err := p.utils.storeInteractionRequest(
+				ctx, intReq,
+			); err != nil {
+				return gtserror.Newf("error storing interaction request: %w", err)
+			}
+
+			// Notify target account (if local) of pending like.
+			if err := p.surfacer.NotifyPendingFave(ctx, intReq.Like); err != nil {
+				return gtserror.Newf("error notifying pending fave: %w", err)
+			}
+
+			return nil
+		}
+
+		// If approval is required and fave *is* preapproved,
+		// that means this is a fave of one of our statuses
+		// that was allowed based on faver's presence in a
+		// following/followers collection.
+		//
+		// Mark the interaction request as accepted, store it,
+		// mark the interaction as approved, and then continue
+		// with side effects as normal.
+
+		// Update intReq fields to
+		// mark it as accepted.
+		intReq.MarkAccepted()
+
+		// Put it in the DB.
+		if err := p.utils.storeInteractionRequest(
+			ctx, intReq,
+		); err != nil {
+			return gtserror.Newf("error storing interaction request: %w", err)
+		}
+
+		// Mark the fave as now approved, referring to
+		// the accepted interaction request we just stored.
 		fave.PendingApproval = util.Ptr(false)
 		fave.PreApproved = false
-		fave.ApprovedByURI = approval.AuthorizationURI
+		fave.ApprovedByURI = intReq.AuthorizationURI
 		if err := p.state.DB.UpdateStatusFave(
 			ctx,
 			fave,
@@ -703,21 +822,18 @@ func (p *fediAPI) CreateLike(ctx context.Context, fMsg *messages.FromFediAPI) er
 		}
 
 		// Send out the approval as Accept.
-		if err := p.federate.AcceptInteraction(ctx, approval); err != nil {
+		if err := p.federate.AcceptInteraction(ctx, intReq); err != nil {
 			return gtserror.Newf("error federating pre-approval of fave: %w", err)
 		}
 
-		// Don't return, just continue as normal.
+		// Don't return, just continue
+		// side effects as normal.
 	}
 
-	if err := p.surface.notifyFave(ctx, fave); err != nil {
+	if err := p.surfacer.NotifyFave(ctx, fave); err != nil {
 		log.Errorf(ctx, "error notifying fave: %v", err)
 	}
 
-	// Interaction counts changed on the faved status;
-	// uncache the prepared version from all timelines.
-	p.surface.invalidateStatusFromTimelines(fave.StatusID)
-
 	return nil
 }
 
@@ -740,7 +856,7 @@ func (p *fediAPI) CreateLikeRequest(ctx context.Context, fMsg *messages.FromFedi
 		//
 		// Just notify target account about
 		// the requested interaction.
-		if err := p.surface.notifyPendingFave(ctx, req.Like); err != nil {
+		if err := p.surfacer.NotifyPendingFave(ctx, req.Like); err != nil {
 			return gtserror.Newf("error notifying pending like: %w", err)
 		}
 
@@ -790,14 +906,10 @@ func (p *fediAPI) CreateLikeRequest(ctx context.Context, fMsg *messages.FromFedi
 	}
 
 	// Notify the faved account.
-	if err := p.surface.notifyFave(ctx, req.Like); err != nil {
+	if err := p.surfacer.NotifyFave(ctx, req.Like); err != nil {
 		log.Errorf(ctx, "error notifying fave: %v", err)
 	}
 
-	// Interaction counts changed on the faved status;
-	// uncache the prepared version from all timelines.
-	p.surface.invalidateStatusFromTimelines(req.Like.StatusID)
-
 	return nil
 }
 
@@ -812,11 +924,18 @@ func (p *fediAPI) CreateAnnounce(ctx context.Context, fMsg *messages.FromFediAPI
 	// Note: this will handle storing the boost in
 	// the db, and dereferencing the target status
 	// ancestors / descendants where appropriate.
-	var err error
-	boost, err = p.federate.EnrichAnnounce(
+	var (
+		targetIsNew bool
+		err         error
+	)
+	boost, targetIsNew, err = p.federate.EnrichAnnounce(
 		ctx,
 		boost,
 		fMsg.Receiving.Username,
+		// Pass callback to insert
+		// other statuses in thread
+		// into timelines (as appropriate).
+		p.surfacer.TimelineAndNotifyStatus,
 	)
 	if err != nil {
 		if gtserror.IsUnretrievable(err) ||
@@ -834,56 +953,66 @@ func (p *fediAPI) CreateAnnounce(ctx context.Context, fMsg *messages.FromFediAPI
 	// If pending approval is true then
 	// boost must target a LOCAL status
 	// that requires approval for the boost.
-	pendingApproval := util.PtrOrZero(boost.PendingApproval)
-
-	switch {
-	case pendingApproval && !boost.PreApproved:
-		// If approval is required and boost isn't
-		// preapproved, then just notify the account
-		// that's being interacted with: they can
-		// approve or deny the interaction later.
-		if err := p.utils.impoliteAnnounceRequest(ctx, boost); err != nil {
-			return gtserror.Newf("error pending boost: %w", err)
-		}
-
-		// Return early.
-		return nil
-
-	case pendingApproval && boost.PreApproved:
-		// If approval is required and status is
-		// preapproved, that means this is a boost
-		// of one of our statuses with permission
-		// that matched on a following/followers
-		// collection. Do the Accept immediately and
-		// then process everything else as normal.
-
-		// Store an already-accepted
-		// impolite interaction request.
-		requestID := id.NewULID()
-		approval := &gtsmodel.InteractionRequest{
-			ID:                    requestID,
+	if util.PtrOrZero(boost.PendingApproval) {
+		intReqID := id.NewULIDFromTime(boost.CreatedAt)
+		intReq := &gtsmodel.InteractionRequest{
+			ID:                    intReqID,
 			TargetStatusID:        boost.BoostOfID,
+			TargetStatus:          boost.BoostOf,
 			TargetAccountID:       boost.BoostOfAccountID,
 			TargetAccount:         boost.BoostOfAccount,
 			InteractingAccountID:  boost.AccountID,
 			InteractingAccount:    boost.Account,
-			InteractionRequestURI: gtsmodel.ForwardCompatibleInteractionRequestURI(boost.URI, gtsmodel.AnnounceRequestSuffix),
+			InteractionRequestURI: boost.URI + gtsmodel.ImpoliteAnnounceRequestSuffix,
 			InteractionURI:        boost.URI,
 			InteractionType:       gtsmodel.InteractionAnnounce,
 			Polite:                util.Ptr(false),
 			Announce:              boost,
-			ResponseURI:           uris.GenerateURIForAccept(boost.BoostOfAccount.Username, requestID),
-			AuthorizationURI:      uris.GenerateURIForAuthorization(boost.BoostOfAccount.Username, requestID),
-			AcceptedAt:            time.Now(),
 		}
-		if err := p.state.DB.PutInteractionRequest(ctx, approval); err != nil {
-			return gtserror.Newf("db error putting pre-approved interaction request: %w", err)
+
+		if !boost.PreApproved {
+			// If approval is required and announce isn't
+			// preapproved, just store the interaction request
+			// and notify the account that's being interacted
+			// with, they can handle the interaction later.
+			if err := p.utils.storeInteractionRequest(
+				ctx, intReq,
+			); err != nil {
+				return gtserror.Newf("error storing interaction request: %w", err)
+			}
+
+			// Notify target account (if local) of pending announce.
+			if err := p.surfacer.NotifyPendingAnnounce(ctx, intReq.Announce); err != nil {
+				return gtserror.Newf("error notifying pending announce: %w", err)
+			}
+
+			return nil
+		}
+
+		// If approval is required and boost *is* preapproved,
+		// that means this is a boost of one of our statuses
+		// that was allowed based on booster's presence in a
+		// following/followers collection.
+		//
+		// Mark the interaction request as accepted, store it,
+		// mark the interaction as approved, and then continue
+		// with side effects as normal.
+
+		// Update intReq fields to
+		// mark it as accepted.
+		intReq.MarkAccepted()
+
+		// Put it in the DB.
+		if err := p.utils.storeInteractionRequest(
+			ctx, intReq,
+		); err != nil {
+			return gtserror.Newf("error storing interaction request: %w", err)
 		}
 
 		// Mark the boost itself as now approved.
 		boost.PendingApproval = util.Ptr(false)
 		boost.PreApproved = false
-		boost.ApprovedByURI = approval.AuthorizationURI
+		boost.ApprovedByURI = intReq.AuthorizationURI
 		if err := p.state.DB.UpdateStatus(
 			ctx,
 			boost,
@@ -894,26 +1023,41 @@ func (p *fediAPI) CreateAnnounce(ctx context.Context, fMsg *messages.FromFediAPI
 		}
 
 		// Send out the approval as Accept.
-		if err := p.federate.AcceptInteraction(ctx, approval); err != nil {
+		if err := p.federate.AcceptInteraction(ctx, intReq); err != nil {
 			return gtserror.Newf("error federating pre-approval of boost: %w", err)
 		}
 
-		// Don't return, just continue as normal.
+		// Don't return, just continue
+		// side effects as normal.
 	}
 
-	// Timeline and notify the announce.
-	if err := p.surface.timelineAndNotifyStatus(ctx, boost); err != nil {
-		log.Errorf(ctx, "error timelining and notifying status: %v", err)
+	// Timeline the target of the announce (if appropriate).
+	//
+	// This is done to avoid cases where we follow both the announcer
+	// of a status and the original creator of that status, and we
+	// receive the Announce of a status *before* we receive the Create
+	// of that status (say because the creator has a big queue of
+	// followers to deliver to, and someone gets it before us and
+	// boosts it to us), and we end up not timelining the original
+	// status, or notifying it, etc.
+	if targetIsNew {
+		if err := p.surfacer.TimelineAndNotifyStatus(ctx, boost.BoostOf); err != nil {
+			log.Errorf(ctx, "error timelining and notifying boosted status: %v", err)
+		}
 	}
 
-	if err := p.surface.notifyAnnounce(ctx, boost); err != nil {
+	// Timeline and notify the announce itself.
+	//
+	// This is specifically done *after* timelining the original
+	// status, so that boost depth can be taken into account.
+	if err := p.surfacer.TimelineAndNotifyStatus(ctx, boost); err != nil {
+		log.Errorf(ctx, "error timelining and notifying boost: %v", err)
+	}
+
+	if err := p.surfacer.NotifyAnnounce(ctx, boost); err != nil {
 		log.Errorf(ctx, "error notifying announce: %v", err)
 	}
 
-	// Interaction counts changed on the original status;
-	// uncache the prepared version from all timelines.
-	p.surface.invalidateStatusFromTimelines(boost.BoostOfID)
-
 	return nil
 }
 
@@ -928,10 +1072,14 @@ func (p *fediAPI) CreateAnnounceRequest(ctx context.Context, fMsg *messages.From
 	//
 	// We can check permissions for the announce *and*
 	// put it in the db (if acceptable) by doing Enrich.
-	boost, err := p.federate.EnrichAnnounce(
+	boost, targetIsNew, err := p.federate.EnrichAnnounce(
 		ctx,
 		req.Announce,
 		fMsg.Receiving.Username,
+		// Don't pass callback;
+		// we're only interested
+		// in enriching the announce.
+		nil,
 	)
 
 	switch {
@@ -964,7 +1112,7 @@ func (p *fediAPI) CreateAnnounceRequest(ctx context.Context, fMsg *messages.From
 		//
 		// Just notify target account about
 		// the requested interaction.
-		if err := p.surface.notifyPendingAnnounce(ctx, boost); err != nil {
+		if err := p.surfacer.NotifyPendingAnnounce(ctx, boost); err != nil {
 			return gtserror.Newf("error notifying pending announce: %w", err)
 		}
 
@@ -1011,14 +1159,25 @@ func (p *fediAPI) CreateAnnounceRequest(ctx context.Context, fMsg *messages.From
 		log.Errorf(ctx, "error federating accept: %v", err)
 	}
 
-	// Timeline the boost + notify recipient(s).
-	if err := p.surface.timelineAndNotifyStatus(ctx, boost); err != nil {
-		log.Errorf(ctx, "error timelining and notifying status: %v", err)
+	// Timeline the target of the announce (if appropriate).
+	//
+	// This is done to avoid cases where we follow both the announcer
+	// of a status and the original creator of that status, and we
+	// receive the Announce of a status *before* we receive the Create
+	// of that status (say because the creator has a big queue of
+	// followers to deliver to, and someone gets it before us and
+	// boosts it to us), and we end up not timelining the original
+	// status, or notifying it, etc.
+	if targetIsNew {
+		if err := p.surfacer.TimelineAndNotifyStatus(ctx, boost.BoostOf); err != nil {
+			log.Errorf(ctx, "error timelining and notifying boosted status: %v", err)
+		}
 	}
 
-	// Interaction counts changed on the boosted status;
-	// uncache the prepared version from all timelines.
-	p.surface.invalidateStatusFromTimelines(boost.BoostOfID)
+	// Timeline the boost + notify recipient(s).
+	if err := p.surfacer.TimelineAndNotifyStatus(ctx, boost); err != nil {
+		log.Errorf(ctx, "error timelining and notifying boost: %v", err)
+	}
 
 	return nil
 }
@@ -1031,7 +1190,7 @@ func (p *fediAPI) CreateBlock(ctx context.Context, fMsg *messages.FromFediAPI) e
 
 	if block.Account.IsLocal() {
 		// Remove posts by target from origin's timelines.
-		p.surface.removeRelationshipFromTimelines(ctx,
+		p.surfacer.RemoveRelationshipFromTimelines(ctx,
 			block.AccountID,
 			block.TargetAccountID,
 		)
@@ -1039,7 +1198,7 @@ func (p *fediAPI) CreateBlock(ctx context.Context, fMsg *messages.FromFediAPI) e
 
 	if block.TargetAccount.IsLocal() {
 		// Remove posts by origin from target's timelines.
-		p.surface.removeRelationshipFromTimelines(ctx,
+		p.surfacer.RemoveRelationshipFromTimelines(ctx,
 			block.TargetAccountID,
 			block.AccountID,
 		)
@@ -1088,7 +1247,7 @@ func (p *fediAPI) CreateFlag(ctx context.Context, fMsg *messages.FromFediAPI) er
 	// TODO: handle additional side effects of flag creation:
 	// - notify admins by dm / notification
 
-	if err := p.surface.emailAdminReportOpened(ctx, incomingReport); err != nil {
+	if err := p.surfacer.EmailAdminReportOpened(ctx, incomingReport); err != nil {
 		log.Errorf(ctx, "error emailing report opened: %v", err)
 	}
 
@@ -1126,9 +1285,6 @@ func (p *fediAPI) UpdateAccount(ctx context.Context, fMsg *messages.FromFediAPI)
 		log.Errorf(ctx, "error refreshing account: %v", err)
 	}
 
-	// Account representation has changed, invalidate from timelines.
-	p.surface.invalidateTimelineEntriesByAccount(account.ID)
-
 	return nil
 }
 
@@ -1149,19 +1305,15 @@ func (p *fediAPI) AcceptReply(ctx context.Context, fMsg *messages.FromFediAPI) e
 	}
 
 	// Timeline and notify the status.
-	if err := p.surface.timelineAndNotifyStatus(ctx, reply); err != nil {
+	if err := p.surfacer.TimelineAndNotifyStatus(ctx, reply); err != nil {
 		log.Errorf(ctx, "error timelining and notifying status: %v", err)
 	}
 
-	// Send out the reply again, fully this time.
+	// Send out the reply.
 	if err := p.federate.CreateStatus(ctx, reply); err != nil {
-		log.Errorf(ctx, "error federating announce: %v", err)
+		log.Errorf(ctx, "error federating status: %v", err)
 	}
 
-	// Interaction counts changed on the replied-to status;
-	// uncache the prepared version from all timelines.
-	p.surface.invalidateStatusFromTimelines(reply.InReplyToID)
-
 	return nil
 }
 
@@ -1195,6 +1347,10 @@ func (p *fediAPI) AcceptRemoteStatus(ctx context.Context, fMsg *messages.FromFed
 		fMsg.Receiving.Username,
 		bareStatus,
 		nil, nil,
+		// Pass callback to insert
+		// other statuses in thread
+		// into timelines (as appropriate).
+		p.surfacer.TimelineAndNotifyStatus,
 	)
 	if err != nil {
 		return gtserror.Newf("error processing accepted status %s: %w", bareStatus.URI, err)
@@ -1202,20 +1358,10 @@ func (p *fediAPI) AcceptRemoteStatus(ctx context.Context, fMsg *messages.FromFed
 
 	// No error means it was indeed a remote status, and the
 	// given approvedByURI permitted it. Timeline and notify it.
-	if err := p.surface.timelineAndNotifyStatus(ctx, reply); err != nil {
+	if err := p.surfacer.TimelineAndNotifyStatus(ctx, reply); err != nil {
 		log.Errorf(ctx, "error timelining and notifying status: %v", err)
 	}
 
-	// Interaction counts changed on the interacted status;
-	// uncache the prepared version from all timelines.
-	if reply.InReplyToID != "" {
-		p.surface.invalidateStatusFromTimelines(reply.InReplyToID)
-	}
-
-	if reply.BoostOfID != "" {
-		p.surface.invalidateStatusFromTimelines(reply.BoostOfID)
-	}
-
 	return nil
 }
 
@@ -1248,19 +1394,15 @@ func (p *fediAPI) AcceptPoliteReplyRequest(ctx context.Context, fMsg *messages.F
 	}
 
 	// Timeline and notify the status.
-	if err := p.surface.timelineAndNotifyStatus(ctx, reply); err != nil {
+	if err := p.surfacer.TimelineAndNotifyStatus(ctx, reply); err != nil {
 		log.Errorf(ctx, "error timelining and notifying status: %v", err)
 	}
 
 	// Send out the reply with approval attached.
 	if err := p.federate.CreateStatus(ctx, reply); err != nil {
-		log.Errorf(ctx, "error federating announce: %v", err)
+		log.Errorf(ctx, "error federating status: %v", err)
 	}
 
-	// Interaction counts changed on the replied-to status;
-	// uncache the prepared version from all timelines.
-	p.surface.invalidateStatusFromTimelines(reply.InReplyToID)
-
 	return nil
 }
 
@@ -1271,7 +1413,7 @@ func (p *fediAPI) AcceptAnnounce(ctx context.Context, fMsg *messages.FromFediAPI
 	}
 
 	// Timeline and notify the boost wrapper status.
-	if err := p.surface.timelineAndNotifyStatus(ctx, boost); err != nil {
+	if err := p.surfacer.TimelineAndNotifyStatus(ctx, boost); err != nil {
 		log.Errorf(ctx, "error timelining and notifying status: %v", err)
 	}
 
@@ -1280,10 +1422,6 @@ func (p *fediAPI) AcceptAnnounce(ctx context.Context, fMsg *messages.FromFediAPI
 		log.Errorf(ctx, "error federating announce: %v", err)
 	}
 
-	// Interaction counts changed on the boosted status;
-	// uncache the prepared version from all timelines.
-	p.surface.invalidateStatusFromTimelines(boost.BoostOfID)
-
 	return nil
 }
 
@@ -1313,62 +1451,20 @@ func (p *fediAPI) UpdateStatus(ctx context.Context, fMsg *messages.FromFediAPI)
 		existing,
 		apStatus,
 		freshness,
+		// Pass callback to insert
+		// other statuses in thread
+		// into timelines (as appropriate).
+		p.surfacer.TimelineAndNotifyStatus,
 	)
 	if err != nil {
 		log.Errorf(ctx, "error refreshing status: %v", err)
 	}
 
-	if status.Poll != nil && status.Poll.Closing {
-
-		// If the latest status has a newly closed poll, at least compared
-		// to the existing version, then notify poll close to all voters.
-		if err := p.surface.notifyPollClose(ctx, status); err != nil {
-			log.Errorf(ctx, "error sending poll notification: %v", err)
-		}
-	}
-
-	// Notify any *new* mentions added
-	// to this status by the editor.
-	for _, mention := range status.Mentions {
-		// Check if we've seen
-		// this mention already.
-		if !mention.IsNew {
-			// Already seen
-			// it, skip.
-			continue
-		}
-
-		// Haven't seen this mention
-		// yet, notify it if necessary.
-		mention.Status = status
-		if err := p.surface.notifyMention(ctx, mention); err != nil {
-			log.Errorf(ctx, "error notifying mention: %v", err)
-		}
-	}
-
-	if len(status.EditIDs) > 0 {
-		// Ensure edits are fully populated for this status before anything.
-		if err := p.surface.State.DB.PopulateStatusEdits(ctx, status); err != nil {
-			log.Error(ctx, "error populating updated status edits: %v")
-
-			// Then send notifications of a status edit
-			// to any local interactors of the status.
-		} else if err := p.surface.notifyStatusEdit(ctx,
-			status,
-			status.Edits[len(status.Edits)-1], // latest
-		); err != nil {
-			log.Errorf(ctx, "error notifying status edit: %v", err)
-		}
-	}
-
-	// Push message that the status has been edited to streams.
-	if err := p.surface.timelineStatusUpdate(ctx, status); err != nil {
+	// Stream and notify relevant local users that the status has been edited.
+	if err := p.surfacer.TimelineAndNotifyStatusUpdate(ctx, status); err != nil {
 		log.Errorf(ctx, "error streaming status edit: %v", err)
 	}
 
-	// Status representation changed, uncache from timelines.
-	p.surface.invalidateStatusFromTimelines(status.ID)
-
 	return nil
 }
 
@@ -1418,12 +1514,6 @@ func (p *fediAPI) DeleteStatus(ctx context.Context, fMsg *messages.FromFediAPI)
 		log.Errorf(ctx, "error wiping status: %v", err)
 	}
 
-	if status.InReplyToID != "" {
-		// Interaction counts changed on the replied status;
-		// uncache the prepared version from all timelines.
-		p.surface.invalidateStatusFromTimelines(status.InReplyToID)
-	}
-
 	return nil
 }
 
@@ -1449,7 +1539,7 @@ func (p *fediAPI) DeleteAccount(ctx context.Context, fMsg *messages.FromFediAPI)
 	p.state.Workers.Federator.Queue.Delete("TargetURI", account.URI)
 
 	// Remove any entries authored by account from timelines.
-	p.surface.removeTimelineEntriesByAccount(account.ID)
+	p.surfacer.RemoveTimelineEntriesByAccount(account.ID)
 
 	// And finally, perform the actual account deletion synchronously.
 	if err := p.account.Delete(ctx, account, account.ID); err != nil {
@@ -1591,7 +1681,7 @@ func (p *fediAPI) UndoFollow(ctx context.Context, fMsg *messages.FromFediAPI) er
 
 	if follow.Account.IsLocal() {
 		// Remove posts by target from origin's timelines.
-		p.surface.removeRelationshipFromTimelines(ctx,
+		p.surfacer.RemoveRelationshipFromTimelines(ctx,
 			follow.AccountID,
 			follow.TargetAccountID,
 		)
@@ -1599,7 +1689,7 @@ func (p *fediAPI) UndoFollow(ctx context.Context, fMsg *messages.FromFediAPI) er
 
 	if follow.TargetAccount.IsLocal() {
 		// Remove posts by origin from target's timelines.
-		p.surface.removeRelationshipFromTimelines(ctx,
+		p.surfacer.RemoveRelationshipFromTimelines(ctx,
 			follow.TargetAccountID,
 			follow.AccountID,
 		)
@@ -1634,11 +1724,7 @@ func (p *fediAPI) UndoAnnounce(
 	}
 
 	// Remove the boost wrapper from all timelines.
-	p.surface.deleteStatusFromTimelines(ctx, boost.ID)
-
-	// Interaction counts changed on the boosted status;
-	// uncache the prepared version from all timelines.
-	p.surface.invalidateStatusFromTimelines(boost.BoostOfID)
+	p.surfacer.DeleteStatusFromTimelines(ctx, boost.ID)
 
 	return nil
 }
@@ -1649,9 +1735,7 @@ func (p *fediAPI) UndoFave(ctx context.Context, fMsg *messages.FromFediAPI) erro
 		return gtserror.Newf("%T not parseable as *gtsmodel.StatusFave", fMsg.GTSModel)
 	}
 
-	// Interaction counts changed on the faved status;
-	// uncache the prepared version from all timelines.
-	p.surface.invalidateStatusFromTimelines(statusFave.StatusID)
+	_ = statusFave
 
 	return nil
 }
