@@ -41,13 +41,14 @@ const (
 	accepts   = "accepts"
 
 	alphaNumeric             = `\p{L}\p{M}*|\p{N}`                                       // A single number or script character in any language, including chars with accents.
-	usernameGrp              = `(?:` + alphaNumeric + `|\.|\-|\_)`                       // Non-capturing group that matches against a single valid username character.
-	domainGrp                = `(?:` + alphaNumeric + `|\.|\-|\:)`                       // Non-capturing group that matches against a single valid domain character.
+	usernameGrp              = `(?:` + alphaNumeric + `|\.|\-|\_|` + unicodeEmoji + `)`  // Non-capturing group that matches against a single valid username character, including emojis.
+	domainGrp                = `(?:` + alphaNumeric + `|\.|\-|\:|` + unicodeEmoji + `)`  // Non-capturing group that matches against a single valid domain character, including emojis.
 	mentionName              = `^@(` + usernameGrp + `+)(?:@(` + domainGrp + `+))?$`     // Extract parts of one mention, maybe including domain.
 	mentionFinder            = `(?:^|\s)(@` + usernameGrp + `+(?:@` + domainGrp + `+)?)` // Extract all mentions from a text, each mention may include domain.
 	emojiShortcode           = `\w{1,30}`                                                // Pattern for emoji shortcodes. maximumEmojiShortcodeLength = 30
 	emojiFinder              = `(?:\b)?:(` + emojiShortcode + `):(?:\b)?`                // Extract all emoji shortcodes from a text.
 	emojiValidator           = `^` + emojiShortcode + `$`                                // Validate a single emoji shortcode.
+	doubleSpaceFinder        = `(?:\b)?(?:\s|^) (?:\b)?`                                 // Extract all double whitespaces from a text.
 	usernameStrict           = `^[a-z0-9_]{1,64}$`                                       // Pattern for usernames on THIS instance. maximumUsernameLength = 64
 	usernameRelaxed          = `[a-z0-9_\.]{1,}`                                         // Relaxed version of username that can match instance accounts too.
 	misskeyReportNotesFinder = `(?m)(?:^Note: ((?:http|https):\/\/.*)$)`                 // Extract reported Note URIs from the text of a Misskey report/flag.
@@ -99,6 +100,9 @@ var (
 	// See: https://regex101.com/r/478XGM/1
 	EmojiFinder = regexp.MustCompile(emojiFinder)
 
+	// DoubleSpaceFinder extracts double whitespaces from a piece of text.
+	DoubleSpaceFinder = regexp.MustCompile(doubleSpaceFinder)
+
 	// Username can be used to validate usernames of new signups on this instance.
 	Username = regexp.MustCompile(usernameStrict)
 
