@@ -23,9 +23,9 @@ import (
 	"regexp"
 	"strings"
 
+	"code.superseriousbusiness.org/gopkg/log"
 	"code.superseriousbusiness.org/gotosocial/internal/gtsmodel"
 	"code.superseriousbusiness.org/gotosocial/internal/id"
-	"code.superseriousbusiness.org/gotosocial/internal/log"
 	"code.superseriousbusiness.org/gotosocial/internal/regexes"
 	"codeberg.org/gruf/go-byteutil"
 	"github.com/yuin/goldmark"
