@@ -18,43 +18,54 @@
 package transport
 
 import (
+	"bytes"
 	"context"
 	"io"
 	"net/http"
 	"net/url"
 
 	"code.superseriousbusiness.org/gotosocial/internal/gtserror"
-	"codeberg.org/gruf/go-bytesize"
 	"codeberg.org/gruf/go-iotools"
 )
 
 func (t *transport) DereferenceMedia(ctx context.Context, iri *url.URL, maxsz int64) (io.ReadCloser, error) {
-	// Build IRI just once
+	if maxsz <= 0 {
+		// Max size is zero, just return.
+		return emptyLimitedReader(), nil
+	}
+
+	// Build IRI just once.
 	iriStr := iri.String()
 
-	// Prepare HTTP request to this media's IRI
-	req, err := http.NewRequestWithContext(ctx, "GET", iriStr, nil)
+	// Prepare HTTP request to this media's IRI.
+	req, err := http.NewRequestWithContext(ctx,
+		"GET",
+		iriStr,
+		nil,
+	)
 	if err != nil {
 		return nil, err
 	}
-	req.Header.Add("Accept", "*/*") // we don't know what kind of media we're going to get here
 
-	// Perform the HTTP request
+	// We don't know what kind of
+	// media we're going to get here.
+	req.Header.Add("Accept", "*/*")
+
+	// Perform the HTTP request.
 	rsp, err := t.GET(req)
 	if err != nil {
 		return nil, err
 	}
 
-	// Check for an expected status code
+	// Check for an expected status code.
 	if rsp.StatusCode != http.StatusOK {
 		return nil, gtserror.NewFromResponse(rsp)
 	}
 
 	// Check media within size limit.
 	if rsp.ContentLength > maxsz {
-		_ = rsp.Body.Close()       // close early.
-		sz := bytesize.Size(maxsz) //nolint:gosec
-		return nil, gtserror.Newf("media body exceeds max size %s", sz)
+		_ = rsp.Body.Close() // close early.
+		return emptyLimitedReader(), nil
 	}
 
 	// Update response body with maximum supported media size.
@@ -62,3 +73,19 @@ func (t *transport) DereferenceMedia(ctx context.Context, iri *url.URL, maxsz in
 
 	return rsp.Body, nil
 }
+
+var newline = []byte{'\n'}
+
+func noop() error { return nil }
+
+// emptyLimitReader returns an io.ReadCloser that itself
+// is wrapped in a limited reader with zero length left
+// in the read. Ensuring media error details passed along.
+func emptyLimitedReader() io.ReadCloser {
+	r := (io.Reader)(bytes.NewReader(newline[:])) //nolint
+	r = &io.LimitedReader{R: r, N: 0}
+	return &iotools.ReadCloserType{
+		Reader: r,
+		Closer: iotools.CloserFunc(noop),
+	}
+}
