@@ -24,12 +24,12 @@ import (
 	"net/url"
 	"time"
 
+	"code.superseriousbusiness.org/gopkg/log"
 	"code.superseriousbusiness.org/gotosocial/internal/ap"
 	"code.superseriousbusiness.org/gotosocial/internal/config"
 	"code.superseriousbusiness.org/gotosocial/internal/db"
 	"code.superseriousbusiness.org/gotosocial/internal/gtserror"
 	"code.superseriousbusiness.org/gotosocial/internal/gtsmodel"
-	"code.superseriousbusiness.org/gotosocial/internal/log"
 	"code.superseriousbusiness.org/gotosocial/internal/uris"
 	"code.superseriousbusiness.org/gotosocial/internal/util"
 	"github.com/miekg/dns"
@@ -162,6 +162,10 @@ func (c *Converter) ASRepresentationToAccount(
 	discoverable := ap.GetDiscoverable(accountable)
 	acct.Discoverable = &discoverable
 
+	// Extract account indexability (default = false).
+	indexable := ap.GetIndexable(accountable)
+	acct.Indexable = &indexable
+
 	// Extract the URL property.
 	urls := ap.GetURL(accountable)
 	if len(urls) == 0 {
