@@ -22,22 +22,19 @@ import (
 	"errors"
 	"net/url"
 
+	"code.superseriousbusiness.org/gopkg/log"
 	"code.superseriousbusiness.org/gotosocial/internal/config"
 	"code.superseriousbusiness.org/gotosocial/internal/db"
 	"code.superseriousbusiness.org/gotosocial/internal/gtserror"
 	"code.superseriousbusiness.org/gotosocial/internal/gtsmodel"
 	"code.superseriousbusiness.org/gotosocial/internal/id"
-	"code.superseriousbusiness.org/gotosocial/internal/log"
 	"code.superseriousbusiness.org/gotosocial/internal/uris"
 	"code.superseriousbusiness.org/gotosocial/internal/util"
 )
 
 // FollowRequestToFollow just converts a follow request
 // into a follow, that's it! No bells and whistles.
-func (c *Converter) FollowRequestToFollow(
-	ctx context.Context,
-	fr *gtsmodel.FollowRequest,
-) *gtsmodel.Follow {
+func FollowRequestToFollow(fr *gtsmodel.FollowRequest) *gtsmodel.Follow {
 	return &gtsmodel.Follow{
 		ID:              fr.ID,
 		CreatedAt:       fr.CreatedAt,
@@ -104,75 +101,6 @@ func (c *Converter) StatusToBoost(
 	return boost, nil
 }
 
-func StatusToImpoliteInteractionRequest(status *gtsmodel.Status) *gtsmodel.InteractionRequest {
-	reqID := id.NewULIDFromTime(status.CreatedAt)
-
-	var (
-		targetID              string
-		target                *gtsmodel.Status
-		targetAccountID       string
-		targetAccount         *gtsmodel.Account
-		interactionRequestURI string
-		interactionType       gtsmodel.InteractionType
-		reply                 *gtsmodel.Status
-		announce              *gtsmodel.Status
-	)
-
-	if status.InReplyToID != "" {
-		// It's a reply.
-		targetID = status.InReplyToID
-		target = status.InReplyTo
-		targetAccountID = status.InReplyToAccountID
-		targetAccount = status.InReplyToAccount
-		interactionRequestURI = gtsmodel.ForwardCompatibleInteractionRequestURI(status.URI, gtsmodel.ReplyRequestSuffix)
-		interactionType = gtsmodel.InteractionReply
-		reply = status
-	} else {
-		// It's a boost.
-		targetID = status.BoostOfID
-		target = status.BoostOf
-		targetAccountID = status.BoostOfAccountID
-		targetAccount = status.BoostOfAccount
-		interactionRequestURI = gtsmodel.ForwardCompatibleInteractionRequestURI(status.URI, gtsmodel.AnnounceRequestSuffix)
-		interactionType = gtsmodel.InteractionAnnounce
-		announce = status
-	}
-
-	return &gtsmodel.InteractionRequest{
-		ID:                    reqID,
-		TargetStatusID:        targetID,
-		TargetStatus:          target,
-		TargetAccountID:       targetAccountID,
-		TargetAccount:         targetAccount,
-		InteractingAccountID:  status.AccountID,
-		InteractingAccount:    status.Account,
-		InteractionRequestURI: interactionRequestURI,
-		InteractionURI:        status.URI,
-		InteractionType:       interactionType,
-		Polite:                util.Ptr(false),
-		Reply:                 reply,
-		Announce:              announce,
-	}
-}
-
-func StatusFaveToImpoliteInteractionRequest(fave *gtsmodel.StatusFave) *gtsmodel.InteractionRequest {
-	reqID := id.NewULIDFromTime(fave.CreatedAt)
-	return &gtsmodel.InteractionRequest{
-		ID:                    reqID,
-		TargetStatusID:        fave.StatusID,
-		TargetStatus:          fave.Status,
-		TargetAccountID:       fave.TargetAccountID,
-		TargetAccount:         fave.TargetAccount,
-		InteractingAccountID:  fave.AccountID,
-		InteractingAccount:    fave.Account,
-		InteractionRequestURI: gtsmodel.ForwardCompatibleInteractionRequestURI(fave.URI, gtsmodel.LikeRequestSuffix),
-		InteractionURI:        fave.URI,
-		InteractionType:       gtsmodel.InteractionLike,
-		Polite:                util.Ptr(false),
-		Like:                  fave,
-	}
-}
-
 func (c *Converter) StatusToSinBinStatus(
 	ctx context.Context,
 	status *gtsmodel.Status,
