@@ -30,15 +30,15 @@ import (
 	"code.superseriousbusiness.org/activity/pub"
 	"code.superseriousbusiness.org/activity/streams"
 	"code.superseriousbusiness.org/activity/streams/vocab"
+	"code.superseriousbusiness.org/gopkg/log"
+	"code.superseriousbusiness.org/gopkg/xslices"
 	"code.superseriousbusiness.org/gotosocial/internal/ap"
 	"code.superseriousbusiness.org/gotosocial/internal/config"
 	"code.superseriousbusiness.org/gotosocial/internal/db"
 	"code.superseriousbusiness.org/gotosocial/internal/gtscontext"
 	"code.superseriousbusiness.org/gotosocial/internal/gtserror"
 	"code.superseriousbusiness.org/gotosocial/internal/gtsmodel"
-	"code.superseriousbusiness.org/gotosocial/internal/log"
 	"code.superseriousbusiness.org/gotosocial/internal/uris"
-	"code.superseriousbusiness.org/gotosocial/internal/util/xslices"
 )
 
 func accountableForActorType(actorType gtsmodel.AccountActorType) ap.Accountable {
@@ -198,6 +198,12 @@ func (c *Converter) AccountToAS(
 	discoverableProp.Set(*a.Discoverable)
 	accountable.SetTootDiscoverable(discoverableProp)
 
+	// indexable
+	// Account has opted its posts into full-text search features.
+	indexableProp := streams.NewTootIndexableProperty()
+	indexableProp.Set(*a.Indexable)
+	accountable.SetTootIndexable(indexableProp)
+
 	// devices
 	// NOT IMPLEMENTED, probably won't implement
 
@@ -294,7 +300,9 @@ func (c *Converter) AccountToAS(
 	// tag -- hashtags
 	// TODO
 
-	accountable.SetActivityStreamsTag(tagProp)
+	if tagProp.Len() != 0 {
+		accountable.SetActivityStreamsTag(tagProp)
+	}
 
 	// attachment
 	// Used for profile fields.
@@ -516,7 +524,9 @@ func (c *Converter) StatusToAS(ctx context.Context, s *gtsmodel.Status) (ap.Stat
 	}
 
 	// `summary` property.
-	ap.AppendSummary(statusable, s.ContentWarning)
+	if s.ContentWarning != "" {
+		ap.AppendSummary(statusable, s.ContentWarning)
+	}
 
 	// `inReplyTo` property.
 	if s.InReplyToURI != "" {
@@ -580,7 +590,9 @@ func (c *Converter) StatusToAS(ctx context.Context, s *gtsmodel.Status) (ap.Stat
 	}
 
 	// Append built `tag` property.
-	statusable.SetActivityStreamsTag(tagProp)
+	if tagProp.Len() != 0 {
+		statusable.SetActivityStreamsTag(tagProp)
+	}
 
 	// `to` and `cc` properties
 	// depend on visibility of post.
@@ -636,14 +648,16 @@ func (c *Converter) StatusToAS(ctx context.Context, s *gtsmodel.Status) (ap.Stat
 	}
 
 	// `content` and `contentMap` properties.
-	ap.AppendContent(statusable, s.Content)
-	if s.Language != "" {
-		ap.AppendContentMap(
-			statusable,
-			map[string]string{
-				s.Language: s.Content,
-			},
-		)
+	if s.Content != "" {
+		ap.AppendContent(statusable, s.Content)
+		if s.Language != "" {
+			ap.AppendContentMap(
+				statusable,
+				map[string]string{
+					s.Language: s.Content,
+				},
+			)
+		}
 	}
 
 	// `attachment` property.
@@ -660,7 +674,9 @@ func (c *Converter) StatusToAS(ctx context.Context, s *gtsmodel.Status) (ap.Stat
 	ap.SetReplies(statusable, replies)
 
 	// `sensitive` property.
-	ap.AppendSensitive(statusable, *s.Sensitive)
+	if sensitive := *s.Sensitive; sensitive {
+		ap.AppendSensitive(statusable, sensitive)
+	}
 
 	// `interactionPolicy` property.
 	if wip, ok := statusable.(ap.WithInteractionPolicy); ok {
@@ -1087,8 +1103,16 @@ func (c *Converter) attachAttachments(
 	s *gtsmodel.Status,
 	statusable ap.Statusable,
 ) error {
+
+	// Return early if no attachments.
+	aIDsLen := len(s.AttachmentIDs)
+	asLen := len(s.Attachments)
+	if aIDsLen == 0 || asLen == 0 {
+		return nil
+	}
+
 	// Ensure status attachments populated.
-	if len(s.AttachmentIDs) != len(s.Attachments) {
+	if aIDsLen != asLen {
 		var err error
 		s.Attachments, err = c.state.DB.GetAttachmentsByIDs(ctx, s.AttachmentIDs)
 		if err != nil && !errors.Is(err, db.ErrNoEntries) {
@@ -1853,9 +1877,6 @@ func populateValuesForProp[T ap.WithIRI](
 
 // InteractionPolicyToASInteractionPolicy returns a
 // GoToSocial interaction policy suitable for federation.
-//
-// Note: This currently includes deprecated properties `always`
-// and `approvalRequired`. These will be removed in v0.21.0.
 func (c *Converter) InteractionPolicyToASInteractionPolicy(
 	ctx context.Context,
 	interactionPolicy *gtsmodel.InteractionPolicy,
@@ -1893,48 +1914,25 @@ func (c *Converter) InteractionPolicyToASInteractionPolicy(
 		return nil, gtserror.Newf("error setting canLike.automaticApproval: %w", err)
 	}
 
-	// Set canLike.manualApproval
+	// Set canLike.automaticApproval
 	canLike.SetGoToSocialAutomaticApproval(canLikeAutomaticApprovalProp)
 
-	// Build canLike.manualApproval
-	canLikeManualApprovalProp := streams.NewGoToSocialManualApprovalProperty()
-	if err := populateValuesForProp(
-		canLikeManualApprovalProp,
-		status,
-		interactionPolicy.CanLike.ManualApproval,
-	); err != nil {
-		return nil, gtserror.Newf("error setting canLike.manualApproval: %w", err)
+	// Only bother building manualApproval if it has entries.
+	// This avoids serializing empty array for no good reason.
+	if len(interactionPolicy.CanLike.ManualApproval) != 0 {
+		canLikeManualApprovalProp := streams.NewGoToSocialManualApprovalProperty()
+		if err := populateValuesForProp(
+			canLikeManualApprovalProp,
+			status,
+			interactionPolicy.CanLike.ManualApproval,
+		); err != nil {
+			return nil, gtserror.Newf("error setting canLike.manualApproval: %w", err)
+		}
+
+		// Set canLike.manualApproval.
+		canLike.SetGoToSocialManualApproval(canLikeManualApprovalProp)
 	}
 
-	// Set canLike.manualApproval.
-	canLike.SetGoToSocialManualApproval(canLikeManualApprovalProp)
-
-	// deprecated: Build canLike.always
-	canLikeAlwaysProp := streams.NewGoToSocialAlwaysProperty()
-	if err := populateValuesForProp(
-		canLikeAlwaysProp,
-		status,
-		interactionPolicy.CanLike.AutomaticApproval,
-	); err != nil {
-		return nil, gtserror.Newf("error setting canLike.always: %w", err)
-	}
-
-	// deprecated: Set canLike.always
-	canLike.SetGoToSocialAlways(canLikeAlwaysProp)
-
-	// deprecated: Build canLike.approvalRequired
-	canLikeApprovalRequiredProp := streams.NewGoToSocialApprovalRequiredProperty()
-	if err := populateValuesForProp(
-		canLikeApprovalRequiredProp,
-		status,
-		interactionPolicy.CanLike.ManualApproval,
-	); err != nil {
-		return nil, gtserror.Newf("error setting canLike.approvalRequired: %w", err)
-	}
-
-	// deprecated: Set canLike.approvalRequired.
-	canLike.SetGoToSocialApprovalRequired(canLikeApprovalRequiredProp)
-
 	// Set canLike on the policy.
 	canLikeProp := streams.NewGoToSocialCanLikeProperty()
 	canLikeProp.AppendGoToSocialCanLike(canLike)
@@ -1957,48 +1955,25 @@ func (c *Converter) InteractionPolicyToASInteractionPolicy(
 		return nil, gtserror.Newf("error setting canReply.automaticApproval: %w", err)
 	}
 
-	// Set canReply.manualApproval
+	// Set canReply.automaticApproval
 	canReply.SetGoToSocialAutomaticApproval(canReplyAutomaticApprovalProp)
 
-	// Build canReply.manualApproval
-	canReplyManualApprovalProp := streams.NewGoToSocialManualApprovalProperty()
-	if err := populateValuesForProp(
-		canReplyManualApprovalProp,
-		status,
-		interactionPolicy.CanReply.ManualApproval,
-	); err != nil {
-		return nil, gtserror.Newf("error setting canReply.manualApproval: %w", err)
+	// Only bother building manualApproval if it has entries.
+	// This avoids serializing empty array for no good reason.
+	if len(interactionPolicy.CanReply.ManualApproval) != 0 {
+		canReplyManualApprovalProp := streams.NewGoToSocialManualApprovalProperty()
+		if err := populateValuesForProp(
+			canReplyManualApprovalProp,
+			status,
+			interactionPolicy.CanReply.ManualApproval,
+		); err != nil {
+			return nil, gtserror.Newf("error setting canReply.manualApproval: %w", err)
+		}
+
+		// Set canReply.manualApproval.
+		canReply.SetGoToSocialManualApproval(canReplyManualApprovalProp)
 	}
 
-	// Set canReply.manualApproval.
-	canReply.SetGoToSocialManualApproval(canReplyManualApprovalProp)
-
-	// deprecated: Build canReply.always
-	canReplyAlwaysProp := streams.NewGoToSocialAlwaysProperty()
-	if err := populateValuesForProp(
-		canReplyAlwaysProp,
-		status,
-		interactionPolicy.CanReply.AutomaticApproval,
-	); err != nil {
-		return nil, gtserror.Newf("error setting canReply.always: %w", err)
-	}
-
-	// deprecated: Set canReply.always
-	canReply.SetGoToSocialAlways(canReplyAlwaysProp)
-
-	// deprecated: Build canReply.approvalRequired
-	canReplyApprovalRequiredProp := streams.NewGoToSocialApprovalRequiredProperty()
-	if err := populateValuesForProp(
-		canReplyApprovalRequiredProp,
-		status,
-		interactionPolicy.CanReply.ManualApproval,
-	); err != nil {
-		return nil, gtserror.Newf("error setting canReply.approvalRequired: %w", err)
-	}
-
-	// deprecated: Set canReply.approvalRequired.
-	canReply.SetGoToSocialApprovalRequired(canReplyApprovalRequiredProp)
-
 	// Set canReply on the policy.
 	canReplyProp := streams.NewGoToSocialCanReplyProperty()
 	canReplyProp.AppendGoToSocialCanReply(canReply)
@@ -2021,53 +1996,48 @@ func (c *Converter) InteractionPolicyToASInteractionPolicy(
 		return nil, gtserror.Newf("error setting canAnnounce.automaticApproval: %w", err)
 	}
 
-	// Set canAnnounce.manualApproval
+	// Set canAnnounce.automaticApproval
 	canAnnounce.SetGoToSocialAutomaticApproval(canAnnounceAutomaticApprovalProp)
 
-	// Build canAnnounce.manualApproval
-	canAnnounceManualApprovalProp := streams.NewGoToSocialManualApprovalProperty()
-	if err := populateValuesForProp(
-		canAnnounceManualApprovalProp,
-		status,
-		interactionPolicy.CanAnnounce.ManualApproval,
-	); err != nil {
-		return nil, gtserror.Newf("error setting canAnnounce.manualApproval: %w", err)
+	// Only bother building manualApproval if it has entries.
+	// This avoids serializing empty array for no good reason.
+	if len(interactionPolicy.CanAnnounce.ManualApproval) != 0 {
+		canAnnounceManualApprovalProp := streams.NewGoToSocialManualApprovalProperty()
+		if err := populateValuesForProp(
+			canAnnounceManualApprovalProp,
+			status,
+			interactionPolicy.CanAnnounce.ManualApproval,
+		); err != nil {
+			return nil, gtserror.Newf("error setting canAnnounce.manualApproval: %w", err)
+		}
+
+		// Set canAnnounce.manualApproval.
+		canAnnounce.SetGoToSocialManualApproval(canAnnounceManualApprovalProp)
 	}
 
-	// Set canAnnounce.manualApproval.
-	canAnnounce.SetGoToSocialManualApproval(canAnnounceManualApprovalProp)
-
-	// deprecated: Build canAnnounce.always
-	canAnnounceAlwaysProp := streams.NewGoToSocialAlwaysProperty()
-	if err := populateValuesForProp(
-		canAnnounceAlwaysProp,
-		status,
-		interactionPolicy.CanAnnounce.AutomaticApproval,
-	); err != nil {
-		return nil, gtserror.Newf("error setting canAnnounce.always: %w", err)
-	}
-
-	// deprecated: Set canAnnounce.always
-	canAnnounce.SetGoToSocialAlways(canAnnounceAlwaysProp)
-
-	// deprecated: Build canAnnounce.approvalRequired
-	canAnnounceApprovalRequiredProp := streams.NewGoToSocialApprovalRequiredProperty()
-	if err := populateValuesForProp(
-		canAnnounceApprovalRequiredProp,
-		status,
-		interactionPolicy.CanAnnounce.ManualApproval,
-	); err != nil {
-		return nil, gtserror.Newf("error setting canAnnounce.approvalRequired: %w", err)
-	}
-
-	// deprecated: Set canAnnounce.approvalRequired.
-	canAnnounce.SetGoToSocialApprovalRequired(canAnnounceApprovalRequiredProp)
-
 	// Set canAnnounce on the policy.
 	canAnnounceProp := streams.NewGoToSocialCanAnnounceProperty()
 	canAnnounceProp.AppendGoToSocialCanAnnounce(canAnnounce)
 	policy.SetGoToSocialCanAnnounce(canAnnounceProp)
 
+	/*
+		CAN QUOTE
+		todo: GtS doesn't support quote posts yet so
+		just set restrictive quote policy (self only).
+	*/
+
+	canQuote := streams.NewGoToSocialCanQuote()
+	canQuoteAutomaticApprovalProp := streams.NewGoToSocialAutomaticApprovalProperty()
+	authorIRI, err := url.Parse(status.Account.URI)
+	if err != nil {
+		return nil, gtserror.Newf("error setting canQuote.automaticApproval: %w", err)
+	}
+	canQuoteAutomaticApprovalProp.AppendIRI(authorIRI)
+	canQuote.SetGoToSocialAutomaticApproval(canQuoteAutomaticApprovalProp)
+	canQuoteProp := streams.NewGoToSocialCanQuoteProperty()
+	canQuoteProp.AppendGoToSocialCanQuote(canQuote)
+	policy.SetGoToSocialCanQuote(canQuoteProp)
+
 	return policy, nil
 }
 
@@ -2118,6 +2088,16 @@ func (c *Converter) InteractionReqToASAccept(
 	// Accepting the interaction.
 	ap.AppendActorIRIs(accept, actorIRI)
 
+	// If set, also include the "result" URI
+	// of the interaction Authorization object.
+	if req.AuthorizationURI != "" {
+		resultIRI, err := url.Parse(req.AuthorizationURI)
+		if err != nil {
+			return nil, gtserror.Newf("invalid authorization uri: %w", err)
+		}
+		ap.AppendResultIRIs(accept, resultIRI)
+	}
+
 	polite := req.IsPolite()
 	if polite {
 		// If accepting a polite request, put
@@ -2159,23 +2139,10 @@ func (c *Converter) InteractionReqToASAccept(
 		// Set the thing.
 		accept.SetActivityStreamsObject(objProp)
 
-		// If polite, also include the "result" URI
-		// of the interaction Authorization object.
-		resultIRI, err := url.Parse(req.AuthorizationURI)
-		if err != nil {
-			return nil, gtserror.Newf("invalid authorization uri: %w", err)
-		}
-		ap.AppendResultIRIs(accept, resultIRI)
-
 	} else {
-		// If accepting an impolite request, just set
-		// interaction URI as object and target status
-		// IRI as target. Don't give authorization in
-		// result field, as this will confuse pre v0.20.0
-		// instances who don't understand Auth types yet.
-		//
-		// TODO: remove this path in v0.21.0 and send an
-		// accept of a Request for impolite requests too.
+		// If accepting an impolite request,
+		// just set interaction URI as object
+		// and target status IRI as target.
 		ap.AppendObjectIRIs(accept, objectIRI)
 		ap.AppendTargetIRIs(accept, targetIRI)
 	}
@@ -2317,12 +2284,9 @@ func (c *Converter) InteractionReqToASReject(
 		reject.SetActivityStreamsObject(objProp)
 
 	} else {
-		// If rejecting an impolite request, just set
-		// interaction URI as object and target status
-		// IRI as target.
-		//
-		// TODO: remove this path in v0.21.0 and send a
-		// Reject of a Request for impolite requests too.
+		// If rejecting an impolite request,
+		// just set interaction URI as object
+		// and target status IRI as target.
 		ap.AppendObjectIRIs(reject, objectIRI)
 		ap.AppendTargetIRIs(reject, targetIRI)
 	}
@@ -2442,7 +2406,7 @@ func (c *Converter) InteractionReqToASAuthorization(
 }
 
 // appendASInteractionAuthorization is a utility function
-// that sets `approvedBy`, and (if possible) `likeAuthorization`,
+// that sets `approvedBy`, or (if possible) `likeAuthorization`,
 // `replyAuthorization`, and/or `announceAuthorization`.
 func (c *Converter) appendASInteractionAuthorization(
 	ctx context.Context,
@@ -2491,18 +2455,6 @@ func (c *Converter) appendASInteractionAuthorization(
 		)
 	}
 
-	// Deprecated: Set `approvedBy`
-	// property to URI of the Accept.
-	//
-	// Todo: Remove this in v0.21.0.
-	if wap, ok := t.(ap.WithApprovedBy); ok {
-		responseURI, err := url.Parse(intReq.ResponseURI)
-		if err != nil {
-			return gtserror.Newf("error parsing responseURI: %w", err)
-		}
-		ap.SetApprovedBy(wap, responseURI)
-	}
-
 	// Set the appropriate authorization
 	// property depending on type.
 	switch intReq.InteractionType {
@@ -2522,3 +2474,108 @@ func (c *Converter) appendASInteractionAuthorization(
 
 	return nil
 }
+
+// InteractionReqToASInteractionRequestable converts the given
+// interaction request to either a LikeRequest, ReplyRequest,
+// or AnnounceRequest, with appropriate instrument and addressing.
+//
+// Result will look something like:
+//
+//	{
+//	  "@context": [... blah blah blah ...],
+//	  "actor": "http://fossbros-anonymous.io/users/foss_satan",
+//	  "id": "https://fossbros-anonymous.io/users/foss_satan/interaction_requests/01J1AKRRHQ6MDDQHV0TP716T2K",
+//	  "instrument": { [... the note that foss_satan is replying with ...] },
+//	  "object": "http://localhost:8080/users/the_mighty_zork/statuses/01JJYCVKCXB9JTQD1XW2KB8MT3",
+//	  "to": "http://localhost:8080/users/the_mighty_zork",
+//	  "type": "ReplyRequest"
+//	}
+func (c *Converter) InteractionReqToASInteractionRequestable(
+	ctx context.Context,
+	req *gtsmodel.InteractionRequest,
+) (ap.InteractionRequestable, error) {
+
+	// Actor of the interaction aka the interacting account.
+	actorIRI, err := url.Parse(req.InteractingAccount.URI)
+	if err != nil {
+		return nil, gtserror.Newf("invalid account uri: %w", err)
+	}
+
+	// Object of the interaction aka the target status.
+	objectIRI, err := url.Parse(req.TargetStatus.URI)
+	if err != nil {
+		return nil, gtserror.Newf("invalid object uri: %w", err)
+	}
+
+	// Account targeted by the interaction.
+	toIRI, err := url.Parse(req.TargetAccount.URI)
+	if err != nil {
+		return nil, gtserror.Newf("invalid to uri: %w", err)
+	}
+
+	// Exact type of InteractionRequestable varies
+	// depending on whether this is a LikeRequest,
+	// ReplyRequest, or AnnounceRequest.
+	var (
+		v              ap.InteractionRequestable
+		instrumentProp = streams.NewActivityStreamsInstrumentProperty()
+	)
+	switch req.InteractionType {
+
+	// LikeRequest
+	case gtsmodel.InteractionLike:
+		v = streams.NewGoToSocialLikeRequest()
+		like, err := c.FaveToAS(ctx, req.Like)
+		if err != nil {
+			return nil, gtserror.Newf("error converting like: %w", err)
+		}
+		instrumentProp.AppendActivityStreamsLike(like)
+
+	// ReplyRequest
+	case gtsmodel.InteractionReply:
+		v = streams.NewGoToSocialReplyRequest()
+		statusable, err := c.StatusToAS(ctx, req.Reply)
+		if err != nil {
+			return nil, gtserror.Newf("error converting reply: %w", err)
+		}
+
+		// If normal status, append as note.
+		// If a poll, append as question.
+		switch t := statusable.(type) {
+		case vocab.ActivityStreamsNote:
+			instrumentProp.AppendActivityStreamsNote(t)
+		case vocab.ActivityStreamsQuestion:
+			instrumentProp.AppendActivityStreamsQuestion(t)
+		default:
+			return nil, gtserror.Newf("type %T not supported as instrument of ReplyRequest", t)
+		}
+
+	// AnnounceRequest
+	case gtsmodel.InteractionAnnounce:
+		v = streams.NewGoToSocialAnnounceRequest()
+		announce, err := c.BoostToAS(ctx, req.Announce)
+		if err != nil {
+			return nil, gtserror.Newf("error converting announce: %w", err)
+		}
+		instrumentProp.AppendActivityStreamsAnnounce(announce)
+	}
+
+	// Set ID.
+	if err := ap.SetJSONLDIdStr(v, req.InteractionRequestURI); err != nil {
+		return nil, gtserror.Newf("error setting id: %w", err)
+	}
+
+	// Set actor IRI.
+	ap.AppendActorIRIs(v, actorIRI)
+
+	// Set object IRI.
+	ap.AppendObjectIRIs(v, objectIRI)
+
+	// Set to IRI.
+	ap.AppendTo(v, toIRI)
+
+	// Set instrument.
+	v.SetActivityStreamsInstrument(instrumentProp)
+
+	return v, nil
+}
