@@ -20,9 +20,9 @@ package typeutils
 import (
 	"code.superseriousbusiness.org/activity/streams"
 	"code.superseriousbusiness.org/activity/streams/vocab"
+	"code.superseriousbusiness.org/gopkg/log"
 	"code.superseriousbusiness.org/gotosocial/internal/ap"
 	"code.superseriousbusiness.org/gotosocial/internal/id"
-	"code.superseriousbusiness.org/gotosocial/internal/log"
 	"code.superseriousbusiness.org/gotosocial/internal/uris"
 )
 
@@ -43,12 +43,14 @@ func (c *Converter) WrapAccountableInUpdate(accountable ap.Accountable) (vocab.A
 	// Set the accountable as the object of the update.
 	objectProp := streams.NewActivityStreamsObjectProperty()
 	switch t := accountable.(type) {
+	case vocab.ActivityStreamsApplication:
+		objectProp.AppendActivityStreamsApplication(t)
 	case vocab.ActivityStreamsPerson:
 		objectProp.AppendActivityStreamsPerson(t)
 	case vocab.ActivityStreamsService:
 		objectProp.AppendActivityStreamsService(t)
 	default:
-		log.Panicf(nil, "%T was neither person nor service", t)
+		log.Panicf(nil, "%T was neither Application, Person, nor Service", t)
 	}
 	update.SetActivityStreamsObject(objectProp)
 
