@@ -410,6 +410,10 @@ func CreateAccount(form *apimodel.AccountCreateRequest) error {
 		return errors.New("registration is not open for this server")
 	}
 
+	if config.GetOIDCEnabled() {
+		return errors.New("oidc is enabled for this instance, new sign ups must go through the OIDC provider")
+	}
+
 	if err := Username(form.Username); err != nil {
 		return err
 	}
@@ -426,11 +430,15 @@ func CreateAccount(form *apimodel.AccountCreateRequest) error {
 		return errors.New("agreement to terms and conditions not given")
 	}
 
-	locale, err := Language(form.Locale)
-	if err != nil {
-		return err
+	// Validate + normalize
+	// locale if provided.
+	if form.Locale != "" {
+		locale, err := Language(form.Locale)
+		if err != nil {
+			return err
+		}
+		form.Locale = locale
 	}
-	form.Locale = locale
 
 	return SignUpReason(form.Reason, config.GetAccountsReasonRequired())
 }
