@@ -19,12 +19,11 @@ package web
 
 import (
 	"net/http"
-	"strings"
 	"time"
 
+	"code.superseriousbusiness.org/gopkg/log"
 	apiutil "code.superseriousbusiness.org/gotosocial/internal/api/util"
 	"code.superseriousbusiness.org/gotosocial/internal/gtserror"
-	"code.superseriousbusiness.org/gotosocial/internal/log"
 	"code.superseriousbusiness.org/gotosocial/internal/paging"
 	"github.com/gin-gonic/gin"
 	"github.com/gorilla/feeds"
@@ -56,11 +55,6 @@ func (m *Module) rssFeedGETHandler(c *gin.Context) {
 		return
 	}
 
-	// Usernames on our instance will always be lowercase.
-	//
-	// todo: https://codeberg.org/superseriousbusiness/gotosocial/issues/1813
-	username = strings.ToLower(username)
-
 	// Parse paging parameters from request.
 	page, errWithCode := paging.ParseIDPage(c,
 		1,  // min limit
