@@ -40,8 +40,8 @@ func (m *Module) SettingsPanelHandler(c *gin.Context) {
 	}
 
 	// We only serve text/html at this endpoint.
-	if _, err := apiutil.NegotiateAccept(c, apiutil.TextHTML); err != nil {
-		apiutil.WebErrorHandler(c, gtserror.NewErrorNotAcceptable(err, err.Error()), instanceGet)
+	if _, errWithCode := apiutil.NegotiateAccept(c, apiutil.TextHTML); errWithCode != nil {
+		apiutil.WebErrorHandler(c, errWithCode, instanceGet)
 		return
 	}
 
