@@ -22,12 +22,12 @@ import (
 )
 
 type QueryHook struct {
-	attrs             []attribute.KeyValue
-	formatQueries     bool
-	tracer            trace.Tracer
-	meter             metric.Meter
-	queryHistogram    metric.Int64Histogram
-	spanNameFormatter func(*bun.QueryEvent) string
+	attrs            []attribute.KeyValue
+	formatQueries    bool
+	tracer           trace.Tracer
+	meter            metric.Meter
+	queryHistogram   metric.Int64Histogram
+	spanNameQueryGen func(*bun.QueryEvent) string
 }
 
 var _ bun.QueryHook = (*QueryHook)(nil)
@@ -88,8 +88,8 @@ func (h *QueryHook) AfterQuery(ctx context.Context, event *bun.QueryEvent) {
 	}
 
 	name := operation
-	if h.spanNameFormatter != nil {
-		name = h.spanNameFormatter(event)
+	if h.spanNameQueryGen != nil {
+		name = h.spanNameQueryGen(event)
 	}
 	span.SetName(name)
 	defer span.End()
@@ -173,7 +173,7 @@ func (h *QueryHook) eventQuery(event *bun.QueryEvent) string {
 
 func unformattedQuery(event *bun.QueryEvent) string {
 	if event.IQuery != nil {
-		if b, err := event.IQuery.AppendQuery(schema.NewNopFormatter(), nil); err == nil {
+		if b, err := event.IQuery.AppendQuery(schema.NewNopQueryGen(), nil); err == nil {
 			return internal.String(b)
 		}
 	}
