@@ -7,7 +7,7 @@ import (
 )
 
 type Logging interface {
-	Printf(format string, v ...interface{})
+	Printf(format string, v ...any)
 }
 
 var defaultLogger = log.New(os.Stderr, "", log.LstdFlags)
@@ -30,7 +30,7 @@ type logger struct {
 	log *log.Logger
 }
 
-func (l *logger) Printf(format string, v ...interface{}) {
+func (l *logger) Printf(format string, v ...any) {
 	_ = l.log.Output(2, fmt.Sprintf(format, v...))
 }
 
@@ -39,7 +39,7 @@ type wrapper struct {
 	logger Logging
 }
 
-func (w *wrapper) Printf(format string, v ...interface{}) {
+func (w *wrapper) Printf(format string, v ...any) {
 	w.logger.Printf(w.prefix+format, v...)
 }
 
