@@ -37,7 +37,7 @@ func (q *DeleteQuery) Conn(db IConn) *DeleteQuery {
 	return q
 }
 
-func (q *DeleteQuery) Model(model interface{}) *DeleteQuery {
+func (q *DeleteQuery) Model(model any) *DeleteQuery {
 	q.setModel(model)
 	return q
 }
@@ -58,12 +58,17 @@ func (q *DeleteQuery) Apply(fns ...func(*DeleteQuery) *DeleteQuery) *DeleteQuery
 }
 
 func (q *DeleteQuery) With(name string, query Query) *DeleteQuery {
-	q.addWith(name, query, false)
+	q.addWith(NewWithQuery(name, query))
 	return q
 }
 
 func (q *DeleteQuery) WithRecursive(name string, query Query) *DeleteQuery {
-	q.addWith(name, query, true)
+	q.addWith(NewWithQuery(name, query).Recursive())
+	return q
+}
+
+func (q *DeleteQuery) WithQuery(query *WithQuery) *DeleteQuery {
+	q.addWith(query)
 	return q
 }
 
@@ -74,12 +79,12 @@ func (q *DeleteQuery) Table(tables ...string) *DeleteQuery {
 	return q
 }
 
-func (q *DeleteQuery) TableExpr(query string, args ...interface{}) *DeleteQuery {
+func (q *DeleteQuery) TableExpr(query string, args ...any) *DeleteQuery {
 	q.addTable(schema.SafeQuery(query, args))
 	return q
 }
 
-func (q *DeleteQuery) ModelTableExpr(query string, args ...interface{}) *DeleteQuery {
+func (q *DeleteQuery) ModelTableExpr(query string, args ...any) *DeleteQuery {
 	q.modelTableName = schema.SafeQuery(query, args)
 	return q
 }
@@ -91,12 +96,12 @@ func (q *DeleteQuery) WherePK(cols ...string) *DeleteQuery {
 	return q
 }
 
-func (q *DeleteQuery) Where(query string, args ...interface{}) *DeleteQuery {
+func (q *DeleteQuery) Where(query string, args ...any) *DeleteQuery {
 	q.addWhere(schema.SafeQueryWithSep(query, args, " AND "))
 	return q
 }
 
-func (q *DeleteQuery) WhereOr(query string, args ...interface{}) *DeleteQuery {
+func (q *DeleteQuery) WhereOr(query string, args ...any) *DeleteQuery {
 	q.addWhere(schema.SafeQueryWithSep(query, args, " OR "))
 	return q
 }
@@ -134,7 +139,7 @@ func (q *DeleteQuery) Order(orders ...string) *DeleteQuery {
 	return q
 }
 
-func (q *DeleteQuery) OrderExpr(query string, args ...interface{}) *DeleteQuery {
+func (q *DeleteQuery) OrderExpr(query string, args ...any) *DeleteQuery {
 	if !q.hasFeature(feature.DeleteOrderLimit) {
 		q.setErr(feature.NewNotSupportError(feature.DeleteOrderLimit))
 		return q
@@ -163,7 +168,7 @@ func (q *DeleteQuery) Limit(n int) *DeleteQuery {
 // Returning adds a RETURNING clause to the query.
 //
 // To suppress the auto-generated RETURNING clause, use `Returning("NULL")`.
-func (q *DeleteQuery) Returning(query string, args ...interface{}) *DeleteQuery {
+func (q *DeleteQuery) Returning(query string, args ...any) *DeleteQuery {
 	if !q.hasFeature(feature.DeleteReturning) {
 		q.setErr(feature.NewNotSupportError(feature.DeleteOrderLimit))
 		return q
@@ -187,14 +192,14 @@ func (q *DeleteQuery) Operation() string {
 	return "DELETE"
 }
 
-func (q *DeleteQuery) AppendQuery(fmter schema.Formatter, b []byte) (_ []byte, err error) {
+func (q *DeleteQuery) AppendQuery(gen schema.QueryGen, b []byte) (_ []byte, err error) {
 	if q.err != nil {
 		return nil, q.err
 	}
 
 	b = appendComment(b, q.comment)
 
-	fmter = formatterWithModel(fmter, q)
+	gen = formatterWithModel(gen, q)
 
 	if q.isSoftDelete() {
 		now := time.Now()
@@ -207,14 +212,14 @@ func (q *DeleteQuery) AppendQuery(fmter schema.Formatter, b []byte) (_ []byte, e
 			whereBaseQuery: q.whereBaseQuery,
 			returningQuery: q.returningQuery,
 		}
-		upd.Set(q.softDeleteSet(fmter, now))
+		upd.Set(q.softDeleteSet(gen, now))
 
-		return upd.AppendQuery(fmter, b)
+		return upd.AppendQuery(gen, b)
 	}
 
 	withAlias := q.db.HasFeature(feature.DeleteTableAlias)
 
-	b, err = q.appendWith(fmter, b)
+	b, err = q.appendWith(gen, b)
 	if err != nil {
 		return nil, err
 	}
@@ -222,9 +227,9 @@ func (q *DeleteQuery) AppendQuery(fmter schema.Formatter, b []byte) (_ []byte, e
 	b = append(b, "DELETE FROM "...)
 
 	if withAlias {
-		b, err = q.appendFirstTableWithAlias(fmter, b)
+		b, err = q.appendFirstTableWithAlias(gen, b)
 	} else {
-		b, err = q.appendFirstTable(fmter, b)
+		b, err = q.appendFirstTable(gen, b)
 	}
 	if err != nil {
 		return nil, err
@@ -232,7 +237,7 @@ func (q *DeleteQuery) AppendQuery(fmter schema.Formatter, b []byte) (_ []byte, e
 
 	if q.hasMultiTables() {
 		b = append(b, " USING "...)
-		b, err = q.appendOtherTables(fmter, b)
+		b, err = q.appendOtherTables(gen, b)
 		if err != nil {
 			return nil, err
 		}
@@ -240,13 +245,13 @@ func (q *DeleteQuery) AppendQuery(fmter schema.Formatter, b []byte) (_ []byte, e
 
 	if q.hasFeature(feature.Output) && q.hasReturning() {
 		b = append(b, " OUTPUT "...)
-		b, err = q.appendOutput(fmter, b)
+		b, err = q.appendOutput(gen, b)
 		if err != nil {
 			return nil, err
 		}
 	}
 
-	b, err = q.mustAppendWhere(fmter, b, withAlias)
+	b, err = q.mustAppendWhere(gen, b, withAlias)
 	if err != nil {
 		return nil, err
 	}
@@ -255,19 +260,19 @@ func (q *DeleteQuery) AppendQuery(fmter schema.Formatter, b []byte) (_ []byte, e
 		return nil, errors.New("bun: can't use ORDER or LIMIT with multiple tables")
 	}
 
-	b, err = q.appendOrder(fmter, b)
+	b, err = q.appendOrder(gen, b)
 	if err != nil {
 		return nil, err
 	}
 
-	b, err = q.appendLimitOffset(fmter, b)
+	b, err = q.appendLimitOffset(gen, b)
 	if err != nil {
 		return nil, err
 	}
 
 	if q.hasFeature(feature.DeleteReturning) && q.hasReturning() {
 		b = append(b, " RETURNING "...)
-		b, err = q.appendReturning(fmter, b)
+		b, err = q.appendReturning(gen, b)
 		if err != nil {
 			return nil, err
 		}
@@ -280,31 +285,31 @@ func (q *DeleteQuery) isSoftDelete() bool {
 	return q.tableModel != nil && q.table.SoftDeleteField != nil && !q.flags.Has(forceDeleteFlag)
 }
 
-func (q *DeleteQuery) softDeleteSet(fmter schema.Formatter, tm time.Time) string {
+func (q *DeleteQuery) softDeleteSet(gen schema.QueryGen, tm time.Time) string {
 	b := make([]byte, 0, 32)
-	if fmter.HasFeature(feature.UpdateMultiTable) {
+	if gen.HasFeature(feature.UpdateMultiTable) {
 		b = append(b, q.table.SQLAlias...)
 		b = append(b, '.')
 	}
 	b = append(b, q.table.SoftDeleteField.SQLName...)
 	b = append(b, " = "...)
-	b = schema.Append(fmter, b, tm)
+	b = gen.Append(b, tm)
 	return internal.String(b)
 }
 
 //------------------------------------------------------------------------------
 
-func (q *DeleteQuery) Scan(ctx context.Context, dest ...interface{}) error {
+func (q *DeleteQuery) Scan(ctx context.Context, dest ...any) error {
 	_, err := q.scanOrExec(ctx, dest, true)
 	return err
 }
 
-func (q *DeleteQuery) Exec(ctx context.Context, dest ...interface{}) (sql.Result, error) {
+func (q *DeleteQuery) Exec(ctx context.Context, dest ...any) (sql.Result, error) {
 	return q.scanOrExec(ctx, dest, len(dest) > 0)
 }
 
 func (q *DeleteQuery) scanOrExec(
-	ctx context.Context, dest []interface{}, hasDest bool,
+	ctx context.Context, dest []any, hasDest bool,
 ) (sql.Result, error) {
 	if q.err != nil {
 		return nil, q.err
@@ -325,7 +330,7 @@ func (q *DeleteQuery) scanOrExec(
 	setCommentFromContext(ctx, q)
 
 	// Generate the query before checking hasReturning.
-	queryBytes, err := q.AppendQuery(q.db.fmter, q.db.makeQueryBytes())
+	queryBytes, err := q.AppendQuery(q.db.gen, q.db.makeQueryBytes())
 	if err != nil {
 		return nil, err
 	}
@@ -387,7 +392,7 @@ func (q *DeleteQuery) afterDeleteHook(ctx context.Context) error {
 // String returns the generated SQL query string. The DeleteQuery instance must not be
 // modified during query generation to ensure multiple calls to String() return identical results.
 func (q *DeleteQuery) String() string {
-	buf, err := q.AppendQuery(q.db.Formatter(), nil)
+	buf, err := q.AppendQuery(q.db.QueryGen(), nil)
 	if err != nil {
 		panic(err)
 	}
@@ -417,12 +422,12 @@ func (q *deleteQueryBuilder) WhereGroup(
 	return q
 }
 
-func (q *deleteQueryBuilder) Where(query string, args ...interface{}) QueryBuilder {
+func (q *deleteQueryBuilder) Where(query string, args ...any) QueryBuilder {
 	q.DeleteQuery.Where(query, args...)
 	return q
 }
 
-func (q *deleteQueryBuilder) WhereOr(query string, args ...interface{}) QueryBuilder {
+func (q *deleteQueryBuilder) WhereOr(query string, args ...any) QueryBuilder {
 	q.DeleteQuery.WhereOr(query, args...)
 	return q
 }
@@ -442,6 +447,6 @@ func (q *deleteQueryBuilder) WherePK(cols ...string) QueryBuilder {
 	return q
 }
 
-func (q *deleteQueryBuilder) Unwrap() interface{} {
+func (q *deleteQueryBuilder) Unwrap() any {
 	return q.DeleteQuery
 }
