@@ -52,7 +52,7 @@ func (q *SelectQuery) Conn(db IConn) *SelectQuery {
 	return q
 }
 
-func (q *SelectQuery) Model(model interface{}) *SelectQuery {
+func (q *SelectQuery) Model(model any) *SelectQuery {
 	q.setModel(model)
 	return q
 }
@@ -73,12 +73,17 @@ func (q *SelectQuery) Apply(fns ...func(*SelectQuery) *SelectQuery) *SelectQuery
 }
 
 func (q *SelectQuery) With(name string, query Query) *SelectQuery {
-	q.addWith(name, query, false)
+	q.addWith(NewWithQuery(name, query))
 	return q
 }
 
 func (q *SelectQuery) WithRecursive(name string, query Query) *SelectQuery {
-	q.addWith(name, query, true)
+	q.addWith(NewWithQuery(name, query).Recursive())
+	return q
+}
+
+func (q *SelectQuery) WithQuery(query *WithQuery) *SelectQuery {
+	q.addWith(query)
 	return q
 }
 
@@ -87,7 +92,7 @@ func (q *SelectQuery) Distinct() *SelectQuery {
 	return q
 }
 
-func (q *SelectQuery) DistinctOn(query string, args ...interface{}) *SelectQuery {
+func (q *SelectQuery) DistinctOn(query string, args ...any) *SelectQuery {
 	q.distinctOn = append(q.distinctOn, schema.SafeQuery(query, args))
 	return q
 }
@@ -101,12 +106,12 @@ func (q *SelectQuery) Table(tables ...string) *SelectQuery {
 	return q
 }
 
-func (q *SelectQuery) TableExpr(query string, args ...interface{}) *SelectQuery {
+func (q *SelectQuery) TableExpr(query string, args ...any) *SelectQuery {
 	q.addTable(schema.SafeQuery(query, args))
 	return q
 }
 
-func (q *SelectQuery) ModelTableExpr(query string, args ...interface{}) *SelectQuery {
+func (q *SelectQuery) ModelTableExpr(query string, args ...any) *SelectQuery {
 	q.modelTableName = schema.SafeQuery(query, args)
 	return q
 }
@@ -120,7 +125,7 @@ func (q *SelectQuery) Column(columns ...string) *SelectQuery {
 	return q
 }
 
-func (q *SelectQuery) ColumnExpr(query string, args ...interface{}) *SelectQuery {
+func (q *SelectQuery) ColumnExpr(query string, args ...any) *SelectQuery {
 	q.addColumn(schema.SafeQuery(query, args))
 	return q
 }
@@ -137,12 +142,12 @@ func (q *SelectQuery) WherePK(cols ...string) *SelectQuery {
 	return q
 }
 
-func (q *SelectQuery) Where(query string, args ...interface{}) *SelectQuery {
+func (q *SelectQuery) Where(query string, args ...any) *SelectQuery {
 	q.addWhere(schema.SafeQueryWithSep(query, args, " AND "))
 	return q
 }
 
-func (q *SelectQuery) WhereOr(query string, args ...interface{}) *SelectQuery {
+func (q *SelectQuery) WhereOr(query string, args ...any) *SelectQuery {
 	q.addWhere(schema.SafeQueryWithSep(query, args, " OR "))
 	return q
 }
@@ -266,12 +271,12 @@ func (q *SelectQuery) Group(columns ...string) *SelectQuery {
 	return q
 }
 
-func (q *SelectQuery) GroupExpr(group string, args ...interface{}) *SelectQuery {
+func (q *SelectQuery) GroupExpr(group string, args ...any) *SelectQuery {
 	q.group = append(q.group, schema.SafeQuery(group, args))
 	return q
 }
 
-func (q *SelectQuery) Having(having string, args ...interface{}) *SelectQuery {
+func (q *SelectQuery) Having(having string, args ...any) *SelectQuery {
 	q.having = append(q.having, schema.SafeQuery(having, args))
 	return q
 }
@@ -281,7 +286,12 @@ func (q *SelectQuery) Order(orders ...string) *SelectQuery {
 	return q
 }
 
-func (q *SelectQuery) OrderExpr(query string, args ...interface{}) *SelectQuery {
+func (q *SelectQuery) OrderBy(colName string, sortDir Order) *SelectQuery {
+	q.addOrderBy(colName, sortDir)
+	return q
+}
+
+func (q *SelectQuery) OrderExpr(query string, args ...any) *SelectQuery {
 	q.addOrderExpr(query, args...)
 	return q
 }
@@ -296,7 +306,7 @@ func (q *SelectQuery) Offset(n int) *SelectQuery {
 	return q
 }
 
-func (q *SelectQuery) For(s string, args ...interface{}) *SelectQuery {
+func (q *SelectQuery) For(s string, args ...any) *SelectQuery {
 	q.selFor = schema.SafeQuery(s, args)
 	return q
 }
@@ -337,22 +347,22 @@ func (q *SelectQuery) addUnion(expr string, other *SelectQuery) *SelectQuery {
 
 //------------------------------------------------------------------------------
 
-func (q *SelectQuery) Join(join string, args ...interface{}) *SelectQuery {
+func (q *SelectQuery) Join(join string, args ...any) *SelectQuery {
 	q.joins = append(q.joins, joinQuery{
 		join: schema.SafeQuery(join, args),
 	})
 	return q
 }
 
-func (q *SelectQuery) JoinOn(cond string, args ...interface{}) *SelectQuery {
+func (q *SelectQuery) JoinOn(cond string, args ...any) *SelectQuery {
 	return q.joinOn(cond, args, " AND ")
 }
 
-func (q *SelectQuery) JoinOnOr(cond string, args ...interface{}) *SelectQuery {
+func (q *SelectQuery) JoinOnOr(cond string, args ...any) *SelectQuery {
 	return q.joinOn(cond, args, " OR ")
 }
 
-func (q *SelectQuery) joinOn(cond string, args []interface{}, sep string) *SelectQuery {
+func (q *SelectQuery) joinOn(cond string, args []any, sep string) *SelectQuery {
 	if len(q.joins) == 0 {
 		q.setErr(errors.New("bun: query has no joins"))
 		return q
@@ -507,20 +517,20 @@ func (q *SelectQuery) Operation() string {
 	return "SELECT"
 }
 
-func (q *SelectQuery) AppendQuery(fmter schema.Formatter, b []byte) (_ []byte, err error) {
+func (q *SelectQuery) AppendQuery(gen schema.QueryGen, b []byte) (_ []byte, err error) {
 	b = appendComment(b, q.comment)
 
-	return q.appendQuery(fmter, b, false)
+	return q.appendQuery(gen, b, false)
 }
 
 func (q *SelectQuery) appendQuery(
-	fmter schema.Formatter, b []byte, count bool,
+	gen schema.QueryGen, b []byte, count bool,
 ) (_ []byte, err error) {
 	if q.err != nil {
 		return nil, q.err
 	}
 
-	fmter = formatterWithModel(fmter, q)
+	gen = formatterWithModel(gen, q)
 
 	cteCount := count && (len(q.group) > 0 || q.distinctOn != nil)
 	if cteCount {
@@ -531,7 +541,7 @@ func (q *SelectQuery) appendQuery(
 		b = append(b, '(')
 	}
 
-	b, err = q.appendWith(fmter, b)
+	b, err = q.appendWith(gen, b)
 	if err != nil {
 		return nil, err
 	}
@@ -551,7 +561,7 @@ func (q *SelectQuery) appendQuery(
 			if i > 0 {
 				b = append(b, ", "...)
 			}
-			b, err = app.AppendQuery(fmter, b)
+			b, err = app.AppendQuery(gen, b)
 			if err != nil {
 				return nil, err
 			}
@@ -565,44 +575,44 @@ func (q *SelectQuery) appendQuery(
 		b = append(b, "count(*)"...)
 	} else {
 		// MSSQL: allows Limit() without Order() as per https://stackoverflow.com/a/36156953
-		if q.limit > 0 && len(q.order) == 0 && fmter.Dialect().Name() == dialect.MSSQL {
+		if q.limit > 0 && len(q.order) == 0 && gen.Dialect().Name() == dialect.MSSQL {
 			b = append(b, "0 AS _temp_sort, "...)
 		}
 
-		b, err = q.appendColumns(fmter, b)
+		b, err = q.appendColumns(gen, b)
 		if err != nil {
 			return nil, err
 		}
 	}
 
 	if q.hasTables() {
-		b, err = q.appendTables(fmter, b)
+		b, err = q.appendTables(gen, b)
 		if err != nil {
 			return nil, err
 		}
 	}
 
-	b, err = q.appendIndexHints(fmter, b)
+	b, err = q.appendIndexHints(gen, b)
 	if err != nil {
 		return nil, err
 	}
 
 	if err := q.forEachInlineRelJoin(func(j *relationJoin) error {
 		b = append(b, ' ')
-		b, err = j.appendHasOneJoin(fmter, b, q)
+		b, err = j.appendHasOneJoin(gen, b, q)
 		return err
 	}); err != nil {
 		return nil, err
 	}
 
 	for _, join := range q.joins {
-		b, err = join.AppendQuery(fmter, b)
+		b, err = join.AppendQuery(gen, b)
 		if err != nil {
 			return nil, err
 		}
 	}
 
-	b, err = q.appendWhere(fmter, b, true)
+	b, err = q.appendWhere(gen, b, true)
 	if err != nil {
 		return nil, err
 	}
@@ -613,7 +623,7 @@ func (q *SelectQuery) appendQuery(
 			if i > 0 {
 				b = append(b, ", "...)
 			}
-			b, err = f.AppendQuery(fmter, b)
+			b, err = f.AppendQuery(gen, b)
 			if err != nil {
 				return nil, err
 			}
@@ -627,7 +637,7 @@ func (q *SelectQuery) appendQuery(
 				b = append(b, " AND "...)
 			}
 			b = append(b, '(')
-			b, err = f.AppendQuery(fmter, b)
+			b, err = f.AppendQuery(gen, b)
 			if err != nil {
 				return nil, err
 			}
@@ -636,19 +646,19 @@ func (q *SelectQuery) appendQuery(
 	}
 
 	if !count {
-		b, err = q.appendOrder(fmter, b)
+		b, err = q.appendOrder(gen, b)
 		if err != nil {
 			return nil, err
 		}
 
-		b, err = q.appendLimitOffset(fmter, b)
+		b, err = q.appendLimitOffset(gen, b)
 		if err != nil {
 			return nil, err
 		}
 
 		if !q.selFor.IsZero() {
 			b = append(b, " FOR "...)
-			b, err = q.selFor.AppendQuery(fmter, b)
+			b, err = q.selFor.AppendQuery(gen, b)
 			if err != nil {
 				return nil, err
 			}
@@ -661,7 +671,7 @@ func (q *SelectQuery) appendQuery(
 		for _, u := range q.union {
 			b = append(b, u.expr...)
 			b = append(b, '(')
-			b, err = u.query.AppendQuery(fmter, b)
+			b, err = u.query.AppendQuery(gen, b)
 			if err != nil {
 				return nil, err
 			}
@@ -676,7 +686,7 @@ func (q *SelectQuery) appendQuery(
 	return b, nil
 }
 
-func (q *SelectQuery) appendColumns(fmter schema.Formatter, b []byte) (_ []byte, err error) {
+func (q *SelectQuery) appendColumns(gen schema.QueryGen, b []byte) (_ []byte, err error) {
 	start := len(b)
 
 	switch {
@@ -695,16 +705,16 @@ func (q *SelectQuery) appendColumns(fmter schema.Formatter, b []byte) (_ []byte,
 				}
 			}
 
-			b, err = col.AppendQuery(fmter, b)
+			b, err = col.AppendQuery(gen, b)
 			if err != nil {
 				return nil, err
 			}
 		}
 	case q.table != nil:
-		if len(q.table.Fields) > 10 && fmter.IsNop() {
+		if len(q.table.Fields) > 10 && gen.IsNop() {
 			b = append(b, q.table.SQLAlias...)
 			b = append(b, '.')
-			b = fmter.Dialect().AppendString(b, fmt.Sprintf("%d columns", len(q.table.Fields)))
+			b = gen.Dialect().AppendString(b, fmt.Sprintf("%d columns", len(q.table.Fields)))
 		} else {
 			b = appendColumns(b, q.table.SQLAlias, q.table.Fields)
 		}
@@ -718,7 +728,7 @@ func (q *SelectQuery) appendColumns(fmter schema.Formatter, b []byte) (_ []byte,
 			start = len(b)
 		}
 
-		b, err = q.appendInlineRelColumns(fmter, b, join)
+		b, err = q.appendInlineRelColumns(gen, b, join)
 		if err != nil {
 			return err
 		}
@@ -734,7 +744,7 @@ func (q *SelectQuery) appendColumns(fmter schema.Formatter, b []byte) (_ []byte,
 }
 
 func (q *SelectQuery) appendInlineRelColumns(
-	fmter schema.Formatter, b []byte, join *relationJoin,
+	gen schema.QueryGen, b []byte, join *relationJoin,
 ) (_ []byte, err error) {
 	if join.columns != nil {
 		table := join.JoinModel.Table()
@@ -745,16 +755,16 @@ func (q *SelectQuery) appendInlineRelColumns(
 
 			if col.Args == nil {
 				if field, ok := table.FieldMap[col.Query]; ok {
-					b = join.appendAlias(fmter, b)
+					b = join.appendAlias(gen, b)
 					b = append(b, '.')
 					b = append(b, field.SQLName...)
 					b = append(b, " AS "...)
-					b = join.appendAliasColumn(fmter, b, field.Name)
+					b = join.appendAliasColumn(gen, b, field.Name)
 					continue
 				}
 			}
 
-			b, err = col.AppendQuery(fmter, b)
+			b, err = col.AppendQuery(gen, b)
 			if err != nil {
 				return nil, err
 			}
@@ -766,18 +776,18 @@ func (q *SelectQuery) appendInlineRelColumns(
 		if i > 0 {
 			b = append(b, ", "...)
 		}
-		b = join.appendAlias(fmter, b)
+		b = join.appendAlias(gen, b)
 		b = append(b, '.')
 		b = append(b, field.SQLName...)
 		b = append(b, " AS "...)
-		b = join.appendAliasColumn(fmter, b, field.Name)
+		b = join.appendAliasColumn(gen, b, field.Name)
 	}
 	return b, nil
 }
 
-func (q *SelectQuery) appendTables(fmter schema.Formatter, b []byte) (_ []byte, err error) {
+func (q *SelectQuery) appendTables(gen schema.QueryGen, b []byte) (_ []byte, err error) {
 	b = append(b, " FROM "...)
-	return q.appendTablesWithAlias(fmter, b)
+	return q.appendTablesWithAlias(gen, b)
 }
 
 //------------------------------------------------------------------------------
@@ -794,7 +804,7 @@ func (q *SelectQuery) Rows(ctx context.Context) (*sql.Rows, error) {
 	// if a comment is propagated via the context, use it
 	setCommentFromContext(ctx, q)
 
-	queryBytes, err := q.AppendQuery(q.db.fmter, q.db.makeQueryBytes())
+	queryBytes, err := q.AppendQuery(q.db.gen, q.db.makeQueryBytes())
 	if err != nil {
 		return nil, err
 	}
@@ -802,12 +812,12 @@ func (q *SelectQuery) Rows(ctx context.Context) (*sql.Rows, error) {
 	query := internal.String(queryBytes)
 
 	ctx, event := q.db.beforeQuery(ctx, q, query, nil, query, q.model)
-	rows, err := q.resolveConn(q).QueryContext(ctx, query)
+	rows, err := q.resolveConn(ctx, q).QueryContext(ctx, query)
 	q.db.afterQuery(ctx, event, nil, err)
 	return rows, err
 }
 
-func (q *SelectQuery) Exec(ctx context.Context, dest ...interface{}) (res sql.Result, err error) {
+func (q *SelectQuery) Exec(ctx context.Context, dest ...any) (res sql.Result, err error) {
 	if q.err != nil {
 		return nil, q.err
 	}
@@ -818,7 +828,7 @@ func (q *SelectQuery) Exec(ctx context.Context, dest ...interface{}) (res sql.Re
 	// if a comment is propagated via the context, use it
 	setCommentFromContext(ctx, q)
 
-	queryBytes, err := q.AppendQuery(q.db.fmter, q.db.makeQueryBytes())
+	queryBytes, err := q.AppendQuery(q.db.gen, q.db.makeQueryBytes())
 	if err != nil {
 		return nil, err
 	}
@@ -845,12 +855,12 @@ func (q *SelectQuery) Exec(ctx context.Context, dest ...interface{}) (res sql.Re
 	return res, nil
 }
 
-func (q *SelectQuery) Scan(ctx context.Context, dest ...interface{}) error {
+func (q *SelectQuery) Scan(ctx context.Context, dest ...any) error {
 	_, err := q.scanResult(ctx, dest...)
 	return err
 }
 
-func (q *SelectQuery) scanResult(ctx context.Context, dest ...interface{}) (sql.Result, error) {
+func (q *SelectQuery) scanResult(ctx context.Context, dest ...any) (sql.Result, error) {
 	if q.err != nil {
 		return nil, q.err
 	}
@@ -881,7 +891,7 @@ func (q *SelectQuery) scanResult(ctx context.Context, dest ...interface{}) (sql.
 	// if a comment is propagated via the context, use it
 	setCommentFromContext(ctx, q)
 
-	queryBytes, err := q.AppendQuery(q.db.fmter, q.db.makeQueryBytes())
+	queryBytes, err := q.AppendQuery(q.db.gen, q.db.makeQueryBytes())
 	if err != nil {
 		return nil, err
 	}
@@ -938,7 +948,7 @@ func (q *SelectQuery) Count(ctx context.Context) (int, error) {
 
 	qq := countQuery{q}
 
-	queryBytes, err := qq.AppendQuery(q.db.fmter, nil)
+	queryBytes, err := qq.AppendQuery(q.db.gen, nil)
 	if err != nil {
 		return 0, err
 	}
@@ -947,14 +957,14 @@ func (q *SelectQuery) Count(ctx context.Context) (int, error) {
 	ctx, event := q.db.beforeQuery(ctx, qq, query, nil, query, q.model)
 
 	var num int
-	err = q.resolveConn(q).QueryRowContext(ctx, query).Scan(&num)
+	err = q.resolveConn(ctx, q).QueryRowContext(ctx, query).Scan(&num)
 
 	q.db.afterQuery(ctx, event, nil, err)
 
 	return num, err
 }
 
-func (q *SelectQuery) ScanAndCount(ctx context.Context, dest ...interface{}) (int, error) {
+func (q *SelectQuery) ScanAndCount(ctx context.Context, dest ...any) (int, error) {
 	if q.offset == 0 && q.limit == 0 {
 		// If there is no limit and offset, we can use a single query to get the count and scan
 		if res, err := q.scanResult(ctx, dest...); err != nil {
@@ -972,7 +982,7 @@ func (q *SelectQuery) ScanAndCount(ctx context.Context, dest ...interface{}) (in
 }
 
 func (q *SelectQuery) scanAndCountConcurrently(
-	ctx context.Context, dest ...interface{},
+	ctx context.Context, dest ...any,
 ) (int, error) {
 	var count int
 	var wg sync.WaitGroup
@@ -1018,7 +1028,7 @@ func (q *SelectQuery) scanAndCountConcurrently(
 	return count, firstErr
 }
 
-func (q *SelectQuery) scanAndCountSeq(ctx context.Context, dest ...interface{}) (int, error) {
+func (q *SelectQuery) scanAndCountSeq(ctx context.Context, dest ...any) (int, error) {
 	var firstErr error
 
 	// Don't scan results if the user explicitly set Limit(-1).
@@ -1051,7 +1061,7 @@ func (q *SelectQuery) selectExists(ctx context.Context) (bool, error) {
 
 	qq := selectExistsQuery{q}
 
-	queryBytes, err := qq.AppendQuery(q.db.fmter, nil)
+	queryBytes, err := qq.AppendQuery(q.db.gen, nil)
 	if err != nil {
 		return false, err
 	}
@@ -1060,7 +1070,7 @@ func (q *SelectQuery) selectExists(ctx context.Context) (bool, error) {
 	ctx, event := q.db.beforeQuery(ctx, qq, query, nil, query, q.model)
 
 	var exists bool
-	err = q.resolveConn(q).QueryRowContext(ctx, query).Scan(&exists)
+	err = q.resolveConn(ctx, q).QueryRowContext(ctx, query).Scan(&exists)
 
 	q.db.afterQuery(ctx, event, nil, err)
 
@@ -1073,7 +1083,7 @@ func (q *SelectQuery) whereExists(ctx context.Context) (bool, error) {
 
 	qq := whereExistsQuery{q}
 
-	queryBytes, err := qq.AppendQuery(q.db.fmter, nil)
+	queryBytes, err := qq.AppendQuery(q.db.gen, nil)
 	if err != nil {
 		return false, err
 	}
@@ -1095,7 +1105,7 @@ func (q *SelectQuery) whereExists(ctx context.Context) (bool, error) {
 // String returns the generated SQL query string. The SelectQuery instance must not be
 // modified during query generation to ensure multiple calls to String() return identical results.
 func (q *SelectQuery) String() string {
-	buf, err := q.AppendQuery(q.db.Formatter(), nil)
+	buf, err := q.AppendQuery(q.db.QueryGen(), nil)
 	if err != nil {
 		panic(err)
 	}
@@ -1108,7 +1118,7 @@ func (q *SelectQuery) Clone() *SelectQuery {
 	}
 
 	cloneArgs := func(args []schema.QueryWithArgs) []schema.QueryWithArgs {
-		if len(args) == 0 {
+		if args == nil {
 			return nil
 		}
 		clone := make([]schema.QueryWithArgs, len(args))
@@ -1138,7 +1148,7 @@ func (q *SelectQuery) Clone() *SelectQuery {
 				table:          q.table,
 				model:          q.model,
 				tableModel:     tableModel,
-				with:           make([]withQuery, len(q.with)),
+				with:           make([]WithQuery, len(q.with)),
 				tables:         cloneArgs(q.tables),
 				columns:        cloneArgs(q.columns),
 				modelTableName: q.modelTableName,
@@ -1167,7 +1177,7 @@ func (q *SelectQuery) Clone() *SelectQuery {
 	}
 
 	for i, w := range q.with {
-		clone.with[i] = withQuery{
+		clone.with[i] = WithQuery{
 			name:      w.name,
 			recursive: w.recursive,
 			query:     w.query, // TODO: maybe clone is need
@@ -1243,12 +1253,12 @@ func (q *selectQueryBuilder) WhereGroup(
 	return q
 }
 
-func (q *selectQueryBuilder) Where(query string, args ...interface{}) QueryBuilder {
+func (q *selectQueryBuilder) Where(query string, args ...any) QueryBuilder {
 	q.SelectQuery.Where(query, args...)
 	return q
 }
 
-func (q *selectQueryBuilder) WhereOr(query string, args ...interface{}) QueryBuilder {
+func (q *selectQueryBuilder) WhereOr(query string, args ...any) QueryBuilder {
 	q.SelectQuery.WhereOr(query, args...)
 	return q
 }
@@ -1268,7 +1278,7 @@ func (q *selectQueryBuilder) WherePK(cols ...string) QueryBuilder {
 	return q
 }
 
-func (q *selectQueryBuilder) Unwrap() interface{} {
+func (q *selectQueryBuilder) Unwrap() any {
 	return q.SelectQuery
 }
 
@@ -1279,10 +1289,10 @@ type joinQuery struct {
 	on   []schema.QueryWithSep
 }
 
-func (j *joinQuery) AppendQuery(fmter schema.Formatter, b []byte) (_ []byte, err error) {
+func (j *joinQuery) AppendQuery(gen schema.QueryGen, b []byte) (_ []byte, err error) {
 	b = append(b, ' ')
 
-	b, err = j.join.AppendQuery(fmter, b)
+	b, err = j.join.AppendQuery(gen, b)
 	if err != nil {
 		return nil, err
 	}
@@ -1295,7 +1305,7 @@ func (j *joinQuery) AppendQuery(fmter schema.Formatter, b []byte) (_ []byte, err
 			}
 
 			b = append(b, '(')
-			b, err = on.AppendQuery(fmter, b)
+			b, err = on.AppendQuery(gen, b)
 			if err != nil {
 				return nil, err
 			}
@@ -1312,11 +1322,11 @@ type countQuery struct {
 	*SelectQuery
 }
 
-func (q countQuery) AppendQuery(fmter schema.Formatter, b []byte) (_ []byte, err error) {
+func (q countQuery) AppendQuery(gen schema.QueryGen, b []byte) (_ []byte, err error) {
 	if q.err != nil {
 		return nil, q.err
 	}
-	return q.appendQuery(fmter, b, true)
+	return q.appendQuery(gen, b, true)
 }
 
 //------------------------------------------------------------------------------
@@ -1325,14 +1335,14 @@ type selectExistsQuery struct {
 	*SelectQuery
 }
 
-func (q selectExistsQuery) AppendQuery(fmter schema.Formatter, b []byte) (_ []byte, err error) {
+func (q selectExistsQuery) AppendQuery(gen schema.QueryGen, b []byte) (_ []byte, err error) {
 	if q.err != nil {
 		return nil, q.err
 	}
 
 	b = append(b, "SELECT EXISTS ("...)
 
-	b, err = q.appendQuery(fmter, b, false)
+	b, err = q.appendQuery(gen, b, false)
 	if err != nil {
 		return nil, err
 	}
@@ -1348,14 +1358,14 @@ type whereExistsQuery struct {
 	*SelectQuery
 }
 
-func (q whereExistsQuery) AppendQuery(fmter schema.Formatter, b []byte) (_ []byte, err error) {
+func (q whereExistsQuery) AppendQuery(gen schema.QueryGen, b []byte) (_ []byte, err error) {
 	if q.err != nil {
 		return nil, q.err
 	}
 
 	b = append(b, "SELECT 1 WHERE EXISTS ("...)
 
-	b, err = q.appendQuery(fmter, b, false)
+	b, err = q.appendQuery(gen, b, false)
 	if err != nil {
 		return nil, err
 	}
