@@ -98,7 +98,7 @@ func (f *Field) HasZeroValue(v reflect.Value) bool {
 	return f.IsZero(v)
 }
 
-func (f *Field) AppendValue(fmter Formatter, b []byte, strct reflect.Value) []byte {
+func (f *Field) AppendValue(gen QueryGen, b []byte, strct reflect.Value) []byte {
 	fv, ok := fieldByIndex(strct, f.Index)
 	if !ok {
 		return dialect.AppendNull(b)
@@ -110,10 +110,10 @@ func (f *Field) AppendValue(fmter Formatter, b []byte, strct reflect.Value) []by
 	if f.Append == nil {
 		panic(fmt.Errorf("bun: AppendValue(unsupported %s)", fv.Type()))
 	}
-	return f.Append(fmter, b, fv)
+	return f.Append(gen, b, fv)
 }
 
-func (f *Field) ScanValue(strct reflect.Value, src interface{}) error {
+func (f *Field) ScanValue(strct reflect.Value, src any) error {
 	if src == nil {
 		if fv, ok := fieldByIndex(strct, f.Index); ok {
 			return f.ScanWithCheck(fv, src)
@@ -125,7 +125,7 @@ func (f *Field) ScanValue(strct reflect.Value, src interface{}) error {
 	return f.ScanWithCheck(fv, src)
 }
 
-func (f *Field) ScanWithCheck(fv reflect.Value, src interface{}) error {
+func (f *Field) ScanWithCheck(fv reflect.Value, src any) error {
 	if f.Scan == nil {
 		return fmt.Errorf("bun: Scan(unsupported %s)", f.IndirectType)
 	}
