@@ -8,7 +8,7 @@ import (
 
 type Model interface {
 	ScanRows(ctx context.Context, rows *sql.Rows) (int, error)
-	Value() interface{}
+	Value() any
 }
 
 type Query interface {
